#
# spec file for package libvirt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Stateful hypervisor drivers that run in daemons
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:0}

# Stateless hypervisor drivers that run in libvirt.so
# The esx driver is built for both openSUSE and SLE, but it is not supported
%define with_esx           0%{!?_without_esx:1}
# Until we have requests for them, disable building the vmware, hyperv and
# openvz drivers
%define with_vmware        0%{!?_without_vmware:0}
%define with_hyperv        0%{!?_without_hyperv:0}
%define with_openvz        0%{!?_without_openvz:0}

# Stateful secondary host drivers that run in daemons
%define with_storage_rbd   0%{!?_without_storage_rbd:0}
# The gluster storage backend is built for both openSUSE and SLE, but it is
# not supported
%define with_storage_gluster  0%{!?_without_storage_gluster:1}
%define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:0}
%define with_apparmor      0%{!?_without_apparmor:1}
# The udev interface backend is the only one that works across SUSE distros.
# It supports just a handful of read-only operations, has a history of
# instability, and is insufficiently maintained. Completely disable the
# interface driver.
%define with_interface     0%{!?_without_interface:0}

# Optional bits on by default
%define with_sanlock       0%{!?_without_sanlock:1}
%define with_polkit_rules  0%{!?_without_polkit_rules:1}
%define with_wireshark     0%{!?_without_wireshark:1}
%define with_libssh2       0%{!?_without_libssh2:1}
%define with_numactl       0%{!?_without_numactl:1}
%define with_modular_daemons 0%{!?_without_modular_daemons:1}
%define with_userfaultfd_sysctl 0%{!?_without_userfaultfd_sysctl:1}

# A few optional bits off by default, we enable later
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld_zone 0%{!?_without_firewalld_zone:0}
%define with_libssh        0%{!?_without_libssh:0}
%define with_nbdkit        0%{!?_without_nbdkit:0}
%define with_nbdkit_config_default 0%{!?_without_nbdkit_config_default:0}

# Set the OS / architecture specific special cases

# Xen is only available on x86_64
%ifnarch x86_64
    %define with_libxl     0
%endif

# Enable numactl for most architectures. Handle aarch64 separately
%ifarch s390 s390x %arm %ix86
    %define with_numactl   0
%endif

# Tumbleweeed is new enough to support /dev/userfaultfd, which
# does not require enabling vm.unprivileged_userfaultfd sysct
%if 0%{?suse_version} > 1500
    %define with_userfaultfd_sysctl 0
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox      0
%endif

# The 'libvirt' zone must be used with firewalld >= 0.7.0
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
    %define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%endif

# Enable libssh support in newer code bases
%if 0%{?suse_version} >= 1500
    %define with_libssh    0%{!?_without_libssh:1}
%endif

%ifarch x86_64 aarch64
    %define with_storage_rbd 0%{!?_without_storage_rbd:1}
%endif

# libiscsi storage backend needs libiscsi >= 1.18.0 which is only available
# in suse_version >= 1500
%if 0%{?suse_version} >= 1500
    %define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
%endif

# numad is used to manage the CPU and memory placement dynamically for
# qemu and lxc drivers
%if %{with_qemu} || %{with_lxc}
# Enable numad for most architectures
    %ifnarch s390 s390x %arm %ix86
        %define with_numad 0%{!?_without_numad:1}
    %endif
%endif

# Items to exclude in SLFO:Main based products
%if 0%{?suse_version} == 1600
    %define with_apparmor  0
    %define with_esx       0
    %define with_interface 0
    %define with_libxl     0
    %define with_lxc       0
    %define with_numad     0
    %define with_sanlock   0
    %define with_storage_gluster 0
    %define with_storage_rbd     0
%endif

# Prefer nftables if available
%if "%{?default_firewall_backend}" == "nftables"
    %define prefer_nftables 1
    %define firewall_backend_priority nftables,iptables
%else
    %define prefer_nftables 0
    %define firewall_backend_priority iptables,nftables
%endif

# Force QEMU to run as qemu:qemu
%define qemu_user          qemu
%define qemu_group         qemu

# Locations for QEMU data
%define qemu_moddir        %{_libdir}/qemu
%define qemu_datadir       %{_datadir}/qemu

%define _fwdefdir %{_prefix}/lib/firewalld/services

%if %{with_wireshark}
    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan
%endif

Name:           libvirt
URL:            https://libvirt.org/
Version:        11.2.0
Release:        2.1
Summary:        Library providing a virtualization API
License:        LGPL-2.1-or-later

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-config-network = %{version}-%{release}
Requires:       %{name}-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires:       %{name}-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_qemu}
Requires:       %{name}-client-qemu = %{version}-%{release}
Requires:       %{name}-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_vbox}
Requires:       %{name}-daemon-driver-vbox = %{version}-%{release}
%endif
Requires:       %{name}-client = %{version}-%{release}
%if %{with_interface}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
%endif
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires:  gettext-tools
BuildRequires:  meson >= 0.56.0
BuildRequires:  ninja
# Needed for modprobe and tests/virkmodtest
BuildRequires:  kmod
BuildRequires:  pkgconfig(systemd)
%if %{with_libxl}
BuildRequires:  xen-devel
%endif
%if %{with_qemu}
# For managing ACLs
BuildRequires:  libacl-devel
# For qemu-bridge-helper, qemu-pr-helper
BuildRequires:  qemu-tools
%endif
BuildRequires:  bash-completion-devel >= 2.0
BuildRequires:  glib2-devel >= 2.66
BuildRequires:  libattr-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libtasn1-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt
BuildRequires:  perl
BuildRequires:  python3
BuildRequires:  python3-docutils
BuildRequires:  python3-pytest
BuildRequires:  readline-devel
# For pool-build probing for existing pools
BuildRequires:  libblkid-devel >= 2.17
BuildRequires:  libpciaccess0-devel >= 0.10.9
BuildRequires:  libjson-c-devel
BuildRequires:  pkgconfig(libudev) >= 145
%if %{with_sanlock}
BuildRequires:  sanlock-devel >= 2.4
%endif
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel >= 1.5.0
BuildRequires:  libselinux-devel
BuildRequires:  libtirpc-devel
%if %{with_apparmor}
BuildRequires:  apparmor-rpm-macros
BuildRequires:  libapparmor-devel
%endif
BuildRequires:  cyrus-sasl-devel
BuildRequires:  polkit >= 0.112
%if %{with_nbdkit}
BuildRequires:  libnbd-devel
%endif
# For mount/umount in FS driver
BuildRequires:  util-linux
# For LVM drivers
BuildRequires:  lvm2
# For pool type=iscsi
BuildRequires:  open-iscsi
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires:  libiscsi-devel
%endif
# For disk driver
BuildRequires:  parted
BuildRequires:  parted-devel
# For Multipath support
BuildRequires:  device-mapper-devel
%if %{with_storage_rbd}
BuildRequires:  librbd-devel
%endif
%if %{with_storage_gluster}
BuildRequires:  glusterfs-devel >= 3.4.1
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires:  libnuma-devel
%endif
BuildRequires:  fuse-devel >= 2.8.6
BuildRequires:  libcap-ng-devel >= 0.5.0
%if %{with_interface}
BuildRequires:  libnetcontrol-devel >= 0.2.0
%endif
%if %{with_libssh2}
BuildRequires:  libssh2-devel
%endif
%if %{with_esx}
BuildRequires:  libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires:  libwsman-devel >= 2.6.3
%endif
BuildRequires:  audit-devel
# For /usr/sbin/dtrace
BuildRequires:  systemtap-sdt-devel
%if %{with_numad}
BuildRequires:  numad
%endif
%if %{with_wireshark}
BuildRequires:  wireshark-devel
%endif
%if %{with_libssh}
BuildRequires:  libssh-devel >= 0.8.1
%endif
# Needed for the firewalld_reload macro
%if %{with_firewalld_zone}
BuildRequires:  firewall-macros
%endif

Source0:        %{name}-%{version}.tar.xz
Source1:        libvirt-supportconfig
Source2:        suse-qemu-domain-hook.py
Source3:        libvirtd-relocation-server.xml
Source98:       README.packaging.txt
Source99:       baselibs.conf
Source100:      %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libvirt is a C toolkit to interact with the virtualization
capabilities of Linux. Virtualization of the Linux Operating System means
the ability to run multiple instances of Operating Systems concurrently
on a single hardware system where the basic resources are driven by a
Linux instance. The library aims to provide long term stable C API
to interact with Linux virtualization technologies.

This package does not contain files, it just requires the necessary packages.

%package doc
Summary:        API reference and website documentation for libvirt
BuildArch:      noarch

%description doc
The API reference for the libvirt C library, and a
copy of the libvirt.org website documentation.

%package daemon
Summary:        Server side daemon and supporting files for libvirt
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-daemon-lock = %{version}-%{release}
Requires:       %{name}-daemon-log = %{version}-%{release}
Requires:       %{name}-daemon-plugin-lockd = %{version}-%{release}
Requires:       %{name}-daemon-proxy = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-common
Summary:        Files and utilities used by daemons
Requires:       %{name}-libs = %{version}-%{release}
# The libvirt-guests.sh script requires virsh from libvirt-client subpackage,
# but not every deployment wants to use libvirt-guests service. Using
# Recommends here will install libvirt-client by default (if available), but
# RPM won't complain if the package is unavailable, masked, or removed later.
Recommends:     %{name}-client = %{version}-%{release}
# for /sbin/ip & /sbin/tc
Requires:       iproute
Requires:       logrotate
Requires:       pkgconfig(udev) >= 145
Recommends:     polkit >= 0.112
%ifarch %ix86 x86_64 aarch64
# For virConnectGetSysinfo
Requires:       dmidecode
%endif
# For service management
%{?systemd_requires}
# Daemons depend on the 'messagebus' service
Requires:       dbus-1
Requires:       group(libvirt)
# Needed by libvirt-guests init script.
Requires:       gettext-runtime
Requires:       bash-completion >= 2.0
# virt-manager uses netcat for accessing spice and VNC servers running in
# qemu processes. See boo#1222100 for details. Although libvirt does not
# use netcat, it's in a good position to provide the dependency for
# virt-manager. netcat-openbsd is a tiny package, so it's a tolerable hack.
Requires:       netcat-openbsd

%if %{with_apparmor}
Recommends:     apparmor-abstractions
%endif

# Ensure smooth upgrades
Obsoletes:      %{name}-admin < 7.3.0
Provides:       %{name}-admin = %{version}
Obsoletes:      %{name}-bash-completion < 7.3.0

%description daemon-common
Miscellaneous files and utilities used by other libvirt daemons

%package daemon-lock
Summary:        Server side daemon for managing locks
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-lock
Server side daemon used to manage locks held against virtual machine
resources

%package daemon-plugin-lockd
Summary:        lockd client plugin for virtlockd
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-daemon-common = %{version}-%{release}

%description daemon-plugin-lockd
A client-side plugin that implements disk locking using POSIX fcntl advisory
locks via communication with the virtlockd daemon

%package daemon-log
Summary:        Server side daemon for managing logs
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-log
Server side daemon used to manage logs from virtual machine consoles

%package daemon-proxy
Summary:        Server side daemon providing libvirtd proxy
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-proxy
Server side daemon providing functionality previously provided by
the monolithic libvirtd

%package daemon-hooks
Summary:        Hook scripts for QEMU
Requires:       %{name}-daemon-driver-qemu = %{version}-%{release}
Requires:       python3-lxml

%description daemon-hooks
Hook scripts for the virtqemud daemon

%package daemon-config-network
Summary:        Default configuration files for the libvirtd daemon
Requires:       %{name}-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary:        Network filter configuration files for the libvirtd
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for the libvirt daemon, used for
cleaning guest network traffic.

%package daemon-driver-network
Summary:        Network driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       dnsmasq >= 2.41
%if %{prefer_nftables}
Requires:       nftables
%else
Requires:       iptables
%endif

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.

%package daemon-driver-nwfilter
Summary:        A nwfilter driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       ebtables
Requires:       iptables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities

%package daemon-driver-nodedev
Summary:        Nodedev driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
# For managing persistent mediated devices
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
Requires:       mdevctl
%endif
# For modprobe of pci devices
Requires:       modutils

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.

%package daemon-driver-interface
Summary:        Interface driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcontrol library

%package daemon-driver-secret
Summary:        Secret driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage-core
Summary:        Storage driver plugin including base backends for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Recommends:     nfs-utils
# For mkfs
Requires:       util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires:       /usr/bin/qemu-img
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%package daemon-driver-storage-logical
Summary:        Storage driver plugin for lvm volumes
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.

%package daemon-driver-storage-disk
Summary:        Storage driver plugin for disk
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       device-mapper
Requires:       parted

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.

%package daemon-driver-storage-scsi
Summary:        Storage driver plugin for local scsi devices
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.

%package daemon-driver-storage-iscsi
Summary:        Storage driver plugin for iscsi
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       open-iscsi

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.

%package daemon-driver-storage-iscsi-direct
Summary:        Storage driver plugin for iscsi-direct
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.

%package daemon-driver-storage-mpath
Summary:        Storage driver plugin for multipath volumes
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.

%package daemon-driver-storage-gluster
Summary:        Storage driver plugin for gluster
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.

%package daemon-driver-storage-rbd
Summary:        Storage driver plugin for rbd
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.

%package daemon-driver-storage
Summary:        Storage driver plugin including all backends for the libvirtd daemon
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-disk = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-iscsi = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-logical = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-mpath = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-scsi = %{version}-%{release}
# Closing the Leap gap note:
# Generally we would have a conditional 'Requires:' for daemon-driver-storage-gluster
# similar to the other configurable storage backends, but gluster is not supported in
# SLE. We'll build the backend so it is available but not require it as part of the
# daemon-driver-storage metapackage
%if %{with_storage_rbd}
Requires:       %{name}-daemon-driver-storage-rbd = %{version}-%{release}
%endif
%if %{with_storage_iscsi_direct}
Requires:       %{name}-daemon-driver-storage-iscsi-direct = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.

This package does not contain files, it just requires the necessary packages.

%package daemon-driver-qemu
Summary:        Qemu driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-daemon-log = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       /usr/bin/qemu-img
# For image compression
Requires:       /usr/bin/bzip2
Requires:       /usr/bin/gzip
Requires:       /usr/bin/lzop
Requires:       /usr/bin/xz
Requires:       /usr/bin/zstd
Requires:       qemu
Requires:       systemd-container
# swtp is needed to manage <tpm> devices.
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150300
Requires:       swtpm
%endif
%ifarch x86_64
Requires:       qemu-ovmf-x86_64
%endif
%ifarch aarch64
Requires:       qemu-uefi-aarch64
%endif
%if %{with_numad}
Suggests:       numad
%endif
%if %{with_nbdkit}
Recommends:     nbdkit
Recommends:     nbdkit-curl-plugin
Recommends:     nbdkit-ssh-plugin
%endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using QEMU.

%package daemon-driver-lxc
Summary:        LXC driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       systemd-container
# For modprobe of nbd driver
Requires:       modutils
%if %{with_numad}
Suggests:       numad
%endif

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel

%package daemon-driver-vbox
Summary:        VirtualBox driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox

%package daemon-driver-libxl
Summary:        Libxl driver plugin for the libvirtd daemon
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       qemu-ovmf-x86_64

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using libxl.

%package daemon-qemu
Summary:        Server side daemon & driver required to run QEMU guests
%if %{with_modular_daemons}
Requires:       %{name}-daemon-lock = %{version}-%{release}
Requires:       %{name}-daemon-log = %{version}-%{release}
Requires:       %{name}-daemon-plugin-lockd = %{version}-%{release}
%else
Requires:       %{name}-daemon = %{version}-%{release}
%endif
%if %{with_interface}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
%endif
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Recommends:     %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-qemu = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU emulators

This package does not contain files, it just requires the necessary packages.

%package daemon-lxc
Summary:        Server side daemon & driver required to run LXC guests
%if %{with_modular_daemons}
Requires:       %{name}-daemon-log = %{version}-%{release}
%else
Requires:       %{name}-daemon = %{version}-%{release}
%endif
%if %{with_interface}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
%endif
Requires:       %{name}-daemon-driver-lxc = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Recommends:     %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC

This package does not contain files, it just requires the necessary packages.

%package daemon-xen
Summary:        Server side daemon & driver required to run XEN guests
%if %{with_modular_daemons}
Requires:       %{name}-daemon-lock = %{version}-%{release}
Requires:       %{name}-daemon-plugin-lockd = %{version}-%{release}
%else
Requires:       %{name}-daemon = %{version}-%{release}
%endif
%if %{with_interface}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
%endif
Requires:       %{name}-daemon-driver-libxl = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN

This package does not contain files, it just requires the necessary packages.

%package daemon-vbox
Summary:        Server side daemon & driver required to run VirtualBox guests
%if ! %{with_modular_daemons}
Requires:       %{name}-daemon = %{version}-%{release}
%endif
%if %{with_interface}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
%endif
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Recommends:     %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       %{name}-daemon-driver-vbox = %{version}-%{release}
# Specify supported virtualbox API explicitly. See ./src/vbox
# Reference bsc#1017189
Requires:       virtualbox < 5.3

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox

This package does not contain files, it just requires the necessary packages.

%package client
Summary:        Client side utilities of the libvirt library
Requires:       %{name}-libs = %{version}-%{release}
Requires:       bash-completion >= 2.0

# Ensure smooth upgrades
Obsoletes:      libvirt-bash-completion < 7.3.0

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package client-qemu
Summary:        Additional client side utilities for QEMU
Requires:       %{name}-libs = %{version}-%{release}
Requires:       python3-libvirt-python >= 5.1.0

%description client-qemu
The additional client binaries are used to interact
with some QEMU specific features of libvirt.

%package libs
Summary:        Client side libraries for libvirt
# Not technically required, but makes 'out-of-box' config
# work correctly & doesn't have onerous dependencies
Requires:       cyrus-sasl-digestmd5

%description libs
Shared libraries for accessing the libvirt daemon.

%package devel
Summary:        Libraries, includes, etc. to compile with the libvirt library
Requires:       %{name}-libs = %{version}-%{release}
Suggests:       %{name}-doc = %{version}-%{release}
Requires:       pkg-config

%description devel
Include header files & development libraries for the libvirt C library.

%package daemon-plugin-sanlock
Summary:        Sanlock lock manager plugin for QEMU driver
Requires:       sanlock >= 2.4
# For virt-sanlock-cleanup require augeas
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-daemon-common = %{version}-%{release}
Requires:       augeas
Obsoletes:      %{name}-lock-sanlock < 9.0.0
Provides:       %{name}-lock-sanlock = %{version}-%{release}

%description daemon-plugin-sanlock
Includes the Sanlock lock manager plugin for the QEMU driver

%package -n wireshark-plugin-libvirt
Summary:        Wireshark plugin for libvirt RPC protocol
Requires:       %{name}-libs = %{version}-%{release}
Requires:       wireshark

%description -n wireshark-plugin-libvirt
Wireshark dissector plugin for better analysis of libvirt RPC traffic.

%package nss
Summary:        Libvirt plugin for Name Service Switch
Requires:       %{name}-daemon-driver-network = %{version}-%{release}

%description nss
libvirt plugin for NSS for translating domain names into IP addresses.

%package ssh-proxy
Summary:        Libvirt SSH proxy
Requires:       %{name}-libs = %{version}-%{release}

%description ssh-proxy
Allows SSH into domains via VSOCK without need for network.

%prep
%autosetup -p1

%build
%if %{with_qemu}
    %define arg_qemu -Ddriver_qemu=enabled
%else
    %define arg_qemu -Ddriver_qemu=disabled
%endif
%if %{with_openvz}
    %define arg_openvz -Ddriver_openvz=enabled
%else
    %define arg_openvz -Ddriver_openvz=disabled
%endif
%if %{with_lxc}
    %define arg_lxc -Ddriver_lxc=enabled
%else
    %define arg_lxc -Ddriver_lxc=disabled
%endif
%if %{with_vbox}
    %define arg_vbox -Ddriver_vbox=enabled
%else
    %define arg_vbox -Ddriver_vbox=disabled
%endif
%if %{with_esx}
    %define arg_esx -Ddriver_esx=enabled -Dcurl=enabled
%else
    %define arg_esx -Ddriver_esx=disabled -Dcurl=disabled
%endif
%if %{with_vmware}
    %define arg_vmware -Ddriver_vmware=enabled
%else
    %define arg_vmware -Ddriver_vmware=disabled
%endif
%if %{with_hyperv}
    %define arg_hyperv -Ddriver_hyperv=enabled -Dopenwsman=enabled
%else
    %define arg_hyperv -Ddriver_hyperv=disabled -Dopenwsman=disabled
%endif
%if %{with_libxl}
    %define arg_libxl -Ddriver_libxl=enabled
%else
    %define arg_libxl -Ddriver_libxl=disabled
%endif
%if %{with_interface}
    %define arg_interface -Ddriver_interface=enabled
    %define arg_netcontrol -Dnetcontrol=enabled
%else
    %define arg_interface -Ddriver_interface=disabled
    %define arg_netcontrol -Dnetcontrol=disabled
%endif
%if %{with_storage_rbd}
    %define arg_storage_rbd -Dstorage_rbd=enabled
%else
    %define arg_storage_rbd -Dstorage_rbd=disabled
%endif
%if %{with_storage_gluster}
    %define arg_storage_gluster -Dstorage_gluster=enabled -Dglusterfs=enabled
%else
    %define arg_storage_gluster -Dstorage_gluster=disabled -Dglusterfs=disabled
%endif
%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=enabled -Dlibiscsi=enabled
%else
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=disabled -Dlibiscsi=disabled
%endif
%if %{with_libssh}
    %define arg_libssh -Dlibssh=enabled
%else
    %define arg_libssh -Dlibssh=disabled
%endif
%if %{with_libssh2}
    %define arg_libssh2 -Dlibssh2=enabled
%else
    %define arg_libssh2 -Dlibssh2=disabled
%endif
%if %{with_modular_daemons}
    %define arg_remote_mode -Dremote_default_mode=direct
%else
    %define arg_remote_mode -Dremote_default_mode=legacy
%endif
%if %{with_numactl}
    %define arg_numactl -Dnumactl=enabled
%else
    %define arg_numactl -Dnumactl=disabled
%endif
%if %{with_numad}
    %define arg_numad -Dnumad=enabled
%else
    %define arg_numad -Dnumad=disabled
%endif
%if %{with_userfaultfd_sysctl}
    %define arg_userfaultfd_sysctl -Duserfaultfd_sysctl=enabled
%else
    %define arg_userfaultfd_sysctl -Duserfaultfd_sysctl=disabled
%endif
%if %{with_nbdkit}
    %define arg_nbdkit -Dnbdkit=enabled
%else
    %define arg_nbdkit -Dnbdkit=disabled
%endif
%if %{with_nbdkit_config_default}
    %define arg_nbdkit_config_default -Dnbdkit_config_default=enabled
%else
    %define arg_nbdkit_config_default -Dnbdkit_config_default=disabled
%endif
%if %{with_apparmor}
    %define arg_apparmor -Dapparmor=enabled -Dsecdriver_apparmor=enabled
    %define arg_apparmor_profiles -Dapparmor_profiles=enabled
%else
    %define arg_apparmor -Dapparmor=disabled -Dsecdriver_apparmor=disabled
    %define arg_apparmor_profiles -Dapparmor_profiles=disabled
%endif
%if %{with_sanlock}
    %define arg_sanlock -Dsanlock=enabled
%else
    %define arg_sanlock -Dsanlock=disabled
%endif
%if %{with_firewalld_zone}
    %define arg_firewalld_zone -Dfirewalld_zone=enabled
%else
    %define arg_firewalld_zone -Dfirewalld_zone=disabled
%endif
%if %{with_wireshark}
    %define arg_wireshark -Dwireshark_dissector=enabled
%else
    %define arg_wireshark -Dwireshark_dissector=disabled
%endif

%define arg_selinux_mount -Dselinux_mount="/selinux"

# UEFI firmwares
# For SLE15 SP2 (Leap 15.2) and newer, use firmware descriptor files from the
# firmware packages, otherwise define firmwares via configure option
%if ! (0%{?suse_version} > 1500 || 0%{?sle_version} > 150100)
    # x86_64 UEFI firmwares
    # To more closely resemble actual hardware, we use the firmwares with
    # embedded Microsoft keys
    #
    # The Windows HCK test requires a bigger variable store, so 4MB firmware
    # images have been introduced. They are advertised first and will be
    # used by default for new VM installations. The 2MB images are still
    # available for existing VMs, and can be selected for new installations
    # as well.
    LOADERS="/usr/share/qemu/ovmf-x86_64-ms-4m-code.bin:/usr/share/qemu/ovmf-x86_64-ms-4m-vars.bin"
    LOADERS="$LOADERS:/usr/share/qemu/ovmf-x86_64-ms-code.bin:/usr/share/qemu/ovmf-x86_64-ms-vars.bin"
    # aarch64 UEFI firmwares
    LOADERS="$LOADERS:/usr/share/qemu/aavmf-aarch64-code.bin:/usr/share/qemu/aavmf-aarch64-vars.bin"
    %define arg_loader_nvram -Dloader-nvram="$LOADERS"
%endif

# Macros for moving vendor provided configuration from /etc to /usr
%if 0%{?suse_version} > 1500
    %define logrotate_prefix %nil
    %define logrotate_dir %{_distconfdir}/logrotate.d
    # Prepare for migration to /usr/etc; save any old .rpmsave
    %define libvirt_logrotate_pre() \
        for sc in %{?*} ; do \
            test -f "%{_sysconfdir}/logrotate.d/${sc}.rpmsave" || continue ; \
            mv -v "%{_sysconfdir}/logrotate.d/${sc}.rpmsave" "%{_sysconfdir}/logrotate.d/${sc}.rpmsave.old" ; \
        done \
        %{nil}
    %define libvirt_logrotate_posttrans() \
        for sc in %{?*} ; do \
            test -f "%{_sysconfdir}/logrotate.d/${sc}.rpmsave" || continue ; \
            mv -v "%{_sysconfdir}/logrotate.d/${sc}.rpmsave" "%{_sysconfdir}/logrotate.d/${sc}" ; \
        done \
        %{nil}
%else
    %define logrotate_prefix %config(noreplace)
    %define logrotate_dir %{_sysconfdir}/logrotate.d
    %define libvirt_logrotate_pre() %nil
    %define libvirt_logrotate_posttrans() %nil
%endif

# The libvirt package has long redefined libexecdir. Stop the madness at SLE15.
# Factory and newer will use the product default for libexecdir
%if 0%{?suse_version} <= 1500
    %define _libexecdir %{_libdir}/%{name}
%endif

%meson \
           --libexecdir=%{_libexecdir} \
           -Drunstatedir=%{_rundir} \
           -Dunitdir=%{_unitdir} \
           -Dsysusersdir=%{_sysusersdir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           -Dsasl=enabled \
           -Dpolkit=enabled \
           -Ddriver_libvirtd=enabled \
           -Ddriver_remote=enabled \
           -Ddriver_test=enabled \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           -Ddriver_vz=disabled \
           -Ddriver_bhyve=disabled \
           -Ddriver_ch=disabled \
           %{?arg_remote_mode} \
           %{?arg_interface} \
           -Ddriver_network=enabled \
           -Dstorage_fs=enabled \
           -Dstorage_lvm=enabled \
           -Dstorage_iscsi=enabled \
           -Dstorage_scsi=enabled \
           -Dstorage_disk=enabled \
           -Dstorage_mpath=enabled \
           %{?arg_storage_rbd} \
           %{?arg_storage_gluster} \
           %{?arg_storage_iscsi_direct} \
           -Dstorage_zfs=disabled \
           -Dstorage_vstorage=disabled \
           %{?arg_numactl} \
           %{?arg_numad} \
           %{?arg_userfaultfd_sysctl} \
           %{?arg_nbdkit} \
           %{?arg_nbdkit_config_default} \
           -Dssh_proxy=enabled \
           -Dsysctl_config=enabled \
           -Dcapng=enabled \
           -Dfuse=enabled \
           -Dnetcf=disabled \
           %{?arg_netcontrol} \
           -Dselinux=enabled \
           %{?arg_selinux_mount} \
           %{?arg_apparmor} \
           %{?arg_apparmor_profiles} \
           -Dudev=enabled \
           -Djson_c=enabled \
           %{?arg_sanlock} \
           -Dlibpcap=enabled \
           -Dlibnl=enabled \
           -Daudit=enabled \
           -Ddtrace=enabled \
           -Dfirewalld=enabled \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           %{?arg_libssh} \
           %{?arg_libssh2} \
           -Dpm_utils=disabled \
           -Dnss=enabled \
           -Dqemu_user=%{qemu_user} \
           -Dqemu_group=%{qemu_group} \
           -Dqemu_moddir=%{qemu_moddir} \
           -Dqemu_datadir=%{qemu_datadir} \
           -Dexpensive_tests=enabled \
           %{?arg_loader_nvram} \
           -Dinit_script=systemd \
           -Dfirewall_backend_priority=%{firewall_backend_priority} \
           -Ddocs=enabled \
           -Dtests=enabled \
           -Drpath=disabled \
           -Dlogin_shell=disabled \
           -Dno_git=true \
          %{nil}

%meson_build

%install
%meson_install
# Remove currently unsupported locale(s)
for dir in %{buildroot}/usr/share/locale/*
do
  sdir=`echo $dir | sed "s|%{buildroot}||"`
  if test -d $sdir ; then continue ; fi
  rm -rfv "$dir"
done

%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}/%{logrotate_dir}
mv %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.lxc %{buildroot}/%{logrotate_dir}
mv %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.qemu %{buildroot}/%{logrotate_dir}
mv %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.libxl %{buildroot}/%{logrotate_dir}
mv %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd %{buildroot}/%{logrotate_dir}
%endif

mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}
%if %{with_qemu}
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/hooks
%endif
%find_lang %{name}
install -d -m 0755 %{buildroot}/%{_datadir}/%{name}/networks/
cp %{buildroot}/%{_sysconfdir}/%{name}/qemu/networks/default.xml \
   %{buildroot}/%{_datadir}/%{name}/networks/default.xml
rm -f %{buildroot}/%{_sysconfdir}/%{name}/qemu/networks/default.xml
rm -f %{buildroot}/%{_sysconfdir}/%{name}/qemu/networks/autostart/default.xml
%if ! %{with_lxc}
rm -f %{buildroot}/%{_sysconfdir}/%{name}/lxc.conf
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
rm -f %{buildroot}/%{logrotate_dir}/libvirtd.lxc
%endif
%if ! %{with_qemu}
rm -f %{buildroot}/%{_sysconfdir}/%{name}/qemu.conf
rm -f %{buildroot}/%{_sysconfdir}/apparmor.d/usr.sbin.virtqemud
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
rm -f %{buildroot}/%{logrotate_dir}/libvirtd.qemu
%endif
%if ! %{with_libxl}
rm -f %{buildroot}/%{_sysconfdir}/%{name}/libxl.conf
rm -f %{buildroot}/%{_sysconfdir}/apparmor.d/usr.sbin.virtxend
rm -f %{buildroot}/%{logrotate_dir}/libvirtd.libxl
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif
%if ! %{with_sanlock}
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

rm -f %{buildroot}/%{_sysusersdir}/libvirt.conf
rm -f %{buildroot}/%{_sysusersdir}/libvirt-qemu.conf
rm -f %{buildroot}/usr/lib/sysctl.d/60-libvirtd.conf

# Install firewall services for migration ports
mkdir -p %{buildroot}/%{_fwdefdir}
install -m 644 %{S:3} %{buildroot}/%{_fwdefdir}/libvirtd-relocation-server.xml

# Install supportconfig plugin
mkdir -p %{buildroot}/usr/lib/supportconfig/plugins
install -m 755 %{S:1} %{buildroot}/usr/lib/supportconfig/plugins/libvirt

# Install qemu hook script
%if %{with_qemu}
install -m 755 %{S:2} %{buildroot}/%{_sysconfdir}/%{name}/hooks/qemu
%endif

%ifarch %{power64} s390x x86_64
mv %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_probes-64.stp
%if %{with_qemu}
mv %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
%endif
%endif

%check
export VIR_TEST_DEBUG=1
%meson_test -t 5 --no-suite syntax-check

# For daemons with only UNIX sockets
%define libvirt_daemon_systemd_pre() %service_add_pre %1.socket %1-ro.socket %1-admin.socket %1.service
%define libvirt_daemon_systemd_post() %service_add_post %1.socket %1-ro.socket %1-admin.socket %1.service
%define libvirt_daemon_systemd_preun() %service_del_preun %1.service %1-ro.socket %1-admin.socket %1.socket
%define libvirt_daemon_systemd_postun() %service_del_postun_without_restart %1.service %1-ro.socket %1-admin.socket %1.socket
%define libvirt_daemon_systemd_postun_restart() %service_del_postun %1.service %1-ro.socket %1-admin.socket %1.socket

# For daemons with UNIX and INET sockets
%define libvirt_daemon_systemd_pre_inet() %service_add_pre %1.socket %1-ro.socket %1-admin.socket %1-tls.socket %1-tcp.socket %1.service
%define libvirt_daemon_systemd_post_inet() %service_add_post %1.socket %1-ro.socket %1-admin.socket %1-tls.socket %1-tcp.socket %1.service
%define libvirt_daemon_systemd_preun_inet() %service_del_preun %1.service %1-ro.socket %1-admin.socket %1-tls.socket %1-tcp.socket %1.socket
%define libvirt_daemon_systemd_postun_inet() %service_del_postun_without_restart %1.service %1-ro.socket %1-admin.socket %1-tls.socket %1-tcp.socket %1.socket
%define libvirt_daemon_systemd_postun_inet_restart() %service_del_postun %1.service %1-ro.socket %1-admin.socket %1-tls.socket %1-tcp.socket %1.socket

# For daemons with only UNIX sockets and no unprivileged read-only access
%define libvirt_daemon_systemd_pre_priv() %service_add_pre %1.socket %1-admin.socket %1.service
%define libvirt_daemon_systemd_post_priv() %service_add_post %1.socket %1-admin.socket %1.service
%define libvirt_daemon_systemd_preun_priv() %service_del_preun %1.service %1-admin.socket %1.socket
%define libvirt_daemon_systemd_postun_priv() %service_del_postun_without_restart %1.service %1-admin.socket %1.socket
%define libvirt_daemon_systemd_postun_priv_restart() %service_del_postun %1.service %1-admin.socket %1.socket

%pre daemon
%libvirt_daemon_systemd_pre_inet libvirtd
%libvirt_logrotate_pre libvirtd

%post daemon
%if %{with_apparmor}
%apparmor_reload /etc/apparmor.d/usr.sbin.libvirtd
%endif
%libvirt_daemon_systemd_post_inet libvirtd

%preun daemon
%libvirt_daemon_systemd_preun_inet libvirtd

%postun daemon
%libvirt_daemon_systemd_postun_inet libvirtd

%posttrans daemon
%libvirt_logrotate_posttrans libvirtd
# All connection drivers should be installed post transaction.
# Time to restart the daemon
test -f %{_sysconfdir}/sysconfig/services && \
  test -z "$DISABLE_RESTART_ON_UPDATE" && . %{_sysconfdir}/sysconfig/services
if test "$DISABLE_RESTART_ON_UPDATE" != yes && \
    test "$DISABLE_RESTART_ON_UPDATE" != 1; then
     %{_bindir}/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi

%pre daemon-common
%service_add_pre libvirt-guests

%post daemon-common
/sbin/ldconfig
%service_add_post libvirt-guests.service

%preun daemon-common
%service_del_preun libvirt-guests.service
if [ $1 = 0 ]; then
    rm -f /var/lib/%{name}/libvirt-guests
fi

%postun daemon-common
/sbin/ldconfig
%service_del_postun_without_restart libvirt-guests.service

%pre daemon-proxy
%libvirt_daemon_systemd_pre_inet virtproxyd

%post daemon-proxy
%libvirt_daemon_systemd_post_inet virtproxyd

%preun daemon-proxy
%libvirt_daemon_systemd_preun_inet virtproxyd

%postun daemon-proxy
%libvirt_daemon_systemd_postun_inet virtproxyd

%pre daemon-lock
%libvirt_daemon_systemd_pre_priv virtlockd

%post daemon-lock
%libvirt_daemon_systemd_post_priv virtlockd

%preun daemon-lock
%libvirt_daemon_systemd_preun_priv virtlockd

%postun daemon-lock
%libvirt_daemon_systemd_postun_priv virtlockd

%posttrans daemon-lock
# virtlockd must not be restarted, otherwise the locks it uses to protect
# VM resources would be lost. It is safe to re-exec.
%{_bindir}/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :

%pre daemon-log
%libvirt_daemon_systemd_pre_priv virtlogd

%post daemon-log
%libvirt_daemon_systemd_post_priv virtlogd

%preun daemon-log
%libvirt_daemon_systemd_preun_priv virtlogd

%postun daemon-log
%libvirt_daemon_systemd_postun_priv virtlogd

%posttrans daemon-log
# virtlogd must not be restarted since it manages logs from virtual machine
# consoles. It is safe to re-exec.
%{_bindir}/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :

%pre daemon-driver-network
%libvirt_daemon_systemd_pre virtnetworkd

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif
%libvirt_daemon_systemd_post virtnetworkd

%preun daemon-driver-network
%libvirt_daemon_systemd_preun virtnetworkd

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif
%libvirt_daemon_systemd_postun_restart virtnetworkd

%post daemon-config-network
# Install the default network if one doesn't exist
if test $1 -eq 1 && test ! -f %{_sysconfdir}/%{name}/qemu/networks/default.xml ; then
    cp %{_datadir}/%{name}/networks/default.xml %{_sysconfdir}/%{name}/qemu/networks/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/%{name}/qemu/networks/default.xml
fi

%pre daemon-driver-nwfilter
%libvirt_daemon_systemd_pre virtnwfilterd

%post daemon-driver-nwfilter
%libvirt_daemon_systemd_post virtnwfilterd

%preun daemon-driver-nwfilter
%libvirt_daemon_systemd_preun virtnwfilterd

%postun daemon-driver-nwfilter
%libvirt_daemon_systemd_postun_restart virtnwfilterd

%pre daemon-driver-storage-core
%libvirt_daemon_systemd_pre virtstoraged

%post daemon-driver-storage-core
%libvirt_daemon_systemd_post virtstoraged

%preun daemon-driver-storage-core
%libvirt_daemon_systemd_preun virtstoraged

%postun daemon-driver-storage-core
%libvirt_daemon_systemd_postun_restart virtstoraged

%pre daemon-driver-interface
%libvirt_daemon_systemd_pre virtinterfaced

%post daemon-driver-interface
%libvirt_daemon_systemd_post virtinterfaced

%preun daemon-driver-interface
%libvirt_daemon_systemd_preun virtinterfaced

%postun daemon-driver-interface
%libvirt_daemon_systemd_postun_restart virtinterfaced

%pre daemon-driver-nodedev
%libvirt_daemon_systemd_pre virtnodedevd

%post daemon-driver-nodedev
%libvirt_daemon_systemd_post virtnodedevd

%preun daemon-driver-nodedev
%libvirt_daemon_systemd_preun virtnodedevd

%postun daemon-driver-nodedev
%libvirt_daemon_systemd_postun_restart virtnodedevd

%pre daemon-driver-secret
%libvirt_daemon_systemd_pre virtsecretd

%post daemon-driver-secret
%libvirt_daemon_systemd_post virtsecretd

%preun daemon-driver-secret
%libvirt_daemon_systemd_preun virtsecretd

%postun daemon-driver-secret
%libvirt_daemon_systemd_postun_restart virtsecretd

%pre daemon-driver-qemu
%libvirt_daemon_systemd_pre virtqemud
%libvirt_logrotate_pre libvirtd.qemu

%post daemon-driver-qemu
%if %{with_apparmor}
%apparmor_reload /etc/apparmor.d/usr.sbin.virtqemud
%endif
%libvirt_daemon_systemd_post virtqemud

%preun daemon-driver-qemu
%libvirt_daemon_systemd_preun virtqemud

%postun daemon-driver-qemu
%libvirt_daemon_systemd_postun_restart virtqemud

%posttrans daemon-driver-qemu
%libvirt_logrotate_posttrans libvirtd.qemu

%pre daemon-driver-lxc
%libvirt_daemon_systemd_pre virtlxcd
%libvirt_logrotate_pre libvirtd.lxc

%post daemon-driver-lxc
%libvirt_daemon_systemd_post virtlxcd

%preun daemon-driver-lxc
%libvirt_daemon_systemd_preun virtlxcd

%postun daemon-driver-lxc
%libvirt_daemon_systemd_postun_restart virtlxcd

%posttrans daemon-driver-lxc
%libvirt_logrotate_posttrans libvirtd.lxc

%pre daemon-driver-libxl
%libvirt_daemon_systemd_pre virtxend
%libvirt_logrotate_pre libvirtd.libxl

%post daemon-driver-libxl
%if %{with_apparmor}
%apparmor_reload /etc/apparmor.d/usr.sbin.virtxend
%endif
%libvirt_daemon_systemd_post virtxend

%preun daemon-driver-libxl
%libvirt_daemon_systemd_preun virtxend

%postun daemon-driver-libxl
%libvirt_daemon_systemd_postun_restart virtxend

%posttrans daemon-driver-libxl
%libvirt_logrotate_posttrans libvirtd.libxl

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post nss -p /sbin/ldconfig

%postun nss -p /sbin/ldconfig

%files

%files daemon
%{_sbindir}/libvirtd
%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%config(noreplace) %{_sysconfdir}/%{name}/libvirtd.conf
%if %{with_apparmor}
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.libvirtd
%endif
%{logrotate_prefix} %{logrotate_dir}/libvirtd
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses/
%dir %{_datadir}/augeas/lenses/tests/
%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%doc %{_mandir}/man8/libvirtd.8*

%files daemon-common
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/connection-driver/
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/hooks
%{_unitdir}/libvirt-guests.service
%{_unitdir}/virt-guest-shutdown.target
%{_bindir}/virt-admin
%{_bindir}/virt-host-validate
%dir %{_sysconfdir}/sasl2/
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%{_datadir}/bash-completion/completions/virt-admin
%dir %{_localstatedir}/lib/%{name}/
%dir %attr(0755, root, root) %{_localstatedir}/lib/%{name}/
%dir %attr(0711, root, root) %{_localstatedir}/lib/%{name}/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/%{name}/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/%{name}/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/%{name}/
%dir %attr(0700, root, root) %{_localstatedir}/log/%{name}/
%if %{with_polkit_rules}
%{_datadir}/polkit-1/rules.d/50-libvirt.rules
%endif
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper
%attr(0755, root, root) %{_bindir}/virt-ssh-helper
%doc %{_mandir}/man1/virt-admin.1*
%doc %{_mandir}/man1/virt-host-validate.1*
%doc %{_mandir}/man8/virt-ssh-helper.8*
%doc %{_mandir}/man8/libvirt-guests.8*
%if %{with_apparmor}
%dir %{_sysconfdir}/apparmor.d/
%dir %{_sysconfdir}/apparmor.d/abstractions/
%dir %{_sysconfdir}/apparmor.d/%{name}/
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.lib.libvirt.virt-aa-helper
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-qemu
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/%{name}/TEMPLATE.lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/%{name}/TEMPLATE.qemu
%{_libexecdir}/virt-aa-helper
%endif
%dir %{_prefix}/lib/firewalld/
%dir %{_fwdefdir}
%{_fwdefdir}/libvirtd-relocation-server.xml
%dir /usr/lib/supportconfig/
%dir /usr/lib/supportconfig/plugins/
/usr/lib/supportconfig/plugins/libvirt

%files daemon-lock
%{_sbindir}/virtlockd
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/%{name}/virtlockd.conf
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%doc %{_mandir}/man8/virtlockd.8*

%files daemon-plugin-lockd
%dir %attr(0755, root, root) %{_libdir}/%{name}/lock-driver
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/lockd.so

%files daemon-log
%{_sbindir}/virtlogd
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%config(noreplace) %{_sysconfdir}/%{name}/virtlogd.conf
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%doc %{_mandir}/man8/virtlogd.8*

%files daemon-proxy
%{_sbindir}/virtproxyd
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%config(noreplace) %{_sysconfdir}/%{name}/virtproxyd.conf
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%doc %{_mandir}/man8/virtproxyd.8*

%if %{with_qemu}
%files daemon-hooks
%{_sysconfdir}/%{name}/hooks/qemu
%endif

%files daemon-config-network
%dir %{_datadir}/%{name}/networks/
%{_datadir}/%{name}/networks/default.xml

%files daemon-config-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/nwfilter/
%config %{_sysconfdir}/%{name}/nwfilter/*.xml

%if %{with_interface}
%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/%{name}/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so
%doc %{_mandir}/man8/virtinterfaced.8*
%endif

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/%{name}/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%config(noreplace) %{_sysconfdir}/%{name}/network.conf
%{_datadir}/augeas/lenses/libvirtd_network.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_network.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/qemu/networks/autostart/
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/%{name}/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so
%if %{with_firewalld_zone}
%dir %{_prefix}/lib/firewalld/zones/
%dir %{_prefix}/lib/firewalld/policies/
%{_prefix}/lib/firewalld/zones/libvirt.xml
%{_prefix}/lib/firewalld/zones/libvirt-routed.xml
%{_prefix}/lib/firewalld/policies/libvirt-routed-in.xml
%{_prefix}/lib/firewalld/policies/libvirt-routed-out.xml
%{_prefix}/lib/firewalld/policies/libvirt-to-host.xml
%endif
%doc %{_mandir}/man8/virtnetworkd.8*

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/%{name}/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so
%doc %{_mandir}/man8/virtnodedevd.8*

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/%{name}/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/nwfilter/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so
%doc %{_mandir}/man8/virtnwfilterd.8*

%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/%{name}/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%{_sbindir}/virtsecretd
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/secrets/
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so
%doc %{_mandir}/man8/virtsecretd.8*

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/%{name}/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%{_sbindir}/virtstoraged
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/storage/
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/storage/autostart/
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%dir %{_libdir}/%{name}/storage-backend/
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%doc %{_mandir}/man8/virtstoraged.8*

%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%dir %{_libdir}/%{name}/storage-file/
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%if %{with_qemu}

%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/%{name}/virtqemud.conf
%if %{with_apparmor}
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.virtqemud
%endif
%if %{with_userfaultfd_sysctl}
%config(noreplace) %{_prefix}/lib/sysctl.d/60-qemu-postcopy-migration.conf
%endif
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%{_sbindir}/virtqemud
%config(noreplace) %{_sysconfdir}/%{name}/qemu.conf
%config(noreplace) %{_sysconfdir}/%{name}/qemu-lockd.conf
%{logrotate_prefix} %{logrotate_dir}/libvirtd.qemu
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/qemu/autostart/
%dir %attr(0751, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/%{name}/qemu/
%dir %attr(0750, root, root) %{_localstatedir}/cache/%{name}/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/%{name}/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/%{name}/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/%{name}/
%dir %attr(0730, tss, tss) %{_localstatedir}/log/swtpm/%{name}/qemu/
%{_bindir}/virt-qemu-run
%doc %{_mandir}/man1/virt-qemu-run.1*
%doc %{_mandir}/man8/virtqemud.8*
%endif

%if %{with_lxc}

%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/%{name}/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/lxc/
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/lxc/autostart/
%config(noreplace) %{_sysconfdir}/%{name}/lxc.conf
%{logrotate_prefix} %{logrotate_dir}/libvirtd.lxc
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/%{name}/lxc/
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%{_bindir}/virt-create-rootfs
%doc %{_mandir}/man1/virt-create-rootfs.1*
%doc %{_mandir}/man8/virtlxcd.8*
%endif

%if %{with_libxl}

%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/%{name}/virtxend.conf
%if %{with_apparmor}
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.virtxend
%endif
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/%{name}/libxl.conf
%{logrotate_prefix} %{logrotate_dir}/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/%{name}/libxl-lockd.conf
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/libxl/
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/libxl/autostart/
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/libxl/dump/
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/libxl/save/
%dir %attr(0700, root, root) %{_localstatedir}/log/%{name}/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%doc %{_mandir}/man8/virtxend.8*
%endif

%if %{with_vbox}

%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/%{name}/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%doc %{_mandir}/man8/virtvboxd.8*
%endif

%if %{with_qemu}

%files daemon-qemu
%endif

%if %{with_lxc}

%files daemon-lxc
%endif

%if %{with_libxl}

%files daemon-xen
%endif

%if %{with_vbox}

%files daemon-vbox
%endif

%files client
%doc %{_mandir}/man1/virsh.1*
%doc %{_mandir}/man1/virt-xml-validate.1*
%doc %{_mandir}/man1/virt-pki-query-dn.1*
%doc %{_mandir}/man1/virt-pki-validate.1*
%doc %{_mandir}/man7/virkey*.7*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-query-dn
%{_bindir}/virt-pki-validate
%{_datadir}/bash-completion/completions/virsh

%if %{with_qemu}
%files client-qemu
%doc %{_mandir}/man1/virt-qemu-qmp-proxy.1*
%{_mandir}/man1/virt-qemu-sev-validate.1*
%{_bindir}/virt-qemu-qmp-proxy
%{_bindir}/virt-qemu-sev-validate
%endif

%files libs -f %{name}.lang
%dir %attr(0700, root, root) %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/libvirt.conf
%config(noreplace) %{_sysconfdir}/%{name}/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/schemas/
%dir %{_datadir}/%{name}/cpu_map/
%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif
%{_datadir}/%{name}/schemas/*.rng
%{_datadir}/%{name}/cpu_map/*.xml
%{_datadir}/%{name}/test-screenshot.png

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%{_includedir}/%{name}
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc
%dir %{_datadir}/%{name}/api/
%{_datadir}/%{name}/api/libvirt-api.xml
%{_datadir}/%{name}/api/libvirt-admin-api.xml
%{_datadir}/%{name}/api/libvirt-qemu-api.xml
%{_datadir}/%{name}/api/libvirt-lxc-api.xml

%files doc
%doc NEWS.rst README.rst
%license COPYING COPYING.LESSER
%dir %{_datadir}/doc/%{name}/
%doc %{_datadir}/doc/%{name}/*

%if %{with_sanlock}

%files daemon-plugin-sanlock
%doc %{_mandir}/man8/virt-sanlock-cleanup.8*
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/%{name}/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/%{name}/libxl-sanlock.conf
    %endif
%dir %{_libdir}/%{name}/lock-driver/
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/sanlock.so
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses/
%dir %{_datadir}/augeas/lenses/tests/
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0700, root, sanlock) %{_localstatedir}/lib/%{name}/sanlock/
%{_sbindir}/virt-sanlock-cleanup
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%if %{with_wireshark}

%files -n wireshark-plugin-libvirt
%dir %{wireshark_plugindir}/
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%files ssh-proxy
%dir %{_sysconfdir}/ssh/
%dir %{_sysconfdir}/ssh/ssh_config.d/
%config(noreplace) %{_sysconfdir}/ssh/ssh_config.d/30-libvirt-ssh-proxy.conf
%{_libexecdir}/libvirt-ssh-proxy

%changelog
* Thu Apr 10 2025 James Fehlig <jfehlig@suse.com>
- cpu_map: Install Ampere-1 ARM CPU models
  bsc#1240922
* Tue Apr  1 2025 James Fehlig <jfehlig@suse.com>
- Update to libvirt 11.2.0
  - jsc#PED-6556, jsc#PED-11466
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v11-2-0-2025-04-01
* Fri Mar 21 2025 James Fehlig <jfehlig@suse.com>
- spec: Disable rbd storage driver for SLFO
  bsc#1239836
* Mon Mar  3 2025 James Fehlig <jfehlig@suse.com>
- Update to libvirt 11.1.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v11-1-0-2025-03-03
* Mon Feb 24 2025 James Fehlig <jfehlig@suse.com>
- Adjust downstream patch 'Add virt-create-rootfs utility' to only
  install virt-create-rootfs when building the LXC driver
* Tue Feb 18 2025 James Fehlig <jfehlig@suse.com>
- spec: Add note about packages with no files
  bsc#1237228
* Mon Feb  3 2025 James Fehlig <jfehlig@suse.com>
- spec: Change hooks dependency from libvirtd to the qemu driver
  bsc#1236378
* Thu Jan 16 2025 James Fehlig <jfehlig@suse.com>
- Update to libvirt 11.0.0
  - jsc#PED-5899, jsc#PED-8909, jsc#PED-9543, jsc#PED-9854,
    jsc#PED-9855
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v11-0-0-2025-01-15
* Wed Jan  8 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Convert from tar_scm to obs_scm: allow OBS internal data
  structure to be more efficient by using .obscpio files
* Mon Jan  6 2025 James Fehlig <jfehlig@suse.com>
- security: apparmor: Fix probing of apparmor availability on the
  VM host when using modular daemons
  bsc#1235079
* Fri Jan  3 2025 James Fehlig <jfehlig@suse.com>
- tests: Extend EOY check in virtimetest
  boo#1234995
* Thu Dec 12 2024 James Fehlig <jfehlig@suse.com>
- qemu: tpm: do not update profile name for transient domains
  Fixes a crash when starting a transient domain
  boo#1234438
* Mon Dec  2 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.10.0
  - jsc#PED-8909, jsc#PED-9543, jsc#PED-9854, jsc#PED-9855
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-10-0-2024-12-02
* Mon Nov  4 2024 James Fehlig <jfehlig@suse.com>
- json: do not call json_tokener_free with NULL
  Fixes potential SEGV in libvirt-nss module
  boo#1232726
* Fri Nov  1 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.9.0
  - jsc#PED-8909, jsc#PED-9854, jsc#PED-9855
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-9-0-2024-11-01
* Tue Oct 22 2024 James Fehlig <jfehlig@suse.com>
- spec: Use default_firewall_backend prjconf setting
- spec: Loosen nwfilter dependency
  boo#1231798
* Tue Oct  1 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.8.0
  - libvirt-daemon-driver-storage-core: Change dependency on
    nfs-utils from Requires to Recommends
  - Switch from YAJL to json-c for JSON parsing and formatting
  - jsc#PED-8909
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-8-0-2024-10-01
* Tue Sep  3 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.7.0
  - CVE-2024-8235, bsc#1230024
  - Unconditionally disable building the interface driver
  - Remove SysV rc* compatibility symlinks
  - jsc#PED-8909
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-7-0-2024-09-02
* Mon Aug  5 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.6.0
  - jsc#PED-8909
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-6-0-2024-08-05
* Mon Jul  1 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.5.0
  - Introduce SEV-SNP support
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-5-0-2024-07-01
* Mon Jun  3 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.4.0
  - network: use nftables to setup virtual network firewall rules
    boo#1201510
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-4-0-2024-06-03
* Wed May  8 2024 James Fehlig <jfehlig@suse.com>
- CVE-2024-4418: rpc: ensure temporary GSource is removed from
  client event loop
  bsc#1223849
- libxl: Fix domxml-to-native conversion
  bsc#1222584
* Thu May  2 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.3.0
  - bsc#1220714
  - bsc#1226492
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-3-0-2024-05-02
* Fri Apr 12 2024 James Fehlig <jfehlig@suse.com>
- spec: Add 'Requires: netcat-openbsd' to libvirt-daemon-common
  boo#1222100
* Tue Apr  2 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.2.0
  - CVE-2024-2494
  - bsc#1221879
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-2-0-2024-04-02
* Thu Mar 21 2024 James Fehlig <jfehlig@suse.com>
- CVE-2024-2494: remote: check for negative array lengths before
  allocation
  bsc#1221815
* Tue Mar  5 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.1.0
  - CVE-2024-1441
    bsc#1221237
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-1-0-2024-03-01
* Thu Feb 22 2024 James Fehlig <jfehlig@suse.com>
- Add SLE virtiofsd path to apparmor profiles
  bsc#1219772
* Wed Feb 21 2024 James Fehlig <jfehlig@suse.com>
- Fix return value when libnetcontrol fails to initialize
  boo#1219986
* Thu Jan 25 2024 James Fehlig <jfehlig@suse.com>
- Replace temporary build fix with upstream equivalent
  bsc#1218823
* Wed Jan 17 2024 James Fehlig <jfehlig@suse.com>
- Add temporary build fix for ppc64le
  bsc#1218823
* Tue Jan 16 2024 James Fehlig <jfehlig@suse.com>
- Update to libvirt 10.0.0
  - jsc#PED-3226, jsc#PED-3279, jsc#PED-4931, jsc#PED-5432,
    jsc#PED-6851
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v10-0-0-2024-01-15
* Wed Dec 20 2023 James Fehlig <jfehlig@suse.com>
- apparmor: Add capabilities for PCI passthrough to virtxend profile
  bsc#1216656
* Fri Dec  8 2023 James Fehlig <jfehlig@suse.com>
- Add upstream commit 1a2f33cb59 to fix memory corruption in the
  remote driver
* Fri Dec  1 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.10.0
  - jsc#PED-3226, jsc#PED-3279, jsc#PED-4931, jsc#PED-5432,
    jsc#PED-6851
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-10-0-2023-12-01
- spec: Drop 'Requires: libvirt-daemon-proxy' from the
  libvirt-daemon-{qemu,xen,lxc,vbox} subpackages
* Wed Nov  1 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.9.0
  - jsc#PED-3279, jsc#PED-4931, jsc#PED-5432
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-9-0-2023-11-01
* Wed Oct 18 2023 James Fehlig <jfehlig@suse.com>
- supportconfig: Adapt plugin to modern supportconfig
* Tue Oct 17 2023 James Fehlig <jfehlig@suse.com>
- spec: Disable use of libnbd/nbdkit
  bsc#1216274
* Mon Oct  2 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.8.0 (jsc#PED-3279)
  - bsc#1215708
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-8-0-2023-10-02
* Wed Sep  6 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.7.0 (jsc#PED-3279)
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-7-0-2023-09-01
- spec: Unconditionally enable modular daemons (jsc#PED-6303)
- spec: Disable ESX hypervisor driver in ALP-based products
- spec: Disable glusterfs storage backend in ALP-based products
* Fri Aug 25 2023 James Fehlig <jfehlig@suse.com>
- spec: Disable Apparmor support in ALP-based products
- spec: Disable interface driver in ALP-based products
- spec: Disable sanlock plugin in ALP-based products
- spec: Disable numad support in ALP-based products
* Thu Aug 17 2023 James Fehlig <jfehlig@suse.com>
- spec: Disable Xen driver in ALP-based products
* Fri Aug  4 2023 James Fehlig <jfehlig@suse.com>
- Add upstream commit 3d2f3fb72b to fix max file limits in systemd
  services
* Wed Aug  2 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.6.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-6-0-2023-08-01
  - jsc#PED-3725
- spec: Unconditionally enable modular daemons
- spec: Remove logic handling package upgrade from old libvirtd
* Thu Jul 20 2023 James Fehlig <jfehlig@suse.com>
- CVE-2023-3750: storage: Fix returning of locked objects from
  'virStoragePoolObjListSearch'
  bsc#1213447
* Thu Jul 13 2023 James Fehlig <jfehlig@suse.com>
- libxl: Improve handling of errors across migration phases
  bsc#1213186
- apparmor: Support local overrides in all profiles and abstractions
  spec: Don't replace /etc/apparmor.d/<profile> on package upgrade
  spec: No longer package empty /etc/apparmor.d/local/* files
  bsc#1211472
* Thu Jul  6 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.5.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-5-0-2023-07-03
  - Add upstream commit 5f7f6ceb47 to fix builds on Leap 15.x
  - Drop downstream commit adding SUSE-specific migration
    parameters
* Tue Jun 13 2023 James Fehlig <jfehlig@suse.com>
- spec: Don't move apparmor profiles to modular daemon subpackages
* Wed Jun  7 2023 James Fehlig <jfehlig@suse.com>
- apparmor: Add support for local profile customizations
  spec: Replace /etc/apparmor.d/<libvirt-profile> on package upgrade
  bsc#1211472
- supportconfig: Modular daemon improvements
* Fri Jun  2 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.4.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-4-0-2023-06-01
* Tue May  2 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.3.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-3-0-2023-05-02
  - CVE-2023-2700
    bsc#1211390
  - boo#1210654
* Wed Apr 12 2023 James Fehlig <jfehlig@suse.com>
- qemu: Fix potential crash during driver cleanup
  bsc#1209861
* Mon Apr 10 2023 James Fehlig <jfehlig@suse.com>
- service: Remove unnecessary auth token from github URL
* Mon Apr  3 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.2.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-2-0-2023-04-01
  - Move to a more git-centric packaging workflow using tar_scm
    instead of download_files
  - New source README.packaging.txt
  - Remove now unused signature file and libvirt.keyring
  - Patches now maintained in git
    libxl-dom-reset.patch,
    network-don-t-use-dhcp-authoritative-on-static-netwo.patch,
    0001-util-Don-t-spawn-pkttyagent-when-stdin-is-not-a-tty.patch,
    libvirt-power8-models.patch,
    ppc64le-canonical-name.patch,
    libxl-set-migration-constraints.patch,
    libxl-set-cach-mode.patch,
    0001-libxl-add-support-for-BlockResize-API.patch,
    suse-libvirtd-disable-tls.patch,
    suse-libvirt-guests-service.patch,
    suse-qemu-conf.patch,
    suse-qemu-ovmf-paths.patch,
    libxl-support-block-script.patch,
    qemu-apparmor-screenshot.patch,
    libvirt-suse-netcontrol.patch,
    lxc-wait-after-eth-del.patch,
    suse-libxl-disable-autoballoon.patch,
    suse-xen-ovmf-paths.patch,
    virt-create-rootfs.patch,
    suse-fix-lxc-container-init.patch
  - Remove old, unused SUSEfirewall2 config file
    libvirtd-relocation-server.fw
  - Dropped patches:
    4959490e-support-SUSE-edk2-firmware-paths.patch,
    bf3be5b7-libxl-Support-custom-firmware-path.patch,
    705525cb-libxl-Support-custom-firmware-path-conversion.patch,
* Fri Mar 10 2023 James Fehlig <jfehlig@suse.com>
- libxl: Support custom firmware paths
  bf3be5b7-libxl-Support-custom-firmware-path.patch,
  705525cb-libxl-Support-custom-firmware-path-conversion.patch
  bsc#1209161
- spec: Move ovmf dependency to correct package
* Thu Mar  2 2023 James Fehlig <jfehlig@suse.com>
- Apparmor: Add support for SUSE edk2 firmware paths
  4959490e-support-SUSE-edk2-firmware-paths.patch
  boo#1208567
* Wed Mar  1 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.1.0
  - bsc#1210666
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-1-0-2023-03-01
  - spec: Remove obsolete Groups tag
  - spec: Integrate upstream spec file changes that split the
    libvirt-daemon package, allowing more modular, customized
    installations
  - spec: New subpackages libvirt-daemon-common, libvirt-daemon-lock,
    libvirt-daemon-log, libvirt-daemon-proxy, and
    libvirt-daemon-plugin-lockd
  - spec: Renamed subpackage libvirt-lock-sanlock to
    libvirt-daemon-plugin-sanlock
  - Dropped patches:
    ef482951-apparmor-Allow-umount-dev.patch,
    d6a8b9ee-qemu-Fix-managed-no-when-creating-ethdev.patch,
    c3f16cea-qemu-cleanup-label-on-umount-failure.patch,
    697c16e3-qemu_process-better-debug-message.patch,
    5155ab4b-qemu_namespace-nested-mounts-when-umount.patch
* Wed Feb  8 2023 James Fehlig <jfehlig@suse.com>
- qemu: Fix umount of /dev in VM private namespace
  c3f16cea-qemu-cleanup-label-on-umount-failure.patch,
  697c16e3-qemu_process-better-debug-message.patch,
  5155ab4b-qemu_namespace-nested-mounts-when-umount.patch
  boo#1207889
* Tue Jan 17 2023 James Fehlig <jfehlig@suse.com>
- Update to libvirt 9.0.0
  - jsc#PED-620
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v9-0-0-2023-01-16
  - Added patches:
    ef482951-apparmor-Allow-umount-dev.patch,
    d6a8b9ee-qemu-Fix-managed-no-when-creating-ethdev.patch
* Tue Dec 27 2022 James Fehlig <jfehlig@suse.com>
- Fix lxc container initialization with systemd and hybrid cgroups
  suse-fix-lxc-container-init.patch
  boo#1183247
* Thu Dec  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.10.0
  - jsc#PED-1472
  - New virt-qemu-sev-validate utility for validating the
    measurement reported for a domain launched with AMD SEV
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-10-0-2022-12-01
  - Dropped patches:
    f81ee7b5-tests-Fix-libxlxml2domconfigtest.patch
* Fri Nov 11 2022 James Fehlig <jfehlig@suse.com>
- tests: Fix libxlxml2domconfigtest
  f81ee7b5-tests-Fix-libxlxml2domconfigtest.patch
  bsc#1205204
* Tue Nov  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.9.0
  - jsc#PED-620, jsc#PED-1540
  - Add support for modular daemons to the supportconfig plugin
  - New subpackage libvirt-client-qemu providing client utilities
    to interact with QEMU-specific features of libvirt
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-9-0-2022-11-01
* Wed Oct  5 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.8.0
  - jsc#PED-620, jsc#PED-1540
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-8-0-2022-10-03
- spec: Switch from monolithic to modular daemons for Factory
* Tue Sep 27 2022 James Fehlig <jfehlig@suse.com>
- spec: Only drop redefinition of libexecdir on Factory and newer
  bsc#1203775
* Thu Sep 15 2022 Stefan Schubert <schubi@suse.com>
- Migration to /usr/etc: Saving user changed configuration files
  in /etc and restoring them while an RPM update.
* Thu Sep  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.7.0
  - jsc#PED-620, jsc#PED-1540
  - bsc#1202630
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-7-0-2022-09-01
  - Dropped patches:
    9493c9b7-lxc-containter-fix-build-with-glibc-2.36.patch,
    c0d9adf2-virfile-Fix-build-with-glibc-2.36.patch
* Wed Aug 24 2022 James Fehlig <jfehlig@suse.com>
- spec: Suppress error messages about nonexistent or unreadable
  files from grep
* Fri Aug 19 2022 James Fehlig <jfehlig@suse.com>
- spec: Place 'Requires:' on compression binaries instead of their
  associated packages
  boo#1202569
* Mon Aug 15 2022 James Fehlig <jfehlig@suse.com>
- Fix build with glibc 2.36
  9493c9b7-lxc-containter-fix-build-with-glibc-2.36.patch,
  c0d9adf2-virfile-Fix-build-with-glibc-2.36.patch
  boo#1202321
* Tue Aug  2 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.6.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-6-0-2022-08-01
* Tue Jul 19 2022 James Fehlig <jfehlig@suse.com>
- spec: Don't redefine libexecdir
  boo#1201565
* Tue Jul  5 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.5.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-5-0-2022-07-01
  - Drop downstream-only lxc patches. They received little interest
    upstream, are difficult to maintain, and are no longer required
    by the requester (SLE):
    0001-Extract-stats-functions-from-the-qemu-driver.patch,
    0002-lxc-implement-connectGetAllDomainStats.patch
* Fri Jun 24 2022 James Fehlig <jfehlig@suse.com>
- spec: Include aarch64 in the list of architectures that 'Require'
  dmidecode
  boo#1196087
* Tue Jun 21 2022 James Fehlig <jfehlig@suse.com>
- spec: Move logrotate config files from /etc/logrotate.d to
  /usr/etc/logrotate.d
* Tue Jun 14 2022 James Fehlig <jfehlig@suse.com>
- spec: Closer alignment with upstream spec file, including
  enabling more unit tests
* Wed Jun  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.4.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-4-0-2022-06-01
* Mon May  9 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.3.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-3-0-2022-05-02
* Fri Apr  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.2.0
  - CVE-2022-0897
    bsc#1197636
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-2-0-2022-04-01
  - Dropped patches:
    823a62ec-qemu-fix-undefine-crash.patch
* Thu Mar  3 2022 James Fehlig <jfehlig@suse.com>
- qemu: Fix segmentation fault in qemuDomainUndefineFlags
  823a62ec-qemu-fix-undefine-crash.patch
* Tue Mar  1 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.1.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-1-0-2022-03-01
  - Dropped patches:
    3be5ba11-libvirt-guests-install.patch,
    16172741-libvirt-guests-manpage.patch,
    8eb44616-remove-sysconfig-files.patch,
    31e937fb-libxl-save-lock-indicator.patch,
    105dace2-revert-virProcessGetStatInfo.patch,
    e0241f33-libxl-mark-allocated-graphics-ports.patch,
    18ec405a-libxl-release-graphics-ports.patch,
    76deb656-qemu-fix-snapshot-revert.patch,
    454b927d-libxl-fix-dom-restore.patch
* Fri Feb 18 2022 James Fehlig <jfehlig@suse.com>
- libxl: Fix libvirtd crash on domain restore
  454b927d-libxl-fix-dom-restore.patch
  bsc#1196115
* Tue Feb  8 2022 James Fehlig <jfehlig@suse.com>
- qemu: fix inactive snapshot revert
  76deb656-qemu-fix-snapshot-revert.patch
  boo#1195690
* Mon Feb  7 2022 James Fehlig <jfehlig@suse.com>
- libxl: Mark auto-allocated graphics ports to used on reconnect
  e0241f33-libxl-mark-allocated-graphics-ports.patch
- libxl: Release all auto-allocated graphics ports
  18ec405a-libxl-release-graphics-ports.patch
  bsc#1191668
* Wed Jan 26 2022 James Fehlig <jfehlig@suse.com>
- Revert commit 938382b60a since it changes semantics on some
  public APIs
  105dace2-revert-virProcessGetStatInfo.patch
* Tue Jan 25 2022 James Fehlig <jfehlig@suse.com>
- libxl: Add lock process indicator to saved VM state
  31e937fb-libxl-save-lock-indicator.patch
  bsc#1191668
* Tue Jan 18 2022 James Fehlig <jfehlig@suse.com>
- sysconfig files have not been distributed for many months. Add
  upstream patches that improve documentation and moves service
  default settings to the associated systemd service file.
  3be5ba11-libvirt-guests-install.patch,
  16172741-libvirt-guests-manpage.patch,
  8eb44616-remove-sysconfig-files.patch
* Tue Jan 18 2022 James Fehlig <jfehlig@suse.com>
- Update to libvirt 8.0.0
  - CVE-2021-4147
  - bsc#1191511
  - jsc#SLE-11435, jsc#SLE-18354
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v8-0-0-2022-01-14
  - Dropped patches:
    23b51d7b-libxl-disable-death-event.patch,
    a4e6fba0-libxl-rename-threadinfo-struct.patch,
    e4f7589a-libxl-shutdown-thread-name.patch,
    b9a5faea-libxl-handle-death-thread.patch,
    5c5df531-libxl-search-domid-in-thread.patch,
    a7a03324-libxl-protect-logger-access.patch,
    cbae4eaa-libxl-add-domainGetMessages.patch
* Tue Dec 14 2021 James Fehlig <jfehlig@suse.com>
- libxl: Implement domainGetMessages API
  cbae4eaa-libxl-add-domainGetMessages.patch
  bsc##1193623
* Mon Dec 13 2021 James Fehlig <jfehlig@suse.com>
- Don't spawn pkttyagent when stdin is not a tty
  0001-util-Don-t-spawn-pkttyagent-when-stdin-is-not-a-tty.patch
  bsc#1193574
* Thu Dec  2 2021 James Fehlig <jfehlig@suse.com>
- libxl: Fix libvirtd deadlocks and segfaults
  23b51d7b-libxl-disable-death-event.patch,
  a4e6fba0-libxl-rename-threadinfo-struct.patch,
  e4f7589a-libxl-shutdown-thread-name.patch,
  b9a5faea-libxl-handle-death-thread.patch,
  5c5df531-libxl-search-domid-in-thread.patch,
  a7a03324-libxl-protect-logger-access.patch
  bsc#1191668, bsc#1192017
* Thu Dec  2 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.10.0
  - jsc#SLE-18260, jsc#SLE-19264
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html#v7-10-0-2021-12-01
* Fri Nov 19 2021 James Fehlig <jfehlig@suse.com>
- virt-create-rootfs: Fix repository URLs
  Updated virt-create-rootfs.patch
  boo#1192318
* Wed Nov 17 2021 James Fehlig <jfehlig@suse.com>
- spec: Weaken apparmor-abstractions dependency to Recommends
  bsc#1192119
* Thu Nov  4 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.9.0
  - jsc#SLE-19264
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    3f9c1a4b-fix-host-validate-sev.patch,
    2703b0b5-qemu-dont-report-eof.patch,
    1b9ce05c-lxc-fix-cgroupV1.patch
- Include collection of active VM config files in the
  supportconfig plugin
* Mon Oct 18 2021 James Fehlig <jfehlig@suse.com>
- supportconfig: Use systemctl command 'is-active' instead of
  'is-enabled' when checking if libvirtd is active
* Fri Oct 15 2021 James Fehlig <jfehlig@suse.com>
- Drop 'Requires: libvirt-daemon-driver-lxc' from the main libvirt
  package
  jsc#SLE-22296
* Fri Oct 15 2021 James Fehlig <jfehlig@suse.com>
- qemu: Do not report eof when processing monitor IO
  2703b0b5-qemu-dont-report-eof.patch
  bsc#1190917
* Fri Oct  8 2021 James Fehlig <jfehlig@suse.com>
- lxc: controller: Fix container launch on cgroup v1
  1b9ce05c-lxc-fix-cgroupV1.patch
  boo#1183247
* Thu Oct  7 2021 James Fehlig <jfehlig@suse.com>
- tools: Fix virt-host-validate SEV detection
  3f9c1a4b-fix-host-validate-sev.patch
  boo#1188715
* Fri Oct  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.8.0
  - jsc#SLE-18260
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    b75a16ae-libxl-improve-die-id.patch,
    65fab900-libxl-fix-driver-reload.patch,
    51eb680b-libxl-dont-autostart-on-reload.patch
* Thu Sep 23 2021 James Fehlig <jfehlig@suse.com>
- spec: Fix hangs during package update
  bsc#1177902, bsc#1190693
- spec: Don't add --timeout arg to /etc/sysconfig/libvirtd when
  running in traditional mode without socket activation
  bsc#1190695
* Tue Sep 14 2021 James Fehlig <jfehlig@suse.com>
- libxl: Improve reporting of die_id in capabilities
  b75a16ae-libxl-improve-die-id.patch
  boo#1190493
- libxl: Fix driver reload
  65fab900-libxl-fix-driver-reload.patch,
  51eb680b-libxl-dont-autostart-on-reload.patch
  bsc#1190420
* Wed Sep  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.7.0
  - jsc#SLE-18446
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
* Wed Aug 11 2021 James Fehlig <jfehlig@suse.com>
- supportconfig: When checking for installed hypervisor drivers,
  use the libvirtr-daemon-driver-<hypervisor> package instead of
  libvirt-daemon-<hypervisor>. The latter are not required packages
  for a functioning hypervisor driver.
* Mon Aug  2 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.6.0
  - storage_driver: Unlock object on ACL fail in storagePoolLookupByTargetPath
    CVE-2021-3667
    bsc#1188843
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    de1e0ae0-lockd-no-error-if-lockspace.patch,
    f58349c9-qemu-storage-migration.patch
* Tue Jul 27 2021 James Fehlig <jfehlig@suse.com>
- spec: Re-exec'ing virt{lock,log}d in posttrans was mistakenly
  dropped in a previous change. Add it back.
* Thu Jul 22 2021 James Fehlig <jfehlig@suse.com>
- libxl: ovmf now provides only one firmware for Xen. The firmware
  is named ovmf-x86_64-xen-4m.bin in the SUSE ovmf package. Adjust
  the upstream default firmware path to match the SUSE name.
- packaging: To improve maintainability, rename suse-ovmf-paths.patch
  to suse-qemu-ovmf-paths.patch and suse-xen-ovmf-loaders.patch to
  suse-xen-ovmf-paths.patch
* Fri Jul 16 2021 James Fehlig <jfehlig@suse.com>
- spec: Don't forcibly remove '--listen' arg from
  /etc/sysconfig/libvirtd. Add '--timeout 120' if '--listen' is
  not specified.
  bsc#1188232
- spec: Remove the sysconfig fillup files for the various daemons
  - Dropped patches:
    suse-libvirtd-sysconfig-settings.patch,
    suse-virtlockd-sysconfig-settings.patch,
    suse-virtlogd-sysconfig-settings.patch
* Fri Jul 16 2021 James Fehlig <jfehlig@suse.com>
- spec: Add bash-completion dependency to libvirt-daemon and
  libvirt-client. It was mistakenly dropped when
  libvirt-bash-completion was merged into the daemon and client
  subpackages
* Fri Jul 16 2021 James Fehlig <jfehlig@suse.com>
- qemu: Use correct flag constant for enabling storage migration
  f58349c9-qemu-storage-migration.patch
  bsc#1188171
* Wed Jul  7 2021 James Fehlig <jfehlig@suse.com>
- virtlockd: Don't report error if lockspace exists
  de1e0ae0-lockd-no-error-if-lockspace.patch
  bsc#1184253
* Thu Jul  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.5.0
  - security: Fix insecure sVirt label generation - CVE-2021-3631
    bsc#1187871
  - apparmor: Permit new capabilities required by libvirtd
    boo#1186888
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    suse-apparmor-libnl-paths.patch
- supportconfig plugin improvements
* Mon Jun 21 2021 Mel Gorman <mgorman@suse.de>
- Suggest numad package instead of requiring it. numad is not
  required for libvirt daemon to run, it does not support the
  cgroup2 API and it has been superseded by the kernel NUMA
  balancer which is enabled by default.
  bsc#1184722
* Tue Jun  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.4.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    ee890f25-libxl-mock-funcs.patch
* Mon May  3 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.3.0
  - libvirt-admin package merged with libvirt-daemon
  - libvirt-bash-completion package merged with libvirt-client and
    libvirt-daemon packages
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    suse-bump-xen-version.patch
  - Added patches:
    ee890f25-libxl-mock-funcs.patch
* Thu Apr  1 2021 James Fehlig <jfehlig@suse.com>
- spec: Remove use of %%fdupes since it was only acting on files
  that should be excluded
  bsc#1184293
- Remove bogus comment from /etc/sysconfig/libvirtd
  bsc#1184253
* Thu Apr  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.2.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    ee3dc2c2-libxl-default-pcistub-name.patch,
    6b8e9613-avoid-use-after-free.patch,
    eab7ae6b-fix-array-access.patch,
    c363f03e-virnetdaemon-intro-virNetDaemonQuitExecRestart.patch,
    ccc6dd8f-fix-exec-restart.patch
* Thu Mar 18 2021 James Fehlig <jfehlig@suse.com>
- spec: Fix exec-restart of virtlockd and virtlogd on package upgrade
  bsc#1183411
* Wed Mar 17 2021 James Fehlig <jfehlig@suse.com>
- spec: Move netcat-openbsd requirement from the libs to the daemon
  subpackage. It is only needed by the daemon and introduces an
  unneeded dependency for users of libvirt-libs.
* Fri Mar 12 2021 James Fehlig <jfehlig@suse.com>
- virtlockd, virtlogd: Fix exec-restart
  6b8e9613-avoid-use-after-free.patch,
  eab7ae6b-fix-array-access.patch,
  c363f03e-virnetdaemon-intro-virNetDaemonQuitExecRestart.patch,
  ccc6dd8f-fix-exec-restart.patch
  bsc#1183411
* Wed Mar 10 2021 James Fehlig <jfehlig@suse.com>
- Replace libxl-default-pcistub-name.patch with upstream variant
  ee3dc2c2-libxl-default-pcistub-name.patch
* Mon Mar  1 2021 James Fehlig <jfehlig@suse.com>
- libxl: Fix node device detach when driver unspecified
  libxl-default-pcistub-name.patch
  boo#1182885
- spec: Bump minimum glib version to 2.56
* Mon Mar  1 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.1.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - bsc#1182367, bsc#1182515
  - Dropped patches:
    32c5e432-revert-f035f53b.patch,
    e3d60f76-fix-socket-file-gen.patch,
    7cf60006-qemu-swtpm-aarch64.patch,
    afb823fc-qemu-validate-swtpm.patch,
    8a4b8996-conf-move-virDomainCheckVirtioOptions.patch,
    c05f0066-conf-drop-empty-virDomainNetDefPostParse.patch,
    19d4e467-conf-improve-virDomainVirtioOptionsCheckABIStability.patch,
    bd112c9e-qemu-virtio-options-vsock.patch
* Sat Feb 20 2021 James Fehlig <jfehlig@suse.com>
- Remove old initscript patching of libvirt-guests.sh
  Modified suse-libvirt-guests-service.patch
  boo#1182494
* Wed Feb 17 2021 James Fehlig <jfehlig@suse.com>
- qemu: Add virtio related options to vsock
  8a4b8996-conf-move-virDomainCheckVirtioOptions.patch,
  c05f0066-conf-drop-empty-virDomainNetDefPostParse.patch,
  19d4e467-conf-improve-virDomainVirtioOptionsCheckABIStability.patch,
  bd112c9e-qemu-virtio-options-vsock.patch
  bsc#1182365
* Thu Feb 11 2021 James Fehlig <jfehlig@suse.com>
- qemu: Fix swtpm device with aarch64
  7cf60006-qemu-swtpm-aarch64.patch,
  afb823fc-qemu-validate-swtpm.patch
  bsc#1181893
* Tue Feb  9 2021 James Fehlig <jfehlig@suse.com>
- build: Fix generation of virtproxyd socket files
  e3d60f76-fix-socket-file-gen.patch
  boo#1181838
* Fri Jan 29 2021 James Fehlig <jfehlig@suse.com>
- Revert "Add libvirtd dependency to virt-guest-shutdown.target"
  32c5e432-revert-f035f53b.patch
  bsc#1177902
* Fri Jan 29 2021 James Fehlig <jfehlig@suse.com>
- spec: Enable the libvirt firewalld zone in SLE >= 15 SP3
  jsc#SLE-17336
* Tue Jan 19 2021 James Fehlig <jfehlig@suse.com>
- Update to libvirt 7.0.0
  - jsc#SLE-15860
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    0d05d51b-apparmor-lxc-fix.patch,
    cf4e7e62-lxc-def-secmodel.patch,
    0ddebdb4-qemu-snapshot-deletion.patch
* Mon Jan  4 2021 olaf@aepfle.de
- Update libxl-set-migration-constraints.patch
  Remove code which handled --max_factor. The total amount of
  transferred data is no indicator to trigger the final stop+copy.
  This should have been removed during upgrade to Xen 4.7.
  Reduce default value of --max_iters from 5 to 2.
  The workload within domU will continue to produce dirty pages.
  It is unreasonable to expect any slowdown during migration.
  Now there is one initial copy of all memory, one instead of four
  iteration for dirty memory, and a final copy iteration prior move.
* Thu Dec 17 2020 James Fehlig <jfehlig@suse.com>
- qemu: Fix logic bug in inactive snapshot deletion
  0ddebdb4-qemu-snapshot-deletion.patch
  boo#1180049
* Wed Dec  9 2020 James Fehlig <jfehlig@suse.com>
- spec: Enable mdevctl support in the nodedev driver for SLE15 SP3
  jsc#SLE-15861, bsc#1179770
* Mon Dec  7 2020 James Fehlig <jfehlig@suse.com>
- apparmor: Allow lxc processes to receive signals from libvirt
  lxc: Set default security model in XML parser config
  0d05d51b-apparmor-lxc-fix.patch, cf4e7e62-lxc-def-secmodel.patch
  bsc#1179735
* Tue Dec  1 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.10.0
  - jsc#SLE-13688
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    f035f53b-virt-guest-shutdown.patch
* Fri Nov 13 2020 James Fehlig <jfehlig@suse.com>
- spec: Remove creation of libvirt group and add Requires to the
  libvirt group created with GID 108 by the system-group-libvirt
  package.
  jsc#SLE-11629
* Wed Nov 11 2020 James Fehlig <jfehlig@suse.com>
- spec: Add 'Requires: bash-completion' to the
  libvirt-bash-completion subpackage
  bsc#1178498
* Mon Nov  9 2020 James Fehlig <jfehlig@suse.com>
- Add libvirtd dependency to virt-guest-shutdown.target
  f035f53b-virt-guest-shutdown.patch
  boo#1175914, bsc#1177902
* Tue Nov  3 2020 Franck Bui <fbui@suse.com>
- Replace  '%%service_del_postun -n' with '%%service_del_postun_without_restart'
  '-n' is deprecated and will be removed in the future.
* Mon Nov  2 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.9.0
  - jsc#SLE-13688, jsc#SLE-16754
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
* Mon Nov  2 2020 ohering@suse.de
- bsc#1177950 - adjust help for --max_iters, default is 5
  libxl-set-migration-constraints.patch
* Wed Oct 28 2020 Franck Bui <fbui@suse.com>
- Drop use of $DISABLE_RESTART_ON_UPDATE in %%postrans
  Testing "$DISABLE_RESTART_ON_UPDATE != yes" had no effect since its
  value is supposed to be read from /etc/sysconfig/services.
* Wed Oct 14 2020 James Fehlig <jfehlig@suse.com>
- Fix 'make check' with all downstream patches applied. Some
  patches touch config files and needed the corresponding augeaus
  test files updated.
  Updated patches:
  suse-libvirtd-disable-tls.patch,
  suse-qemu-conf.patch,
  suse-ovmf-paths.patch,
  suse-libxl-disable-autoballoon.patch
  boo#1175574
* Thu Oct  1 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.8.0
  - jsc#SLE-12684, jsc#SLE-15861
  - bsc#1174955 (CVE-2020-15708)
  - bsc#1177155 (CVE-2020-25637)
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    2ad009ea-qemu-check-modules-dir.patch,
    8abd1ffe-qemu-tolerate-non-existent-files.patch,
    4a72b76b-qemu-namespace-memleak-fix.patch
* Thu Sep 10 2020 James Fehlig <jfehlig@suse.com>
- spec: Increase test timeout to account for slower test execution
  on some architectures
* Thu Sep 10 2020 James Fehlig <jfehlig@suse.com>
- qemu: Tolerate non-existing files such as /dev/kvm when
  populating domain private namespace
  8abd1ffe-qemu-tolerate-non-existent-files.patch,
  4a72b76b-qemu-namespace-memleak-fix.patch
  boo#1176380
* Wed Sep  2 2020 James Fehlig <jfehlig@suse.com>
- spec: Enable the same hypervisor drivers for openSUSE and SLE
  jsc#SLE-11772
- spec: Enable the same storage drivers for openSUSE and SLE
  jsc#SLE-11877
* Tue Sep  1 2020 James Fehlig <jfehlig@suse.com>
- qemu: Reprobe capabilities if the qemu modules directory changes
  2ad009ea-qemu-check-modules-dir.patch
  boo#1175320
* Tue Sep  1 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.7.0
  - jsc#SLE-14253, jsc#SLE-15159
  - CVE-2020-14339
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    2edd63a0-fix-virFileSetCOW-logic.patch,
    82bb167f-dont-cache-devmapper-major.patch,
    feb8564a-handle-no-devmapper.patch,
    53d9af1e-ignore-devmapper-open-errors.patch,
    support-managed-pci-xen-driver.patch,
    disable-multipath-pr-tests.patch
* Wed Aug 19 2020 James Fehlig <jfehlig@suse.com>
- virdevmapper: Handle kernel without device-mapper support
  82bb167f-dont-cache-devmapper-major.patch,
  feb8564a-handle-no-devmapper.patch,
  53d9af1e-ignore-devmapper-open-errors.patch
  boo#1175465
* Tue Aug 18 2020 James Fehlig <jfehlig@suse.com>
- util: Fix logic in virFileSetCOW
  2edd63a0-fix-virFileSetCOW-logic.patch
  boo#1175463
* Tue Aug  4 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.6.0
  - CVE-2020-14339
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
* Mon Jul  6 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.5.0
  - The node device driver now supports creating mediated devices
    using the mdevctl utility
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    ec07aad8-libxl-normalize-mac-addr.patch
* Wed Jun  3 2020 James Fehlig <jfehlig@suse.com>
- libxl: Normalize MAC address in device conf on netdev hotplug
  ec07aad8-libxl-normalize-mac-addr.patch
  bsc#1172052
* Tue Jun  2 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.4.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    d677de9d-libxl-fix-driver-name-check.patch,
    d218a9c2-libxl-xen-driver-tables.patch,
    836ea91d-libxl-xenlight-internal.patch,
    57687260-xen-doc-improvements.patch
* Wed May  6 2020 James Fehlig <jfehlig@suse.com>
- Xen: Fix connection when host uses modular daemons
  d677de9d-libxl-fix-driver-name-check.patch,
  d218a9c2-libxl-xen-driver-tables.patch,
  836ea91d-libxl-xenlight-internal.patch,
  57687260-xen-doc-improvements.patch
  boo#1171113
* Wed May  6 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.3.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    88011ed2-libxl-driver-crash-fix.patch,
    8e669b38-conf-add-event-channels.patch,
    a93f55c5-libxl-add-event-channels.patch,
    967f4eeb-xenconfig-event-channels.patch,
    93b15ba0-qemu-fix-hang-in-p2p-xbzrle-compression-parallel-mig.patch,
    b7d6648d-conf-add-e820-host.patch,
    5749395b-libxl-e820-host.patch,
    f3ef7daf-xenconfig-e820-host.patch,
    34077c1b-tests-check-e820-host.patch,
    fadbaa23-conf-add-passthrough.patch,
    9529e007-libxl-passthrough.patch,
    9cb8bc6f-xenconfig-refactor-features.patch,
    b523e225-xenconfig-passthrough.patch,
    bed32525-tests-check-passthrough.patch
* Tue Apr 21 2020 James Fehlig <jfehlig@suse.com>
- libxl: Add support for 'passthrough' and 'e820_host' settings
  b7d6648d-conf-add-e820-host.patch,
  5749395b-libxl-e820-host.patch,
  f3ef7daf-xenconfig-e820-host.patch,
  34077c1b-tests-check-e820-host.patch,
  fadbaa23-conf-add-passthrough.patch,
  9529e007-libxl-passthrough.patch,
  9cb8bc6f-xenconfig-refactor-features.patch,
  b523e225-xenconfig-passthrough.patch,
  bed32525-tests-check-passthrough.patch
  bsc#1167217
* Fri Apr 17 2020 Lin Ma <lma@suse.com>
- qemu: fix hang in p2p + xbzrle compression + parallel migration
  93b15ba0-qemu-fix-hang-in-p2p-xbzrle-compression-parallel-mig.patch
  bsc#1161159
* Thu Apr  9 2020 James Fehlig <jfehlig@suse.com>
- libxl: Add support for max event channels with maxEventChannel
  attribute on the xenbus controller
  8e669b38-conf-add-event-channels.patch,
  a93f55c5-libxl-add-event-channels.patch,
  967f4eeb-xenconfig-event-channels.patch
  bsc#1168767
* Mon Apr  6 2020 James Fehlig <jfehlig@suse.com>
- libxl: fix crash when initializing driver
  88011ed2-libxl-driver-crash-fix.patch
* Fri Apr  3 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.2.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - CVE-2020-10701
    bsc#1168680
  - Dropped patches:
    a30078cb-qemu-create-mp-target.patch,
    aeb909bf-qemu-multipath-fix.patch
  - Added patch:
    disable-multipath-pr-tests.patch
* Thu Mar 19 2020 James Fehlig <jfehlig@suse.com>
- libxl: Bump minimum supported Xen version to 4.9, allowing use
  of newer libxl APIs for retrieving memory statistics
  suse-bump-xen-version.patch
  bsc#1157490, bsc#1167007
* Tue Mar 17 2020 James Fehlig <jfehlig@suse.com>
- qemu: Create multipath targets for PRs
  a30078cb-qemu-create-mp-target.patch,
  aeb909bf-qemu-multipath-fix.patch
  bsc#1161883
* Mon Mar 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Xen is not built for armv7 anymore, so do not use it for armv7
* Thu Mar  5 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.1.0
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - CVE-2020-12430
    bsc#1170765
  - Dropped patches:
    6c1dddaf-libxl-shutdown-inhibit.patch,
    849052ec-libxl-support-credit2.patch,
    72ed254b-drop-exec-perms-bashcompletion.patch,
    e092daac-prohib-parallel-tunneled-mig.patch,
    ae9e6c2a-qemu-allow-cond-format-probe.patch
* Tue Mar  3 2020 James Fehlig <jfehlig@suse.com>
- qemu: Allow format probing under special circumstances
  ae9e6c2a-qemu-allow-cond-format-probe.patch
  bsc#1165588
* Wed Feb  5 2020 James Fehlig <jfehlig@suse.com>
- xen: Fix the list of supported ovmf firmwares
  suse-xen-ovmf-loaders.patch
  bsc#1159793
* Mon Feb  3 2020 James Fehlig <jfehlig@suse.com>
- lib: Prohibit parallel connections with tunneled migration
  e092daac-prohib-parallel-tunneled-mig.patch
  jsc#SLE-6998
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig((lib)?udev) instead of (lib)?udev: allow
  OBS to shortcut through -mini flavors.
* Thu Jan 30 2020 James Fehlig <jfehlig@suse.com>
- spec: Fix several rpmlint warnings
  72ed254b-drop-exec-perms-bashcompletion.patch
* Thu Jan 30 2020 James Fehlig <jfehlig@suse.com>
- xen: Support setting credit2 scheduler parameters
  849052ec-libxl-support-credit2.patch
  bsc#1162160
* Wed Jan 29 2020 James Fehlig <jfehlig@suse.com>
- xen: Inhibit libvirtd shutdown when domains are running
  6c1dddaf-libxl-shutdown-inhibit.patch
  bsc#1157100
* Wed Jan 15 2020 James Fehlig <jfehlig@suse.com>
- Update to libvirt 6.0.0
  - jsc#SLE-6997, jsc#SLE-6998
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    0a65cba4-news-fix.patch 07aaced4-Add-TAA-No.patch,
    f411b7ef6-Add-TSX-CTRL.patch, 50d7465f-qemu-firmware1.patch,
    57f9067c-qemu-firmware2.patch, 7c5264d2-qemu-firmware3.patch,
    8e1804f9-qemu-firmware4.patch, 8fcee478-qemu-firmware5.patch
* Thu Jan  9 2020 James Fehlig <jfehlig@suse.com>
- qemu: Fix firmware auto detection
  50d7465f-qemu-firmware1.patch, 57f9067c-qemu-firmware2.patch,
  7c5264d2-qemu-firmware3.patch, 8e1804f9-qemu-firmware4.patch,
  8fcee478-qemu-firmware5.patch
  boo#1157378, bsc#1159796
* Thu Dec 19 2019 James Fehlig <jfehlig@suse.com>
- CVE-2019-11135: Add TSX_CTRL and TAA_NO bits for
  IA32_ARCH_CAPABILITIES MSR
  07aaced4-Add-TAA-No.patch, f411b7ef6-Add-TSX-CTRL.patch
  bsc#1152505
* Tue Dec 10 2019 Cédric Bosdonnat <cbosdonnat@suse.com>
- virt-create-rootfs: add SLE 15 and SLE 12 service packs support
  bsc#1154093
* Mon Dec  2 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.10.0
  - bsc#1157149
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    2552752f-libxl-fix-lock-manager-lock-ordering.patch
  - Added patches:
    0a65cba4-news-fix.patch
* Wed Nov 27 2019 James Fehlig <jfehlig@suse.com>
- spec: Enable 'libvirt' firewalld zone for firewalld >= 0.7.0
  boo#1157766
* Thu Nov 14 2019 James Fehlig <jfehlig@suse.com>
- libxl: Fix lock manager lock ordering
  2552752f-libxl-fix-lock-manager-lock-ordering.patch
  bsc#1145774
* Tue Nov 12 2019 James Fehlig <jfehlig@suse.com>
- spec: Forcibly remove '--listen' option from LIBVIRTD_ARGS in
  /etc/sysconfig/libvirtd since it is incompatible with socket
  activation. Also add '--timeout' option for consistency with
  upstream.
  boo#1156161
* Mon Nov 11 2019 James Fehlig <jfehlig@suse.com>
- Enable automatic firmware seletction and add the new smm
  flavor to the build-time firmware list
  jsc#SLE-6997
* Wed Nov  6 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.9.0
  - jsc#SLE-7440
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
* Tue Oct  8 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.8.0
  - bsc#1149100
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
* Thu Sep  5 2019 James Fehlig <jfehlig@suse.com>
- Add apparmor-abstractions as a required package for daemon
  bsc#1142992
* Wed Sep  4 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.7.0
  - Experimental split of libvirtd into separate daemons
  - bsc#1145440, bsc#1145586
  - Many incremental improvements and bug fixes, see
    https://libvirt.org/news.html
  - Dropped patches:
    93c1d5fe-network-fix-ability-to-use-openvswitch-with-vlans.patch,
    blockcopy-check-dst-identical-device.patch,
    suse-libvirtd-service-xen.patch
* Thu Aug 15 2019 Martin Wilck <mwilck@suse.com>
- network: fix ability to use openvswitch with vlans (bsc#1145651)
  - Added patch:
    93c1d5fe-network-fix-ability-to-use-openvswitch-with-vlans.patch
* Mon Aug  5 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.6.0
  - Enable proper use of systemd socket	activation with libvirtd
  - bsc#1133719
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    xen-pv-cdrom.patch, xen-sxpr-disk-type.patch
- qemu: fix default value of security_default_confined
  Updated suse-qemu-conf.patch
  bsc#1143871
* Tue Jul  2 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.5.0
  - CVE-2019-10161, CVE-2019-10166, CVE-2019-10167, CVE-2019-10168
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    aed6a032-CVE-2019-10161.patch,
    db0b7845-CVE-2019-10166.patch,
    8afa68ba-CVE-2019-10167.patch,
    bf6c2830-CVE-2019-10168.patch
* Thu Jun 20 2019 Jim Fehlig <jfehlig@suse.com>
- api: disallow virConnect*HypervisorCPU,
  virConnectGetDomainCapabilities, virDomainManagedSaveDefineXML,
  and virDomainSaveImageGetXMLDesc on read-only connections
  aed6a032-CVE-2019-10161.patch, db0b7845-CVE-2019-10166.patch,
  8afa68ba-CVE-2019-10167.patch, bf6c2830-CVE-2019-10168.patch
  CVE-2019-10161, CVE-2019-10166, CVE-2019-10167, CVE-2019-10168
  bsc#1138301, bsc#1138302, bsc#1138303, bsc#1138305
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Drop systemd BuildRequires: there is already pkgconfig(systemd)
  present, which is the same package.
* Mon Jun  3 2019 Jim Fehlig <jfehlig@suse.com>
- Update to libvirt 5.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    5cd9db3a-cputest-add-data-E3-1225-v5.patch,
    538d8735-cpu_map-Define-md-clear-CPUID-bit.patch,
    96f41cd7-admin-reject-clients.patch,
    f111e094-locking-restrict-sockets-to-mode-0600.patch,
    e37bd65f-logging-restrict-sockets-to-mode-0600.patch,
    76b420d0-build-libqemutestdriver-lto-fix.patch
* Thu May 30 2019 James Fehlig <jfehlig@suse.com>
- build: fix linking libqemutestdriver with LTO enabled
  76b420d0-build-libqemutestdriver-lto-fix.patch
  boo#1133253
* Thu May 30 2019 Martin Liška <mliska@suse.cz>
- Use %%make_build in order to provide verbose output.
* Thu May 23 2019 Jim Fehlig <jfehlig@suse.com>
- spec: add systemd-container dependency to qemu and lxc drivers
  bsc#1136109
* Tue May 21 2019 James Fehlig <jfehlig@suse.com>
- admin: reject clients unless their UID matches the server UID
  CVE-2019-10132
  96f41cd7-admin-reject-clients.patch,
  f111e094-locking-restrict-sockets-to-mode-0600.patch,
  e37bd65f-logging-restrict-sockets-to-mode-0600.patch
  bsc#1134348
* Mon May 20 2019 James Fehlig <jfehlig@suse.com>
- cpu_map: add cpu feature md-clear. CVE-2018-12126,
  CVE-2018-12127, CVE-2018-12130, CVE-2019-11091
  5cd9db3a-cputest-add-data-E3-1225-v5.patch,
  538d8735-cpu_map-Define-md-clear-CPUID-bit.patch
  bsc#1111331, bsc#1135273
* Wed May  8 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    ff376c62-tests-fix-mocking-stat-lstat.patch,
    ebe9c6ea-qemu-firmware-dirent.patch,
    2a07c990-api-CVE-2019-3886.patch,
    ae076bb4-remote-CVE-2019-3886.patch,
    f66f70ac-snapshot-fix-use-after-free.patch,
    89237d53-conf-expose-virDomainSCSIDriveAddressIsUsed.patch,
    ee2c5ef3-test-scsi-disk.patch,
    ddc72f99-qemu-check-dup-drive-address.patch,
    22dc3e94-revert-f1d65853.patch
* Thu Apr 25 2019 Jim Fehlig <jfehlig@suse.com>
- Fix build with LTO enabled
  Adjusted support-managed-pci-xen-driver.patch
  boo#1133253
* Fri Apr 19 2019 James Fehlig <jfehlig@suse.com>
- qemu: fix CDROM media change when using virDomainAttachDevice
  89237d53-conf-expose-virDomainSCSIDriveAddressIsUsed.patch,
  ee2c5ef3-test-scsi-disk.patch,
  ddc72f99-qemu-check-dup-drive-address.patch,
  22dc3e94-revert-f1d65853.patch
  boo#1132127
* Thu Apr 11 2019 James Fehlig <jfehlig@suse.com>
- Fix and re-enable snapshot tests
  f66f70ac-snapshot-fix-use-after-free.patch
* Fri Apr  5 2019 James Fehlig <jfehlig@suse.com>
- CVE-2019-3886: disallow virDomainGetHostname and virDomainGetTime
  for read-only connections and users
  2a07c990-api-CVE-2019-3886.patch,
  ae076bb4-remote-CVE-2019-3886.patch
  bsc#1131595
- spec: BuildRequires rpcgen since ae076bb4-remote-CVE-2019-3886.patch
  touches remote_protocol.x
* Wed Apr  3 2019 Jim Fehlig <jfehlig@suse.com>
- Update to libvirt 5.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    4ec3cf9a-apparmor-rules.patch,
    f38ef0fa-no-RDMA-check.patch,
    411cdaf8-apparmor-check-profile-name.patch,
    696239ba-qemu-fix-query-cpus-fast.patch,
    09eb1ae0-conf-add-xenbus-controller.patch,
    fb059757-libxl-add-xenbus-controller.patch,
    ec5a1191-libxl-support-max-grant-frames.patch,
    5a64c202-xenconfig-support-max-grant-frames.patch
  - Added patches:
    ff376c62-tests-fix-mocking-stat-lstat.patch,
    ebe9c6ea-qemu-firmware-dirent.patch
* Thu Mar 21 2019 James Fehlig <jfehlig@suse.com>
- apparmor: reintroduce upstream lxc mount rules
  Drop apparmor-no-mount.patch
  bsc#1130129
* Fri Mar 15 2019 James Fehlig <jfehlig@suse.com>
- supportconfig: collect rotated logs in /var/log/libvirt/*
  Modified libvirt-supportconfig
  bsc#1124667
* Wed Mar 13 2019 James Fehlig <jfehlig@suse.com>
- hook: encode incoming XML to UTF-8 before passing to lxml etree
  fromstring method
  Modifed suse-qemu-domain-hook.py
  boo#1123642
* Wed Mar 13 2019 James Fehlig <jfehlig@suse.com>
- libxl: change autoballooning default to disabled
  suse-libxl-disable-autoballoon.patch
  jsc#SLE-3059
* Wed Mar 13 2019 James Fehlig <jfehlig@suse.com>
- conf: add new 'xenbus' controller type
  09eb1ae0-conf-add-xenbus-controller.patch
- libxl: support Xen's max_grant_frames setting with maxGrantFrames
  attribute on the xenbus controller
  fb059757-libxl-add-xenbus-controller.patch,
  ec5a1191-libxl-support-max-grant-frames.patch,
  5a64c202-xenconfig-support-max-grant-frames.patch
  bsc#1126325
* Wed Mar 13 2019 James Fehlig <jfehlig@suse.com>
- Replace patches with upstream variants
  Old:
  0001-apparmor-Check-libvirtd-profile-status-by-name.patch,
  0001-qemu-Fix-query-cpus-fast-target-architecture-detecti.patch
  New:
  411cdaf8-apparmor-check-profile-name.patch,
  696239ba-qemu-fix-query-cpus-fast.patch
* Mon Mar 11 2019 James Fehlig <jfehlig@suse.com>
-  util: skip RDMA detection for non-PCI network devices
  f38ef0fa-no-RDMA-check.patch
  bsc#1112182
* Wed Mar  6 2019 James Fehlig <jfehlig@suse.com>
- qemu: s390: show correct CPU status after guest crash
  0001-qemu-Fix-query-cpus-fast-target-architecture-detecti.patch
  bsc#1127841
* Wed Mar  6 2019 James Fehlig <jfehlig@suse.com>
- apparmor: fix more fallout from changing libvirtd profile to a
  named profile
  4ec3cf9a-apparmor-rules.patch,
  0001-apparmor-Check-libvirtd-profile-status-by-name.patch
  boo#1125841
* Mon Mar  4 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.1.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    11c8aca9-libxl-set-mem-after-balloon.patch,
    70c2933d-apparmor-named-profiles.patch,
    a3ab6d42-apparmor-conv-libvirtd-named-profile.patch,
    b6440119-qemu-conf-sev.patch,
    a404ac34-qemu-cgroup-sev.patch,
    6fd4c8f8-qemu-domain-sev.patch,
    17f6a257-security-dac-sev.patch,
    a2d3dea9-qemu-caps-dac-override-sev.patch,
    620d9dd5-qemu-no-dac-override-nonroot.patch
  - jsc#SLE-3887, jsc#SLE-4480, jsc#SLE-4577
* Wed Feb 27 2019 jfehlig@suse.com
- spec: disable VirtualBox driver
* Tue Feb 19 2019 James Fehlig <jfehlig@suse.com>
- qemu: don't use CAP_DAC_OVERRIDE capability if non-root
  620d9dd5-qemu-no-dac-override-nonroot.patch
  boo#1125665
* Fri Feb  8 2019 James Fehlig <jfehlig@suse.com>
- qemu: fix issues related to restricted permissions on /dev/sev
  b6440119-qemu-conf-sev.patch, a404ac34-qemu-cgroup-sev.patch,
  6fd4c8f8-qemu-domain-sev.patch, 17f6a257-security-dac-sev.patch,
  a2d3dea9-qemu-caps-dac-override-sev.patch
  bsc#1124842
* Wed Jan 23 2019 James Fehlig <jfehlig@suse.com>
- apparmor: add support for named profiles and convert libvirtd
  profile to a named profile
  70c2933d-apparmor-named-profiles.patch,
  a3ab6d42-apparmor-conv-libvirtd-named-profile.patch
  boo#1118952
- libxl: save current memory value after successful balloon
  11c8aca9-libxl-set-mem-after-balloon.patch
  bsc#1120813
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Noun phrase for %%description doc.
- Remove idempotent %%if..%%endif pair around
  %%package bash-completion.
- Reduce hard requirements on bash-c and documentation.
* Thu Jan 17 2019 James Fehlig <jfehlig@suse.com>
- Enable bash completion in Leap15/SLE15 and newer
* Tue Jan 15 2019 James Fehlig <jfehlig@suse.com>
- Update to libvirt 5.0.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Remove UML hypervisor driver
  - Dropped patches:
    de09ae2f-libxl-support-openvswitch.patch,
    0a1b5653-xenconfig-support-openvswitch.patch
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Wed Jan  2 2019 James Fehlig <jfehlig@suse.com>
- Requires: ncurses expands to Requires: libncurses5, which
  is not required by any component of this package. Remove it
  along with the BuildRequires: ncurses-devel
* Mon Dec  3 2018 James Fehlig <jfehlig@suse.com>
- Update to libvirt 4.10.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    14d03b27-libxl-rm-redundant-virObjectEventStateQueue.patch,
    82452a5d-libxl-rm-goto-libxlDomainShutdownThread.patch,
    da4b0fd9-libxl-support-soft-reset.patch,
    libxl-qemu-emulator-caps.patch
  - Added patches:
    de09ae2f-libxl-support-openvswitch.patch,
    0a1b5653-xenconfig-support-openvswitch.patch
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Tue Nov  6 2018 James Fehlig <jfehlig@suse.com>
- libxl: add support for soft reset
  14d03b27-libxl-rm-redundant-virObjectEventStateQueue.patch,
  82452a5d-libxl-rm-goto-libxlDomainShutdownThread.patch,
  da4b0fd9-libxl-support-soft-reset.patch
  bsc#1081516
* Mon Nov  5 2018 James Fehlig <jfehlig@suse.com>
- Update to libvirt 4.9.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - FATE#326371
* Fri Oct 19 2018 jfehlig@suse.com
- Update SLE15 SP1 with openSUSE Factory package
  FATE#325848, FATE#326368
- FATE and bug references made in the SLE15 package since the last
  Factory update: FATE#325817, bsc#959329, bsc#1074014,
  bsc#1106420, bsc#1108395
- Patches in SLE15 package that are dropped by this update:
  1b0c42ff-libvirtd-depend-machined.patch,
  ac4a12db-libxl-fix-hasManagedSave.patch
* Tue Oct  2 2018 jfehlig@suse.com
- Update to libvirt 4.8.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    60b4fd90-libxl-rm-vm-finish-phase.patch,
    e39c66d3-libxl-fix-p2p-migration.patch,
    47da84e0-libxl-fix-job-handling-migsrc.patch,
    0149464a-libxl-fix-job-handling-migdst.patch,
    5ea2abb3-libxl-join-mig-rcv-thread.patch
* Mon Sep 24 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups. Remove idempotent %%if..%%endif guards.
- Remove redundant %%clean section.
* Wed Sep 19 2018 James Fehlig <jfehlig@suse.com>
- libxl: fix VM migration on busy hosts
  60b4fd90-libxl-rm-vm-finish-phase.patch,
  e39c66d3-libxl-fix-p2p-migration.patch,
  47da84e0-libxl-fix-job-handling-migsrc.patch,
  0149464a-libxl-fix-job-handling-migdst.patch,
  5ea2abb3-libxl-join-mig-rcv-thread.patch
  bsc#1108086
* Wed Sep  5 2018 jfehlig@suse.com
- Update to libvirt 4.7.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    9ed59012--revert-jansson1.patch,
    54f2b5e3-revert-jansson2.patch,
    b56950fd-revert-jansson3.patch,
    6c3d66ac-revert-jansson4.patch,
    8e373e6d-revert-jansson5.patch,
    6f99de31-revert-jansson6.patch,
    f204cf51-revert-jansson7.patch,
    5a58b5ed-revert-jansson8.patch,
    63f6e0e9-revert-jansson9.patch,
    8687eba-revert-jansson10.patch,
    e96e71d8-revert-jansson11.patch,
    d99a8959-revert-jansson12.patch,
    074a7e14-revert-jansson13.patch,
    86db0db9-revert-jansson14.patch
* Tue Aug 14 2018 jfehlig@suse.com
- Revert switch to jansson
  boo#1104820
  - Dropped:
    temp-build-fix.patch
  - Added:
    9ed59012--revert-jansson1.patch,
    54f2b5e3-revert-jansson2.patch,
    b56950fd-revert-jansson3.patch,
    6c3d66ac-revert-jansson4.patch,
    8e373e6d-revert-jansson5.patch,
    6f99de31-revert-jansson6.patch,
    f204cf51-revert-jansson7.patch,
    5a58b5ed-revert-jansson8.patch,
    63f6e0e9-revert-jansson9.patch,
    8687eba-revert-jansson10.patch,
    e96e71d8-revert-jansson11.patch,
    d99a8959-revert-jansson12.patch,
    074a7e14-revert-jansson13.patch,
    86db0db9-revert-jansson14.patch
* Mon Aug 13 2018 jfehlig@suse.com
- spec: don't restart libvirt-guests when updating libvirt-client
  bsc#1104662
* Mon Aug  6 2018 jfehlig@suse.com
- Update to libvirt 4.6.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Switch from yajl to jansson
  - Dropped patches:
    libvirt-4.5.0-apparmor-add-missing-comma.patch
  - Patches added to fix upstream bugs:
    temp-build-fix.patch
* Fri Aug  3 2018 antoine.belvire@opensuse.org
- Fix apparmor failure at startup because of syntax error in
  libvirt profile:
  * Add libvirt-4.5.0-apparmor-add-missing-comma.patch (picked
    from upstream).
* Thu Jul  5 2018 jfehlig@suse.com
- Update to libvirt 4.5.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    67c56f6e-libxl-logfd-leak-fix.patch
- spec: use more macros in file paths
- libxl: Implement virDomainBlockResize
  0001-libxl-add-support-for-BlockResize-API.patch
  FATE#325467, bsc#1094325, bsc#1094725
* Wed Jul  4 2018 jfehlig@suse.com
- spec: enable gluster storage backend for openSUSE
* Mon Jun 25 2018 jfehlig@suse.com
- spec: BuildRequires glusterfs-devel when gluster support is
  enabled
* Tue Jun  5 2018 jfehlig@suse.com
- spec: use wireshark plugin directory from pkg-config
* Tue Jun  5 2018 jfehlig@suse.com
- virt-aa-helper: add SUSE path to OVMF and AAVMF images
  Adjusted suse-ovmf-paths.patch
  boo#1095556
* Mon Jun  4 2018 jfehlig@suse.com
- Update to libvirt 4.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - CVE-2018-3639
  - Dropped patches:
    1dbca2ec-CVE-2018-3639.patch, 92673422-CVE-2018-3639.patch
- libxl: fix leaking logfile fds
  67c56f6e-libxl-logfd-leak-fix.patch
  bsc#1094480
* Tue May 22 2018 jfehlig@suse.com
- cpu: add support for 'ssbd' and 'virt-ssbd' CPUID feature bits
  CVE-2018-3639
  1dbca2ec-CVE-2018-3639.patch, 92673422-CVE-2018-3639.patch
  bsc#1092885
* Mon May  7 2018 jfehlig@suse.com
- spec: enable libssh support for suse_version >= 1500
* Wed May  2 2018 jfehlig@suse.com
- Update to libvirt 4.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Remove legacy Xen driver
  - Dropped patches:
    09877303-virSocketAddrParseInternal.patch,
    412afdb8-intro-virSocketAddrParseAny.patch
* Thu Apr  5 2018 jfehlig@suse.com
- util: improvements in error handling
  09877303-virSocketAddrParseInternal.patch,
  412afdb8-intro-virSocketAddrParseAny.patch
  bsc#1080957
* Thu Apr  5 2018 jfehlig@suse.com
- Update to libvirt 4.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    6b3d716e-keycodemap-py3.patch,
    33c6eb96-fix-libvirtd-reload-deadlock.patch,
    464889ff-rpc-aquire-ref-dispatch.patch,
    c6f1d519-rpc-simplify-dispatch.patch,
    06e7ebb6-rpc-invoke-dispatch-unlocked.patch,
    86cae503-rpc-fix-pre-exec.patch,
    eefabb38-rpc-virtlockd-virtlogd-single-thread.patch,
    fbf31e1a-CVE-2018-1064.patch,
    fb327ac2-virtlockd-admin-socket.patch,
    64370c4b-libxl-MigrateBegin.patch,
    99486799-libxl-MigrateConfirm.patch,
    f5eacf2a-libxl-MigratePerform.patch,
    4e6fcdb6-libxl-libxlDomObjFromDomain-cleanup.patch,
    fe51dbda-libxl-use-FindByRef.patch,
    60b3fcd9-libxl-MigratePrepare.patch,
    3c89868c-libxl-lock-after-ListRemove.patch,
    13e81fc6-libxl-EndJob-on-error.patch,
    594b8b99-libxl-DefineXMLFlags-API-pattern.patch,
    c66e344e-libxl-dont-deref-NULL.patch,
    83edaf44-libxl-dont-hardcode-sched-weight.patch,
    apibuild-py3.patch
* Wed Mar 21 2018 jfehlig@suse.com
- libxl: don't hardcode scheduler weight
  83edaf44-libxl-dont-hardcode-sched-weight.patch
  bsc#1086377
* Tue Mar 20 2018 jfehlig@suse.com
- libxl: fixes and improvements in migration APIs
  64370c4b-libxl-MigrateBegin.patch,
  99486799-libxl-MigrateConfirm.patch,
  f5eacf2a-libxl-MigratePerform.patch,
  4e6fcdb6-libxl-libxlDomObjFromDomain-cleanup.patch,
  fe51dbda-libxl-use-FindByRef.patch,
  60b3fcd9-libxl-MigratePrepare.patch,
  3c89868c-libxl-lock-after-ListRemove.patch,
  13e81fc6-libxl-EndJob-on-error.patch,
  594b8b99-libxl-DefineXMLFlags-API-pattern.patch,
  c66e344e-libxl-dont-deref-NULL.patch
  bsc#1080957
* Thu Mar 15 2018 jfehlig@suse.com
- lockd: fix typo in virtlockd-admin.socket
  fb327ac2-virtlockd-admin-socket.patch
  bsc#1085386
* Wed Mar 14 2018 jfehlig@suse.com
- Install correct firewall service file depending on availability
  of firewalld vs SuSEfirewall2
  libvirtd-relocation-server.xml
  bsc#1083455
* Wed Mar 14 2018 jfehlig@suse.com
- qemu: avoid denial of service reading from QEMU guest agent
  CVE-2018-1064
  fbf31e1a-CVE-2018-1064.patch
  bsc#1083625
* Tue Mar 13 2018 jfehlig@suse.com
- virtlockd: fix loosing lock on re-exec
  464889ff-rpc-aquire-ref-dispatch.patch,
  c6f1d519-rpc-simplify-dispatch.patch,
  06e7ebb6-rpc-invoke-dispatch-unlocked.patch,
  86cae503-rpc-fix-pre-exec.patch,
  eefabb38-rpc-virtlockd-virtlogd-single-thread.patch
  bsc#1076861
* Tue Mar 13 2018 jfehlig@suse.com
- libvirtd: fix potential deadlock when reloading
  33c6eb96-fix-libvirtd-reload-deadlock.patch
  bsc#1079150
* Mon Mar  5 2018 jfehlig@suse.com
- Update to libvirt 4.1.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    72adaf2f-revert-qemu-monitor-error-report.patch,
    71d56a39-nodedev-fix-parse-PCI-address.patch,
    68eed56b-conf-smbios-oem-strings.patch,
    76977061-qemu-smbios-oem-strings.patch,
    0c710a37-libxl-resume-lock-on-mig-failure.patch,
    759b4d1b-virlog-determine-the-hostname-on-startup-CVE-2018-67.patch,
    c2dc6698-fix-deadlock-obtaining-hostname.patch,
    c391e07e-libxl-clock-settings.patch,
    ef71caea-libxl-memalign.patch,
    suse-apparmor-signal.patch
* Fri Feb 23 2018 jfehlig@suse.com
- libxl: round memory values to next 1MiB increment
  ef71caea-libxl-memalign.patch
  bsc#1082041
* Wed Feb 21 2018 jfehlig@suse.com
- libxl: add support for specifying clock offset and adjustment
  c391e07e-libxl-clock-settings.patch
  bsc#1082161
* Fri Feb  9 2018 cbosdonnat@suse.com
- Remove all uses of python2 during the build (bsc#1080034)
    6b3d716e-keycodemap-py3.patch
    apibuild-py3.patch
- Determine hostname early to avoid code injection
  in lxc driver. (bsc#1080042)
    759b4d1b-virlog-determine-the-hostname-on-startup-CVE-2018-67.patch
    c2dc6698-fix-deadlock-obtaining-hostname.patch
- Add basic support of connectGetAllDomainStats for lxc driver
  (fate#323742)
    0001-Extract-stats-functions-from-the-qemu-driver.patch
    0002-lxc-implement-connectGetAllDomainStats.patch
* Fri Jan 26 2018 jfehlig@suse.com
- qemu: Support setting OEM strings in SMBIOS
  68eed56b-conf-smbios-oem-strings.patch,
  76977061-qemu-smbios-oem-strings.patch
  FATE#323624
- libxl: resume lock process after failed migration
  0c710a37-libxl-resume-lock-on-mig-failure.patch
  bsc#1076861
* Thu Jan 25 2018 jfehlig@suse.com
- qemu hook: Change shebang to /usr/bin/python3
- spec: Require python lxml in daemon-hooks subpackage
* Fri Jan 19 2018 jfehlig@suse.com
- Update to libvirt 4.0.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    2d07f1f0-fix-storage-crash.patch,
    69ed99c7-dom0-persistent.patch,
    8599aedd-libvirt-guests-dom0-filter.patch,
    0f33025a-virt-aa-helper-handle-more-disk-images.patch,
    b475a91b-add-virStringFilterChars-string-utility.patch,
    faec1958-lxc-set-hostname-based-on-container-name.patch,
    2089ab21-netserver-close-clients-before-stopping-all-drivers.patch,
    fix-virt-aa-helper-profile.patch,
  - Patches added to fix upstream bugs:
    72adaf2f-revert-qemu-monitor-error-report.patch,
    71d56a39-nodedev-fix-parse-PCI-address.patch
  - CVE-2018-5748, CVE-2017-5715, bsc#1071651, bsc#1076500
* Thu Jan 11 2018 jfehlig@suse.com
- Add a qemu hook script providing functionality similar to Xen's
  block-dmmd script
  suse-qemu-domain-hook.py
  FATE#324177
* Wed Jan  3 2018 cbosdonnat@suse.com
- Fix apparmor rules for virt-aa-helper (bsc#1074265)
  fix-virt-aa-helper-profile.patch
- Lift VirtualBox dependency version to include 5.2.x
- Update upstreamed patches
  Removed patches:
  * daemon-close-crasher.patch
  * lxc-hostname.patch
  Added patches:
  * 2089ab21-netserver-close-clients-before-stopping-all-drivers.patch
  * b475a91b-add-virStringFilterChars-string-utility.patch
  * faec1958-lxc-set-hostname-based-on-container-name.patch
* Wed Dec 20 2017 cbosdonnat@suse.com
- Close clients before drivers are cleaned up to avoid crash at
  libvirtd stop (bsc#1073730)
  daemon-close-crasher.patch
- Set a hostname on lxc containers based on guest's name.
  lxc-hostname.patch
- Enhance apparmor rules for virt-aa-helper (bsc#1070916)
  0f33025a-virt-aa-helper-handle-more-disk-images.patch
* Mon Dec 18 2017 jfehlig@suse.com
- libvirt-guests: fix 'stop' operation when action is 'suspend'
  69ed99c7-dom0-persistent.patch,
  8599aedd-libvirt-guests-dom0-filter.patch
  bsc#1070130
* Thu Dec 14 2017 jfehlig@suse.com
- storage: Don't dereference driver object if virStorageSource is
  not initialized
  2d07f1f0-fix-storage-crash.patch
  bsc#1072974
* Mon Dec  4 2017 jfehlig@suse.com
- Update to libvirt 3.10.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - bsc#1070285, bsc#1070478, boo#1070914,
  - FATE#323473, FATE#324365, FATE#324479
* Fri Dec  1 2017 jfehlig@suse.com
- Update to libvirt 3.10.0 RC2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    8056721c-qemu-null-storage-source.patch,
    74a13be4-xdr-flags.patch,
    apparmor-rules-for-new-mediation-features.patch,
    apparmor-fine-grained-mount-rules.patch
  - bsc#1070285, bsc#1070478, FATE#323473, FATE#324479
* Thu Nov 30 2017 jfehlig@suse.com
- spec: remove use of 'systemctl enable'
  bsc#1038401
* Thu Nov 30 2017 jfehlig@suse.com
- spec: enable firewalld support for SLE15, Leap15, and Tumbleweed
  FATE#320794
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Nov 22 2017 kukuk@suse.de
- spec: Add BuildRequires for libtirpc-devel in preparation of
  removal of sunrpc from glibc
- build: Use XDR_CFLAGS in more places
  74a13be4-xdr-flags.patch
* Wed Nov 22 2017 olaf@aepfle.de
- Replace hardcoded libvirt with Name tag when refering to subpkgs
- Remove dependencies to /bin/sh in libs and nss %%post scripts
* Fri Nov 17 2017 jfehlig@suse.com
- apparmor: allow libvirtd to send signals to unconfined processes
  suse-apparmor-signal.patch
  boo#1065123
* Fri Nov 17 2017 jfehlig@suse.com
- qemu: Tolerate storage source private data being NULL
  8056721c-qemu-null-storage-source.patch
  bsc#1068752
* Wed Nov  8 2017 jfehlig@suse.com
- apparmor: add rules for new mediation features
  apparmor-rules-for-new-mediation-features.patch,
  apparmor-fine-grained-mount-rules.patch
  bsc#1066124, boo#1065123
- spec: unconditionally enable the wireshark dissector
* Wed Nov  8 2017 cbosdonnat@suse.com
- Replace %%{with_sle_build} by ! 0%%{?is_opensuse}
  bsc#940315
* Thu Nov  2 2017 jfehlig@suse.com
- Update to libvirt 3.9.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    c44b29aa-apparmor-dnsmasq-ptrace.patch,
    441d3eb6-qemu-tls-client-verify-server-cert.patch
* Mon Oct 16 2017 jfehlig@suse.com
- qemu: ensure TLS clients always verify the server certificate
  CVE-2017-1000256
  441d3eb6-qemu-tls-client-verify-server-cert.patch
  bsc#1062563
* Thu Oct 12 2017 jengelh@inai.de
- Do not ignore errors from useradd/groupadd.
- Invoke/expand %%service_* just once per scriptlet.
- Replace some old macros.
* Tue Oct 10 2017 jfehlig@suse.com
- spec: libvirt-daemon-qemu requires libvirt-daemon-driver-storage
  bsc#1062620
* Mon Oct  9 2017 jfehlig@suse.com
- spec: reload libvirtd Apparmor profile in %%post
  bsc#1060860
* Fri Oct  6 2017 jfehlig@suse.com
- apparmor: add dnsmasq ptrace rule to libvirtd profile
  c44b29aa-apparmor-dnsmasq-ptrace.patch
  bsc#1060860
* Thu Oct  5 2017 jfehlig@suse.com
- spec: Add dependency to UEFI firmwares since paths are specified
  at build time
* Wed Oct  4 2017 jfehlig@suse.com
- Update to libvirt 3.8.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    92bd87a2-ryzen-test-data.patch,
    5c83b360-epyc-test-data.patch,
    a0b62843-epyc-cpu-model.patch,
    f305d8a1-apparmor-attach_disconnected.patch,
    b482925c-apparmor-ptrace-support.patch
* Tue Oct  3 2017 jfehlig@suse.com
- Enable firewalld support for openSUSE >= 42.2
* Tue Sep 26 2017 jfehlig@suse.com
- apparmor: Add rules for kernel 4.13 ptrace checks
  b482925c-apparmor-ptrace-support.patch
  Drop temporary workaround apparmor-ptrace-support.patch
  bsc#1058847
- apparmor: Add rules for denial encountered when starting
  confined domains
  f305d8a1-apparmor-attach_disconnected.patch,
  suse-apparmor-libnl-paths.patch
  Drop old, useless, undocumented apparmor-fixes.patch
* Wed Sep 20 2017 jfehlig@suse.com
- apparmor: add temporary profile fixes to allow starting domains
  apparmor-ptrace-support.patch
  bsc#1058847
* Fri Sep 15 2017 jfehlig@suse.com
- cpu: Add new EPYC CPU model
  92bd87a2-ryzen-test-data.patch, 5c83b360-epyc-test-data.patch,
  a0b62843-epyc-cpu-model.patch
  bsc#1052825
* Fri Sep 15 2017 jfehlig@suse.com
- Update to libvirt 3.7.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    8982f3ab-util-hash-header.patch,
    0b1ecf7b-virHashCodeGen-mockable.patch,
    f536b0dd-tests-arch-independent-hash.patch,
    e4cb8500-avoid-malicious-ssh-hostname-as-args.patch
* Fri Sep  1 2017 jfehlig@suse.com
- Support OVMF 4MB firmware images
  Adjustment to spec file and suse-ovmf-paths.patch
* Thu Aug 31 2017 jfehlig@suse.com
- supportconfig plugin: list active networks, interfaces and
  storage pools
* Tue Aug 29 2017 jfehlig@suse.com
- rpc: avoid ssh interpreting malicious hostname as arguments
  e4cb8500-avoid-malicious-ssh-hostname-as-args.patch
  bsc#1053600
* Thu Aug  3 2017 jfehlig@suse.com
- Update to libvirt 3.6.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- Fix unit tests on s390x and ppc64
  8982f3ab-util-hash-header.patch,
  0b1ecf7b-virHashCodeGen-mockable.patch.
  f536b0dd-tests-arch-independent-hash.patch
- Patch cleanup
  - Renamed libvirtd-defaults.patch to
    suse-libvirtd-disable-tls.patch
  - Renamed libvirtd-init-script.patch to
    suse-libvirtd-sysconfig-settings.patch
  - Renamed virtlockd-init-script.patch to
    suse-virtlockd-sysconfig-settings.patch
  - Renamed virtlogd-init-script.patch to
    suse-virtlogd-sysconfig-settings.patch
  - Renamed libvirt-guests-init-script.patch to
    suse-libvirt-guests-service.patch
  - Combined suse-libvirtd-service.patch and
    systemd-service-xen.patch to suse-libvirtd-service-xen.patch
    since both patches add Xen support to libvirtd service file
  - Pull OVMF-related changes from suse-qemu-conf.patch into a
    new suse-ovmf-paths.patch
* Wed Jul 26 2017 jfehlig@suse.com
- Add a supportconfig plugin
  libvirt-supportconfig
  FATE#323661
* Wed Jul 26 2017 jfehlig@suse.com
- Remove Requires on bridge-utils
  FATE#323639
* Fri Jul 21 2017 dmueller@suse.com
- drop dependency on xen for armv6hl (not supported and does not
  build)
* Wed Jul  5 2017 jfehlig@suse.com
- Update to libvirt 3.5.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    5004f121-virFdStreamThread-dont-exceed-length.patch,
    1a4b21f1-set-EOF-on-end-of-stream.patch
* Thu Jun 29 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs
- Use %%_smp_mflags instead of just %%jobs
* Wed Jun  7 2017 jfehlig@suse.com
- misc spec file cleanup
  - remove checks for old distros well beyond EOL
  - enable wireshark dissector for Leap >= 42.2 and Factory
  - remove support for old, non-systemd distros
  - replace $RPM_ shell vars with modern macros
* Tue Jun  6 2017 jfehlig@suse.com
- Don't exceed specified length when reading from stream
  5004f121-virFdStreamThread-dont-exceed-length.patch,
  1a4b21f1-set-EOF-on-end-of-stream.patch
* Fri Jun  2 2017 jfehlig@suse.com
-  Update to libvirt 3.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    aeda1b8c-qemu-no-error-shutdown.patch,
    8023b21a-conf-ioapic.patch, 6b5c6314-qemu-irqchip.patch,
    2020e2c6-conf-intremap.patch, 04028a9d-qemu-intremap.patch,
    d12781b4-conf-iommu-cache-mode-attr.patch,
    a5691448-qemu-iommu-cache-mode.patch,
    3a276c65-conf-iommu-def-stability-check.patch,
    935d927a-conf-iommu-ABI-stability-check.patch,
    4cd3f241-fix-NULL-disk-source.patch,
    975ea20f-loopback-macro.patch,
    dbb85e0c-libxl-graphics-listen-addr.patch,
    libxl-def-usbctrl.patch, revert-2841e675-mtu.patch
  - FATE#321335, bsc#1031056, bsc#1037774, bsc#1040207, bsc#1040213
* Mon May 22 2017 jfehlig@suse.com
- libxl: add default listen address for VNC and spice
  975ea20f-loopback-macro.patch,
  dbb85e0c-libxl-graphics-listen-addr.patch
  bsc#1040207
- xenconfig: fix handling of NULL disk source
  4cd3f241-fix-NULL-disk-source.patch
  bsc#1040213
* Mon May 15 2017 jfehlig@suse.com
- qemu: add support for 288 VCPUS
  aeda1b8c-qemu-no-error-shutdown.patch,
  8023b21a-conf-ioapic.patch,
  6b5c6314-qemu-irqchip.patch,
  2020e2c6-conf-intremap.patch,
  04028a9d-qemu-intremap.patch,
  d12781b4-conf-iommu-cache-mode-attr.patch,
  a5691448-qemu-iommu-cache-mode.patch,
  3a276c65-conf-iommu-def-stability-check.patch,
  935d927a-conf-iommu-ABI-stability-check.patch
  FATE#321335
- revert commit 2841e675: qemu: propagate bridge MTU into qemu
  "host_mtu"
  revert-2841e675-mtu.patch
  bsc#1037774
* Mon May  8 2017 jfehlig@suse.com
-  Update to libvirt 3.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Bug fixes:
    bsc#978121, bsc#1017017, bsc#1032863, bsc#1033117, bsc#1034024,
    bsc#1034146, bsc#1035995
- libxl: updated libxl-def-usbctrl.patch
  bsc#1031056
* Fri Apr 28 2017 jfehlig@suse.com
- Update to libvirt 3.3.0 RC1
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    ae102b5d7-qemu-fix-regression-when-hyperv-vendor_id-feature-is-used.patch
  - Bug fixes:
    bsc#978121, bsc#1017017, bsc#1032863, bsc#1033117, bsc#1034024,
    bsc#1034146
- libxl: add default controllers for USB devices
  libxl-def-usbctrl.patch
  bsc#1031056
* Wed Apr 12 2017 petracvv@opensuse.org
- qemu: Fix regression when hyperv/vendor_id feature is used
  Added patch:
  ae102b5d7-qemu-fix-regression-when-hyperv-vendor_id-feature-is-used.patch
  boo#1033893
* Mon Apr  3 2017 jfehlig@suse.com
- Update to libvirt 3.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    67dcb797-virTimeBackOffWait-sleepcap.patch,
    85af0b80-qemu-adaptive-montimeout.patch,
    d68cb4f55-extract-the-request-sending-code-from-virNetlin.patch,
    754515b7d-add-virNetlinkDumpCommand.patch,
    3ee35d7d6-more-uses-of-SYSCTL_PATH.patch,
    5dd607059-add-virNetDevGetName.patch,
    00d28a78b-check-accept_ra-before-enabling-ipv6-forward.patch
- Add Conflicts=xendomains.service to libvirtd service
  suse-libvirtd-service.patch
  bsc#1015348
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Wed Mar 22 2017 cbosdonnat@suse.com
- Fail to start network instead of losing routes if IPv6 forwarding
  is required. bsc#1025252
  Added patches:
    00d28a78b-check-accept_ra-before-enabling-ipv6-forward.patch
    3ee35d7d6-more-uses-of-SYSCTL_PATH.patch
    5dd607059-add-virNetDevGetName.patch
    754515b7d-add-virNetlinkDumpCommand.patch
    d68cb4f55-extract-the-request-sending-code-from-virNetlin.patch
* Thu Mar 16 2017 jfehlig@suse.com
- qemu: Fix monitor timeout with large memory VMs
  67dcb797-virTimeBackOffWait-sleepcap.patch
  85af0b80-qemu-adaptive-montimeout.patch
  bsc#1013113
* Tue Mar  7 2017 mwilck@suse.com
- network: don't use dhcp-authoritative on static networks
  bsc#1015588
  * added network-don-t-use-dhcp-authoritative-on-static-netwo.patch
* Fri Mar  3 2017 jfehlig@suse.com
- Update to libvirt 3.1.0
  - Modularize storage driver by splitting it into backend-specific
    subpackages
  - CVE-2017-2635, bsc#1027075
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    b018ada3-shunloadtest-build-fix.patch,
    f86a7a83-libxl-dom0-balloon-fix.patch,
    6e4759d0-libxl-timer-fix.patch,
    87df87e0-libxl-timer-tsc-emulate.patch,
    b4386fda-xenconfig-timer-fix.patch,
    d3970925-timer-tests.patch,
    321a28c6-libxl-default-disk-format.patch,
    bd116810-libxl-fix-disk-detach.patch,
    ff225538-libxl-autoballoon-setting.patch,
    c89a6e78-libxl-physinfo-cleanup.patch,
    d2b77608-libxl-maxmem-fix.patch,
    79692c38-libxl-dom0-maxmem.patch,
    4ab0c959-libxl-mem-leak.patch,
    2dc1cf19-libxl-double-free.patch,
    apparmor-errormsg-fix.patch,
    apparmor-alt-seclabel.patch,
    qemu-disable-namespaces.patch
* Thu Mar  2 2017 jengelh@inai.de
- Drop author list from description. Fix summary to be more
  accurate as to what the subpackage pertains to.
* Sat Feb 18 2017 kukuk@suse.de
- Don't call insserv if we use systemd and don't require it.
* Thu Feb 16 2017 jfehlig@suse.com
- libxl: more fixes for dom0 maxmem setting
  4ab0c959-libxl-mem-leak.patch, 2dc1cf19-libxl-double-free.patch
  bsc#1017762
* Fri Feb 10 2017 jfehlig@suse.com
- apparmor: don't fail on non-apparmor <seclabel>
  apparmor-errormsg-fix.patch, apparmor-alt-seclabel.patch
  bsc#1023436
* Fri Feb 10 2017 jfehlig@suse.com
- libxl: fix reporting of domain maximum memory
  ff225538-libxl-autoballoon-setting.patch,
  c89a6e78-libxl-physinfo-cleanup.patch,
  d2b77608-libxl-maxmem-fix.patch,
  79692c38-libxl-dom0-maxmem.patch
  bsc#1017762
* Fri Feb 10 2017 jfehlig@suse.com
- libxl: set disk format to raw if not specified and fix disk
  detach
  321a28c6-libxl-default-disk-format.patch,
  bd116810-libxl-fix-disk-detach.patch
  bsc#1003379
* Thu Feb  9 2017 jfehlig@suse.com
- libxl: fix timer configurations
  6e4759d0-libxl-timer-fix.patch,
  87df87e0-libxl-timer-tsc-emulate.patch,
  b4386fda-xenconfig-timer-fix.patch, d3970925-timer-tests.patch
  bsc#1019969
* Thu Feb  2 2017 jfehlig@suse.com
- SLE12 SP2 bugs merged via version updates of the Factory libvirt
  package:
  bsc#986718
- SLE12 SP2 FATEs merged via version updates of the Factory libvirt
  package:
  FATE#316228, FATE#316628, FATE#319531, FATE#319810, FATE#320490
- Replaced libxl-dom0-balloon-fix.patch with upstream patch
  f86a7a83-libxl-dom0-balloon-fix.patch
* Fri Jan 27 2017 jfehlig@suse.com
- Fix dom0 ballooning with Xen >= 4.8
  libxl-dom0-balloon-fix.patch
  bsc#1020755
* Fri Jan 27 2017 jfehlig@suse.com
- SLE12 SP2 bugs merged via version updates of the Factory libvirt
  package:
  bsc#996020, bsc#987002, bsc#997278, bsc#998005, bsc#998389,
  bsc#1001446, bsc#1001698, bsc#1005288, bsc#1013991, bsc#1016253,
  bsc#1017086, bsc#1017762, bsc#1018189
* Fri Jan 27 2017 jfehlig@suse.com
- virt-create-rootfs is a temporary SLE-only hack that was never
  added to the Factory libvirt package, causing it to be dropped
  when rebasing SLE on Factory. Add it now but only apply
  associated patch when building for SLE.
  virt-create-rootfs.patch
  bsc#995981
* Wed Jan 18 2017 jfehlig@suse.com
- Update to libvirt 3.0.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Add b018ada3-shunloadtest-build-fix.patch to fix 'make check'
    failures
  - Add qemu-disable-namespaces.patch to temporarily disable
    qemu namespace feature until all issues are resolved
* Wed Dec 28 2016 matwey.kornilov@gmail.com
- In order to avoid issues like bsc#1017189, explicitly specify
  supported VirtualBox versions
* Mon Dec  5 2016 jfehlig@suse.com
- Update to libvirt 2.5.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- Import new public signing key
* Wed Nov 16 2016 jfehlig@suse.com
- spec: explicitly set qemu-bridge-helper path to /usr/lib/
  bsc#999070
* Tue Nov  8 2016 cbosdonnat@suse.com
- Package org.libvirt.api.policy polkit file (bsc#959297)
- Fix postun systemd services cleanup
- Mark /etc/libvirt/nwfilter/*.xml files as config files
* Wed Nov  2 2016 jfehlig@suse.com
- Update to libvirt 2.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Wed Oct  5 2016 jfehlig@suse.com
- Update to libvirt 2.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    pci-use-driver-override-sysfs.patch,
    virHostdevFindUSBDevice-privsyms.patch, libxl-usb-vendor.patch,
    apparmor-qemu-bridge-helper.patch
* Fri Sep  2 2016 jfehlig@suse.com
- Update to libvirt 2.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    856965b3-qemu-secdriver.patch,
    541e9ae6-cpu-vendor-crash-fix.patch,
    d53d4650-qemu-rbd-auth.patch
* Sat Aug 20 2016 jfehlig@suse.com
- libxl: allow vendor/product addressing for USB hostdevs
  virHostdevFindUSBDevice-privsyms.patch, libxl-usb-vendor.patch
  bsc#989646
- qemu: fix auth for rbd network disks
  d53d4650-qemu-rbd-auth.patch
  bsc#988998
- Replace cpumodel-vendor-crash-fix.patch with upstream variant
  541e9ae6-cpu-vendor-crash-fix.patch
  bsc#992425
* Fri Aug 12 2016 jfehlig@suse.com
- Update to libvirt 2.1.0
  - New subpackages libvirt-libs and libvirt-admin
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    c8f08e48-systemd-notify-fix.patch
- qemu: fix qemu.conf security_driver regression in 2.1.0 release
  856965b3-qemu-secdriver.patch
* Fri Aug  5 2016 jfehlig@suse.com
- cpu_x86: fix libvirtd segfault when host cpu is 'qemu64'
  cpumodel-vendor-crash-fix.patch
  bsc#992425
* Fri Aug  5 2016 cbosdonnat@suse.com
- bsc#988279. Move the qemu-bridge-helper apparmor profile from the
  qemu abstraction to the usr.sbin.libvirtd profile.
  apparmor-qemu-bridge-helper.patch
* Wed Aug  3 2016 jfehlig@suse.com
- spec: minor improvements to logic enabling numactl and numad
  support and fix nested if indentation
  FATE#319979
* Tue Aug  2 2016 jfehlig@suse.com
- Update patches providing support for driver_override sysfs
  interface with latest upstream variant. Dropped
  pci-simplify-stub.patch and updated
  pci-use-driver-override-sysfs.patch
  bsc#986718
* Sat Jul 30 2016 jfehlig@suse.com
- spec: enable numactl and numad support for aarch64
  FATE#319979, bsc#991377
* Fri Jul 15 2016 jfehlig@suse.com
- BuildRequires: use librbd-devel instead of ceph-devel
- Enable rbd support for aarch64
  bsc#979473
* Thu Jul 14 2016 jfehlig@suse.com
- Use driver_override sysfs interface for binding/unbinding
  PCI stub drivers
  pci-simplify-stub.patch, pci-use-driver-override-sysfs.patch
  bsc#986718
* Tue Jul 12 2016 jfehlig@suse.com
- systemd: fix ready notification on abstract socket
  c8f08e48-systemd-notify-fix.patch
  boo#987668
* Fri Jul  1 2016 jfehlig@suse.com
- Update to libvirt 2.0.0
  - Change version scheme to match libvirt's time-driven release
    schedule. <major> will be incremented on first release of
    new calendar year, <minor> on each monthly release, and
    <micro> on stable branch maintenance release
  - Include libvirt-admin utility and API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    apparmor-dont-scrub-environment-of-virtlogd-process.patch,
    e33cd67a-xenconfig-backendtype-fix.patch
* Mon Jun 20 2016 jfehlig@suse.com
- spec: Recent simplification allows using a common spec file for
  SLE and openSUSE
- Add SLE patches missing in openSUSE
  libxl-dom-reset.patch, libxl-set-migration-constraints.patch,
  libxl-set-cach-mode.patch
* Thu Jun 16 2016 jfehlig@suse.com
- xenconfig: fix conversion of <driver> to backendtype
  e33cd67a-xenconfig-backendtype-fix.patch
  bsc#984798
* Wed Jun 15 2016 jfehlig@suse.com
- Advertise aarch64 UEFI firmware paths
  - adjust spec file to include aarch64 paths in
    '--with-loader-nvram=' configure option
  - adjust qemu.conf 'nvram' option to include the SUSE paths
  bsc#981836, bsc#983747
* Thu Jun  9 2016 jfehlig@suse.com
- apparmor: Don't scrub environment of virtlogd process
  apparmor-dont-scrub-environment-of-virtlogd-process.patch
  boo#980441
* Mon Jun  6 2016 jfehlig@suse.com
- Update to libvirt 1.3.5
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    e4d131b8-mv-virDomainDefPostParseInternal.patch,
    3e428670-post-parse-implicit-video.patch,
    538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
    400e716d-libxl-noprope-emulator.patch,
    b90c4b5f-tests-use-qemu-xen.patch,
    fccf2725-libxl-API-4.4.patch,
    5325123d-libxl-migv2-save-restore.patch,
    f9edcfa4-libxl-migv2-migration.patch,
    a1c9a81a-libxl-rbd-fix.patch,
    ba566428-libxl-dom-iface-addrs.patch
- spec: simplify and cleanup by removing many conditionals that
  are never toogled. Also drop conditionals for suse_version <
  1310
* Fri May 27 2016 jengelh@inai.de
- Avoid suppressing errors during useradd/groupadd
* Wed May 25 2016 jfehlig@suse.com
-  libxl: add domainInterfaceAddresses API
  ba566428-libxl-dom-iface-addrs.patch
  bsc#979425
* Wed May 25 2016 jfehlig@suse.com
- libxl: default to qemu driver for network disks
  a1c9a81a-libxl-rbd-fix.patch
  boo#981094
* Wed May 18 2016 jfehlig@suse.com
- spec: Remove %%defattr usage
  Inspired by upstream commit 90f9193c
* Fri May 13 2016 jfehlig@suse.com
- libxl: support Xen migration stream V2
  fccf2725-libxl-API-4.4.patch,
  5325123d-libxl-migv2-save-restore.patch,
  f9edcfa4-libxl-migv2-migration.patch
  bsc#978361
* Fri May 13 2016 jfehlig@suse.com
- Fix default video RAM setting
  e4d131b8-mv-virDomainDefPostParseInternal.patch,
  3e428670-post-parse-implicit-video.patch,
  538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
  400e716d-libxl-noprope-emulator.patch,
  b90c4b5f-tests-use-qemu-xen.patch
  bsc#979397
* Fri May  6 2016 olaf@aepfle.de
- Remove unknown locales to fix build in old dists
* Tue May  3 2016 jfehlig@suse.com
- Update to libvirt 1.3.4
  - Add support for migration data compression in QEMU driver
  - Drop libvirtd.socket
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: 216650f1-libxl-build-fix.patch,
    6d8b6d28-mark-implicit-video-primary.patch,
    03e8d5fb-qemu-perf-memory-corruption.patch,
    libvirtd-systemd-socket.patch
* Mon Apr 18 2016 jfehlig@suse.com
- qemu: perf: Fix crash/memory corruption on failed VM start
  03e8d5fb-qemu-perf-memory-corruption.patch
  bsc#977131
* Mon Apr 18 2016 jfehlig@suse.com
- Fix setting implicit video devices as primary
  6d8b6d28-mark-implicit-video-primary.patch
  bsc#977150
* Tue Apr 12 2016 jfehlig@suse.com
- Update to libvirt 1.3.3
  - perf events
  - post-copy migration support
  - NSS module
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Add rpmlintrc file to filter shlib-policy-name-error for
    new libnss_libvirt plugin
- Fix build with Xen4.7
  216650f1-libxl-build-fix.patch
* Fri Mar 18 2016 jfehlig@suse.com
- spec: restart daemons in %%posttrans after connection drivers
  have been processed
  bsc#854343, bsc#968483
* Thu Mar  3 2016 jfehlig@suse.com
- libxl: advertise system qemu instead of qemu-xen in caps
  libxl-qemu-emulator-caps.patch
  FATE#320638
* Tue Mar  1 2016 jfehlig@suse.com
- Update to libvirt 1.3.2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Thu Feb 18 2016 jfehlig@suse.com
- libxl: Add support for block-{dmmd,drbd,npiv} scripts
  libxl-support-block-script.patch
  bsc#954872
* Sat Jan 23 2016 jfehlig@suse.com
- qemu: set /usr/share/qemu/ovmf-x86_64-ms-{code,vars}.bin as
  default UEFI firmwares for x86_64
  bsc#961853
* Mon Jan 18 2016 jfehlig@suse.com
- Update to libvirt 1.3.1
  - CVE-2015-5313
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: 034e47c3-CVE-2015-5313.patch,
    ace1ee22-qemuxml2argv-test.patch, add-with-login-shell.patch,
    virt-aa-helper-rw-mounts.patch
* Tue Dec 22 2015 jfehlig@suse.com
- spec: perform one-time enable and start of virtlogd.socket when
  upgrading from libvirt < 1.3.0. Inspired by upstream libvirt.git
  commit da054f35.
* Fri Dec 18 2015 jfehlig@suse.com
- CVE-2015-5313: don't allow '/' in filesystem volume names
  034e47c3-CVE-2015-5313.patch
  bsc#953110
- Fix failing qemuxml2argv test on 32-bit platforms
  ace1ee22-qemuxml2argv-test.patch
* Thu Dec 17 2015 jfehlig@suse.com
- Update to libvirt 1.3.0
  - New virtlogd log daemon
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patch: 703ec1b7-qemu-bridge-helper-fix.patch
  - Added patch: virtlogd-init-script.patch
* Thu Dec  3 2015 cbosdonnat@suse.com
- Run udevadm settle after removing NICs in lxc driver.
  bsc#829033. lxc-wait-after-eth-del.patch
* Tue Nov 17 2015 cbosdonnat@suse.com
- Don't add apparmor deny rw rule for 9P readonly mounts.
  bsc#952849. virt-aa-helper-rw-mounts.patch
* Mon Nov  9 2015 cbosdonnat@suse.com
- Don't package virt-login-shell anymore as shipping it as
  non-setuid doesn't make sense. bsc#837609
  add-with-login-shell.patch
* Wed Nov  4 2015 normand@linux.vnet.ibm.com
- Detect path of qemu-bridge-helper during %%configure
  - add qemu-tools as BuildRequires for suse_version > 1130
  - add upstream patch 703ec1b7-qemu-bridge-helper-fix.patch
* Wed Nov  4 2015 jfehlig@suse.com
- Update to libvirt 1.2.21
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    disable-virCgroupGetPercpuStats-test.patch
* Mon Nov  2 2015 jfehlig@suse.com
- spec: some minor wireshark fixups. Essentially a backport of
  commit 7c8250d7.
* Fri Oct 16 2015 cbosdonnat@suse.com
- spec: remove all dependencies on apparmor to keep it optional.
  bsc#949793
* Tue Oct 13 2015 jfehlig@suse.com
- xenconfig: set disk type to BLOCK when driver is not tap or file
  xen-sxpr-disk-type.patch
  bsc#938228
* Fri Oct  9 2015 jfehlig@suse.com
- spec: the libvirt apparmor profiles #include files from the
  apparmor-profiles package, thus should have a dependency on it
  bsc#949793
* Wed Oct  7 2015 olaf@aepfle.de
- Remove Wants=xencommons.service from libvirtd.service
  xencommons is already enabled by a global preset, and the
  absence of xen-tools.rpm causes a systemd warning
* Fri Oct  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.20
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    3468542f-virFileUnlink.patch,
    8b1d84e6-refreshVol-failure.patch,
    e0025d29-storage-mode-check.patch,
    ba25c214-libxl-log-level.patch,
    56945e13-libxl-AttachDeviceConfig-hostdev.patch
* Thu Sep 17 2015 cyliu@suse.com
- bsc#945962: SLES12 SP1 Beta3 - Pass-through NIC device via virsh
  not available to VM.
  56945e13-libxl-AttachDeviceConfig-hostdev.patch
* Tue Sep 15 2015 jfehlig@suse.com
- libxl: set driver log level to the log_level specified in
  libvirtd.conf
  ba25c214-libxl-log-level.patch
  bsc#945796
* Mon Sep 14 2015 cbosdonnat@suse.com
- CVE-2015-5247 - denial of service through root-squash NFS storage
  bsc#945645
  3468542f-virFileUnlink.patch
  8b1d84e6-refreshVol-failure.patch
  e0025d29-storage-mode-check.patch
* Wed Sep  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.19
  - Improved ppc64 support
  - New virDomainRename API
  - Support for PCI Express controllers in QEMU
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    269d39af-storage-allocation-fix.patch,
    26c5fa3a-virt-aa-helper-missing-doc.patch,
    d25a5e08-virt-aa-helper-simplify-restriction-logic.patch,
    2f01cfdf-virt-aa-helper-allow-ovmf.patch,
    91fdcefa-virt-aa-helper-allow-nvram.patch,
    52970dec-virt-aa-helper-improve-valid-path.patch,
    44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch,
    15120b8c-libxl-no-resume-on-suspend-fail.patch,
    e80b84a7-libxl-acquire-job-on-migrate.patch,
    60acb38-revert-curmem-inactive-dom.patch
* Fri Aug 28 2015 jfehlig@suse.com
- Replace local libxl patches with upstream variants
  Dropped:
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  Added:
  44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch
  15120b8c-libxl-no-resume-on-suspend-fail.patch
  e80b84a7-libxl-acquire-job-on-migrate.patch
  bsc#936185
- Added another virt-aa-helper upstream patch
  52970dec-virt-aa-helper-improve-valid-path.patch
  lp#1483071
- Added upstream patch to fix libvirt-tck memory balloon test
  failure on Xen
  60acb38-revert-curmem-inactive-dom.patch
* Wed Aug 26 2015 cbosdonnat@suse.com
- Fix generated apparmor profile to allow access to ovmf and nvram.
  26c5fa3a-virt-aa-helper-missing-doc.patch
  2f01cfdf-virt-aa-helper-allow-ovmf.patch
  91fdcefa-virt-aa-helper-allow-nvram.patch
  d25a5e08-virt-aa-helper-simplify-restriction-logic.patch
  lp#1483071
* Mon Aug 24 2015 jfehlig@suse.com
- storage: only run safezero if allocation is > 0
  269d39af-storage-allocation-fix.patch
  bsc#942085
* Mon Aug  3 2015 jfehlig@suse.com
- Update to libvirt 1.2.18
  - libxl: support dom0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    e44bcae-virt-aa-helper-trailing-slash.patch,
    a55a5e7-virt-aa-helper-log.patch,
    61dab0f-virt-aa-helper-renaming.patch,
    24f3c2f-virt-aa-helper-fix-caps.patch,
    45697fe5-libxl-support-dom0.patch,
    e9c27344-libxl-fix-virDomainObj-state.patch,
    4ffb21c8-libxl-dom0-state-fix.patch,
    qemu-nbd-cleanup-fix.patch
* Fri Jul 31 2015 jfehlig@suse.com
- Fix crash in libxl driver on receiving side
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  bsc#936185
* Fri Jul 10 2015 jfehlig@suse.com
- libxl: set dom0 state to running
  4ffb21c8-libxl-dom0-state-fix.patch
  bsc#937316
- libxl: support management of dom0
  45697fe5-libxl-support-dom0.patch
  bsc#937316
- libxl: libxl: fix setting state of virDomainObj
  e9c27344-libxl-fix-virDomainObj-state.patch
  bsc#934937
* Fri Jul 10 2015 cbosdonnat@suse.com
- Fixed virt-aa-helper bugs preventing virt-sandbox to work.
  24f3c2f-virt-aa-helper-fix-caps.patch
  61dab0f-virt-aa-helper-renaming.patch
  a55a5e7-virt-aa-helper-log.patch
  e44bcae-virt-aa-helper-trailing-slash.patch
  bsc#936841
- Fixed crasher due to uninitialized values
  qemu-nbd-cleanup-fix.patch bsc#936841
* Thu Jul  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.17
  - parallels driver renamed to vz (Virtuozzo)
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- spec: re-enable tests that have received upstream fixes and
  are now passing
* Wed Jun  3 2015 jfehlig@suse.com
- Remove unsupported settings in libvirtd.socket unit file when
  systemd version < 214
  libvirtd-systemd-socket.patch
  bsc#933043
- spec: always apply Apparmor and netcontrol patches
* Tue Jun  2 2015 jfehlig@suse.com
- spec: Add libvirtd.socket unit file to service_add_pre and
  service_del_postun macros
* Mon Jun  1 2015 jfehlig@suse.com
- Update to libvirt 1.2.16
  - Introduce pci-serial
  - Introduce virDomainSetUserPassword API
  - Introduce protected key mgmt ops
  - Add domain vmport feature
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches c0d3f608-libxl-soundhw.patch and
    8910e063-arch-caps.patch
  - Drop polkit-10-virt.rules in favor of upstream 50-libvirt.rules
* Wed May 20 2015 dmacvicar@suse.de
- qemu: fix regression defaulting to host arch
  8910e063-arch-caps.patch
  rhb#1219191
* Wed May  6 2015 jfehlig@suse.com
- spec: build libxl driver for aarch64 and remove useless
  'suse_version <= 1220' conditional
* Tue May  5 2015 jfehlig@suse.com
- libxl: support virtual sound devices in HVM domains
  c0d3f608-libxl-soundhw.patch
  bsc#875216
* Mon May  4 2015 jfehlig@suse.com
- Update to libvirt 1.2.15
  - Implement virDomainAddIOThread and virDomainDelIOThread
  - libxl: Introduce configuration file for libxl driver
  - Add VIR_DOMAIN_EVENT_ID_DEVICE_ADDED event
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches da33a1ac-lxc-init-statedir.patch and
    open-ns-files-readonly.patch
- spec file fixups for building --without-driver-modules
* Mon Apr 20 2015 cbosdonnat@suse.com
- boo#926765: add libvirt-daemon-driver-qemu dependency on
  libvirt-daemon-driver-storage.
* Thu Apr  9 2015 cbosdonnat@suse.com
- boo#926153: make sure /var/run/libvirt/lxc folder exists when
  starting the driver. da33a1ac-lxc-init-statedir.patch
- Fix lxc-enter-namespace for 3.19+ kernels.
  open-ns-files-readonly.patch
* Thu Apr  2 2015 jfehlig@suse.com
- Disable building wireshark dissector.  Commit 37397320
  requires wireshark pkgconfig, which SUSE wireshark packages
  do not provide.
- Disable building the legacy Xen driver since Xen no longer
  provides the xend toolstack.  Remove xend-specific patches
  while at it: fix-pci-attach-xen-driver.patch,
  xen-name-for-devid.patch
* Thu Apr  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.14
  - qemu: Implement memory device hotplug
  - Implement public API for virDomainPinIOThread
  - Implement public API for virDomainGetIOThreadsInfo
  - SRIOV NIC offload feature discovery
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop disable-hugepage-test.patch in favor of upstream fix
* Tue Mar 31 2015 jfehlig@suse.com
- Fix build on older distros containing a polkit package that lacks
  support for /etc/polkit-1/rules.d drop directory
* Wed Mar 25 2015 jfehlig@suse.com
- Disable interface driver if libnetcontrol cannot be initialized
  Modified libvirt-suse-netcontrol.patch
  boo#920551
* Mon Mar 16 2015 jfehlig@suse.com
- Fix crash in libnetcontrol-backed interface driver
  Modified libvirt-suse-netcontrol.patch
  boo#920551
* Thu Mar 12 2015 fcastelli@suse.com
- Instruct polkit to allow memebers of the 'libvirt' group to connect
  to libvirt without providing any password (bnc#920804)
- Added polkit-10-virt.rules to fix bnc#920804
* Wed Mar 11 2015 jfehlig@suse.com
- Change default setting of security_default_confined in
  /etc/libvirt/qemu.conf instead of in code.  Making the change in
  code changes the default behavior for all users, even those that
  have a custom security setup in their /etc/libvirt/qemu.conf.
  Modified suse-qemu-conf.patch
  bsc#921586
* Mon Mar  9 2015 cbosdonnat@suse.com
- Fixed a number of QEMU apparmor abstraction problems. bsc#921355
  apparmor-fixes.patch
* Mon Mar  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.13
  - qemu: improved support for host and guest NUMA
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Tue Jan 27 2015 jfehlig@suse.com
- Update to libvirt 1.2.12
  - CVE-2015-0236: qemu: Check ACLs when dumping security info
    from snapshots
  - CVE-2015-0236: qemu: Check ACLs when dumping security info
    from save image
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 30c6aecc-apparmor-lib64.patch,
    apparmor-xen-fixup.patch, apparmor-allow-helpers.patch,
    apparmor-tck-raw-packets.patch
  - Disable a hugepage test that is failing on ppc, ppc64, and
    ppc64le architectures - disable-hugepage-test.patch
* Tue Jan 20 2015 cbosdonnat@suse.com
- Fixed patches to pass make syntax-check
* Tue Jan 20 2015 mlatimer@suse.com
- Apparmor profile regression breaks Xen domains. bsc#913799
  apparmor-xen-fixup.patch
  apparmor-allow-helpers.patch
  apparmor-tck-raw-packets.patch
* Mon Jan  5 2015 cbosdonnat@suse.com
- Replaced hard to maintain install-apparmor-profiles.patch
  by upstreamed 30c6aecc-apparmor-lib64.patch.
- Reformatted libvirt.spec and libvirtd.init to pass upstream make
  syntax-check
* Sat Dec 27 2014 Led <ledest@gmail.com>
- fix bashisms in libvirt-guests.sh script
- update patches:
  + libvirt-guests-init-script.patch
* Mon Dec 15 2014 cbosdonnat@suse.com
- Update to libvirt 1.2.11
  - Implement public API for virDomainGetFSInfo
  - qemu: Add define for the new throttle options
  - CVE-2014-8131: Fix possible deadlock and segfault in qemuConnectGetAllDomainStats()
  - CVE-2014-7823: dumpxml: security hole with migratable flag
- Drop upstream patches: 2222123-virt-aa-helper-crash.patch,
  433b427-iplink-name.patch,
  52691f99-qemu-mig-crash.patch,
  72fecf1-lxc-resolve-symlinks.patch,
  b1674ad5-CVE-2014-7823.patch,
  ba9b7252-sys-net-rw.patch,
  c264eea-virt-aa-helper-sandbox.patch,
  e50457d-lxc-unmount-check.patch,
  cgroup-all-devices.patch,
  libvirt-ppc64le-support.patch
* Wed Dec 10 2014 cbosdonnat@suse.com
- Get /proc/sys/net/ipv[46] read-write for wicked to work in
  containers. bsc#904432. ba9b7252-sys-net-rw.patch
- Fixed allowing devices for containers.
  cgroup-all-devices.patch
* Wed Dec  3 2014 jfehlig@suse.com
- qemu: Fix crash in tunnelled migration
  52691f99-qemu-mig-crash.patch
  boo#908008
* Thu Nov 20 2014 cbosdonnat@suse.com
- Fix potential crasher in virt-aa-helper
  2222123-virt-aa-helper-crash.patch
- ip link add now needs the 'name' parameter.
  433b427-iplink-name.patch
- Fixes for virt-sandbox-service to work:
  - Allow adding virt-sandbox service config to apparmor rules.
    c264eea-virt-aa-helper-sandbox.patch
  - fix symlink resolving for containers to start.
    72fecf1-lxc-resolve-symlinks.patch
  - fix unmounting file system if it contains the source to mount.
    e50457d-lxc-unmount-check.patch
* Tue Nov 18 2014 cbosdonnat@suse.com
- Remove security_driver = "none" in qemu config. This completely
  disabled all security drivers instead of probing them.
- Changed default value of QEMU's security_default_confined to 0 to
  keep QEMU domains unconfined by default.
* Tue Nov 11 2014 jfehlig@suse.com
- CVE-2014-7823: dumpxml: security hole with migratable flag
  b1674ad5-CVE-2014-7823.patch
  bsc#904176
* Thu Nov  6 2014 cbosdonnat@suse.com
- Fix Qemu AppArmor abstraction.
  - qemu-block.so was denied on x86_64. install-apparmor-profiles.patch
  - Temporary fix access to screenshot temporary file. bsc#904426.
    qemu-apparmor-screenshot.patch
* Mon Nov  3 2014 jfehlig@suse.com
- Update to libvirt 1.2.10
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Mon Oct 27 2014 cbosdonnat@suse.com
- Added package wireshark-plugin-libvirt to provide the wireshark
  dissector for the libvirt RPC protocol
* Thu Oct  2 2014 jfehlig@suse.com
- spec: Remove gpg-offline build dependency and use of gpg_verify
  to verify tarball since this task can be performed by source
  services
* Wed Oct  1 2014 jfehlig@suse.com
- Update to libvirt 1.2.9
  - Introduce virNodeAllocPages
  - event: introduce new event for tunable values
  - Add support for fetching statistics of completed jobs
  - CVE-2014-3657: domain_conf: fix domain deadlock
  - CVE-2014-3633: qemu: blkiotune: Use correct definition when
    looking up disk
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 3e745e8f-CVE-2014-3633.patch,
    libvirt-guests-wait-for-ntp.patch
- Verify tarball with associated .asc file
  Add: libvirt.keyring, libvirt-1.2.9.tar.gz.asc
  Use upstream .gz tarball instead of locally generated .bz2
* Fri Sep 19 2014 jfehlig@suse.com
- CVE-2014-3633: Use correct definition when looking up disk in
  qemu blkiotune
  3e745e8f-CVE-2014-3633.patch
  bnc#897783
* Wed Sep 10 2014 jfehlig@suse.com
- spec: do not require dmidecode on older code 11
* Mon Sep  8 2014 jfehlig@suse.com
- Wait for ntp service before running libvirt-guests
  libvirt-guests-wait-for-ntp.patch
  bnc#895194
* Thu Sep  4 2014 jfehlig@suse.com
- Canonicalize host arch name ppc64le to ppc64
  ppc64le-canonical-name.patch
  bnc#894956
* Tue Sep  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.8
  - virDomainBlockCopy with XML destination, typed params
  - Introduce API for retrieving bulk domain stats
  - Introduce virDomainOpenGraphicsFD API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Mon Sep  1 2014 cbosdonnat@suse.com
- bnc#893999: remove mount rules from libvirt-lxc apparmor
  abstraction file as those aren't handled by our kernel.
  apparmor-no-mount.patch
* Fri Aug 29 2014 mlatimer@suse.com
- bnc#894232 - Update apparmor profile to allow raw packets
  install-apparmor-profiles.patch
* Wed Aug 20 2014 ro@suse.de
- remove not necessary hunks from libvirt-ppc64le-support.patch
- move new patches to section for to be upstreamed
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-power8-models.patch
  add current power8 cpu models to map
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-ppc64le-support.patch
  add preliminary ppc64le support to libvirt
* Fri Aug  8 2014 cyliu@suse.com
- bnc#820399 - virsh blockcopy should refuse identical device
  blockcopy-check-dst-identical-device.patch
* Mon Aug  4 2014 jfehlig@suse.com
- Update to libvirt 1.2.7
  - Introduce virConnectGetDomainCapabilities
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: dba3432b-virt-lxc-convert-fix.patch,
    9b1e4cd5-skip-useless-apparmor-files.patch,
    9265f8ab-apparmor-lxc-rework.patch,
    add-nocow-to-vol-xml.patch,
    lxc-keep-caps-feature.patch,
    lxc-keep-caps-feature-conversion.patch,
    lxc-keep-caps-feature-doc.patch,
    lxc-net-target-name.patch,
    lxc-net-target-name-conversion.patch,
    lxc-net-target-name-doc.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- lxc AppArmor profile now only restricting potentially dangerous
  accesses. fdo#886460
- Add virt-lxc-convert to libvirt-daemon-driver-lxc package
- added patches:
  * 9265f8ab-apparmor-lxc-rework.patch
  * 9b1e4cd5-skip-useless-apparmor-files.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- virt-lxc-convert: force free to output values in bytes
- added patches:
  * dba3432b-virt-lxc-convert-fix.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- lxc: allow setting a custom name for container NICs as LXC is
  is able to do it.
  lxc-net-target-name.patch,
  lxc-net-target-name-conversion.patch,
  lxc-net-target-name-doc.patch
* Wed Jul  2 2014 jfehlig@suse.com
- Move 'Requires' of qemu from libvirt-daemon-qemu subpackage to
  libvirt-daemon-driver-qemu
  bnc#885267
* Wed Jul  2 2014 jfehlig@suse.com
- Temporarily disable virt-aa-helper-test, which fails in Factory
* Wed Jul  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.6
  - libxl: add migration support and fixes
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patch libxl-migration-support.patch
  - Drop ia64-clone.patch since libvirt is not built for IA64
* Wed Jun 25 2014 cbosdonnat@suse.com
- lxc-keep-caps-feature.patch: allow to keep/drop additional
  capabilities for LXC containers. bnc#881465
- lxc-keep-caps-feature-conversion.patch: convert lxc.cap.drop to
  the new domain configuration.
- lxc-keep-caps-feature-doc.patch: documentation for the new feature.
* Mon Jun  2 2014 jfehlig@suse.com
- Disable failing virportallocatortest on aarch64
* Mon Jun  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.5
  - Introduce virDomain{Get,Set}Time APIs
  - Introduce virDomainFSFreeze() and virDomainFSThaw() public API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches:
    b98bf811-add-paravirt-shutdown-flag.patch,
    c4fe29f8-use-shutdown-flag.patch,
    da744120-use-reboot-flag.patch,
    d6b27d3e-CVE-2014-0179.patch,
    fd43d1f8-libxl-iface-hostdev.patch,
    99f50208-managed-hostdev-iface.patch,
    292d3f2d-libselinux-build-fix1.patch,
    b109c097-libselinux-build-fix2.patch
* Wed May 28 2014 jfehlig@suse.com
- Add upstream patches that fix build with libselinux 2.3
  Added: 292d3f2d-libselinux-build-fix1.patch,
    b109c097-libselinux-build-fix2.patch
  Dropped: libselinux-build-fix.patch
* Wed May 28 2014 cbosdonnat@suse.com
- Fix the build breakers brought by libselinux 2.3.
  libselinux-build-fix.patch
* Tue May 20 2014 jfehlig@suse.com
- spec: libvirt-daemon package owns /etc/libvirt, not libvirt-client
  bnc#878056
* Mon May 12 2014 jfehlig@suse.com
- libxl: Fix <interface type='hostdev'> syntax for SR-IOV devices
  fd43d1f8-libxl-iface-hostdev.patch,
  99f50208-managed-hostdev-iface.patch
* Tue May  6 2014 jfehlig@suse.com
- Update to libvirt 1.2.4
  - Primarily a bug-fix release.  See http://libvirt.org/news.html
    for a detailed list of bug fixes and improvements
  - Drop upstream patches:
    0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch
- libxl: Support ACPI shutdown event
  b98bf811-add-paravirt-shutdown-flag.patch,
  c4fe29f8-use-shutdown-flag.patch, da744120-use-reboot-flag.patch
  bnc#872777
- libx: Support migration
  libxl-migration-support.patch
  bnc#875193
* Mon May  5 2014 jfehlig@suse.com
- CVE-2014-0179: Don't expand entities when parsing XML
  d6b27d3e-CVE-2014-0179.patch
  bnc#873705
* Wed Apr 16 2014 dmueller@suse.com
- blacklist one more unit test for qemu_linux_user builds
* Tue Apr  8 2014 jfehlig@suse.com
- libxl: Set disk format for empty cdrom device
  0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch
  bnc#872517
* Mon Apr  7 2014 cyliu@suse.com
- Fate#315125: add NOCOW flag
  add-nocow-to-vol-xml.patch
* Wed Apr  2 2014 cbosdonnat@suse.com
- Removed libxl-hvm-vnc.patch: went upstream in another form
* Wed Apr  2 2014 cbosdonnat@suse.com
- Update to libvirt 1.2.3
  - add new virDomainCoreDumpWithFormat API
  - conf: Introduce virDomainDeviceGetInfo API
  - more features and fixes on bhyve driver
  - lot of cleanups and improvement on the Xen driver
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Fri Mar 14 2014 jfehlig@suse.com
- Add /usr/sbin/rc{libvirtd,virtlockd,libvirt-guests} symlinks
  to preserve backwards compatibility
  bnc#868190
* Tue Mar  4 2014 jfehlig@suse.com
- Improve lock manager comments in qemu.conf
  Updated suse-qemu-conf.patch
* Tue Mar  4 2014 speilicke@suse.com
- Create /etc/libvirt/hooks to allow using hook scripts
* Mon Mar  3 2014 jfehlig@suse.com
- Update to libvirt 1.2.2
  - add LXC from native conversion tool
  - vbox: add support for v4.2.20+ and v4.3.4+
  - CVE-2013-6456 (bnc#857490)
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 37564b47-xend-parse-response.patch,
    4f20084-fix-apparmor-install-patch.patch
  - Add local disable-virCgroupGetPercpuStats-test.patch to disable
    failing virCgroupGetPercpuStats test in 'make check'
* Mon Feb 24 2014 jfehlig@suse.com
- daemon-qemu: Require qemu instead of kvm to align with
  recent changes to the qemu package structure
* Fri Feb 14 2014 jfehlig@suse.com
- spec: fix dependencies of daemon-config-network and
  daemon-config-nwfilter subpackages.  Influenced by upstream
  commits cf76c4b3 and dca5ce4c
* Fri Feb 14 2014 jfehlig@suse.com
- Remove libvirtd, virtlockd, and libvirt-guests init scripts when
  using systemd
  bnc#863540
* Wed Feb 12 2014 cbosdonnat@suse.com
- Fix the path to libvirtd AppArmor template profile
* Wed Jan 29 2014 jfehlig@suse.com
- Fix parsing xend http response
  37564b47-xend-parse-response.patch
  rhb#1055165
* Wed Jan 22 2014 jfehlig@suse.com
- Add CAP_SYS_PACCT capability to libvirtd AppArmor profile
  Modified install-apparmor-profiles.patch
  bnc#817407
* Tue Jan 21 2014 jfehlig@suse.com
- Fix build on code 11
- Fix rpmlint warning
* Tue Jan 21 2014 jfehlig@suse.com
- Following the upstream pattern, introduce the
  daemon-config-network subpackage to handle defining the default
  network
  bnc#859041
* Fri Jan 17 2014 jfehlig@suse.com
- Update to libvirt 1.2.1
  - CVE-2014-0028, CVE-2014-1447, CVE-2013-6458, CVE-2013-6457,
    CVE-2013-6436
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches: 5e397d9c-test-fix-dbus-crash.patch,
    78af457e-fix-virnettlscontexttest.patch,
    9faf3f29-LXC-memtune.patch, f8c1cb90-CVE-2013-6436.patch,
    libxl-hvm-nic.patch
* Fri Dec 27 2013 jfehlig@suse.com
- Ignore 'make check' on older, code 11 base
* Thu Dec 26 2013 cbosdonnat@suse.com
- Fixed and reenabled unit tests. bnc#854694
* Fri Dec 20 2013 jfehlig@suse.com
- Remove dependency on pm-utils from libvirt-client
  bnc#856381
* Fri Dec 20 2013 jfehlig@suse.com
- CVE-2013-6436: Fix crashes in lxc memtune code, one of which
  results in DoS
  f8c1cb90-CVE-2013-6436.patch, 9faf3f29-LXC-memtune.patch
  bnc#854486
* Fri Dec  6 2013 jfehlig@suse.com
- More adjustments to the spec file to fix package dependency
  issues
  bnc#848918
* Fri Dec  6 2013 jfehlig@suse.com
- Update to libvirt 1.2.0
  - Add support for gluster pool
  - Separation of python binding
  - vbox: add support for 4.3 APIs
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Updated and renamed clone.patch to ia64-clone.patch
- Enabled numad support for openSUSE >= 13.1
* Wed Dec  4 2013 jfehlig@suse.com
- Link with same versions of libnl used by netcontrol to prevent
  crashing libvirtd on start
* Wed Dec  4 2013 jfehlig@suse.com
- Add '/etc/sasl2' to libvirt-client file list to fix Factory build
* Wed Nov 27 2013 jfehlig@suse.com
- Fix starting of libvirtd when NetworkManager is enabled
  Modified libvirt-suse-netcontrol.patch
* Tue Nov 26 2013 jfehlig@suse.com
- Allow execution of libvirt hook scripts in /etc/libvirt/hooks/
  in libvirtd AppArmor profile
* Wed Nov 20 2013 jfehlig@suse.com
- Update to libvirt 1.1.4
  - Add support for AArch64 architecture
  - Various improvements on test code and test driver
  - Don't link virt-login-shell against libvirt.so
  - Close all non-stdio FDs in virt-login-shell
  - Only allow 'stderr' log output when running setuid
  - Fix perms for virConnectDomainXML{To,From}Native
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: e7f400a1-CVE-2013-4296.patch,
    2dba0323-CVE-2013-4297.patch, db7a5688-CVE-2013-4311.patch,
    e65667c0-CVE-2013-4311.patch, 922b7fda-CVE-2013-4311.patch,
    e4697b92-CVE-2013-4311.patch, 8294aa0c-CVE-2013-4399.patch,
    484cc321-fix-spice-migration.patch,
    79552754-libvirtd-chardev-crash.patch,
    57687fd6-CVE-2013-4401.patch, ae53e5d1-CVE-2013-4400.patch,
    8c3586ea-CVE-2013-4400.patch, b7fcc799a-CVE-2013-4400.patch,
    3e2f27e1-CVE-2013-4400.patch, 5a0ea4b7-CVE-2013-4400.patch,
    843bdb2f-CVE-2013-4400.patch,
    bd773e74-lxc-terminate-machine.patch,
    e350826c-python-fix-fd-passing.patch
* Tue Nov 19 2013 jfehlig@suse.com
- Allow execution of Xen binaries in /usr/lib{,64}/xen/bin in
  libvirtd AppArmor profile
  bnc#849524
* Tue Nov 19 2013 jfehlig@suse.com
- Require libvirt-daemon-<hypervisor> in the main libvirt package
  for each supported hypervisor
  bnc#850882
* Mon Nov  4 2013 jfehlig@suse.com
- Fix initialization of libxl NIC devices
  libxl-hvm-nic.patch
  bnc#848918
* Wed Oct 30 2013 jfehlig@suse.com
- Fix typo in libvirtd apparmor profile which prevented the profile
  from loading
  bnc#848216
* Fri Oct 25 2013 jfehlig@suse.com
- libxl driver: fix initialization of VNC and SDL info for
  HVM domains
  libxl-hvm-vnc.patch
  bnc#847566
- Allow libvirtd apparmor profile to access /etc/xen/scripts/*
* Wed Oct 23 2013 jfehlig@suse.com
- Fix file descriptor passing in python bindings
  e350826c-python-fix-fd-passing.patch
  rhb#1021434
* Tue Oct 22 2013 cbosdonnat@suse.com
- Have systemd terminate the machine as a workaround of fdo#68370
  bd773e74-lxc-terminate-machine.patch
  bnc#842834
* Tue Oct 22 2013 jfehlig@suse.com
- Spec file fixes to only package libvirt-login-shell when
  building the LXC driver
* Mon Oct 21 2013 jfehlig@suse.com
- CVE-2013-4400: Unsantized use of env variables allows privilege
  escalation via virt-login-shell
  ae53e5d1-CVE-2013-4400.patch, 8c3586ea-CVE-2013-4400.patch,
  b7fcc799a-CVE-2013-4400.patch, 3e2f27e1-CVE-2013-4400.patch,
  5a0ea4b7-CVE-2013-4400.patch, 843bdb2f-CVE-2013-4400.patch
  bnc#837609
- CVE-2013-4401: Fix perms for virConnectDomainXML{To,From}Native
  57687fd6-CVE-2013-4401.patch
  bnc#845704
* Fri Oct 18 2013 jfehlig@suse.com
- Move hypervisor-specific files out of libvirt-daemon package
  and into libvirt-daemon-<hypervisor> subpackage
  bnc#845851
- conf: Don't crash on invalid chardev source definition
  79552754-libvirtd-chardev-crash.patch
  bnc#845704, rhb#1012196
* Thu Oct 17 2013 jfehlig@suse.com
- Use newer libnl3 instead of libnl-1_1
  bnc#845540
* Tue Oct 15 2013 jfehlig@suse.com
- Move virt-login-shell to new subpackage libvirt-login-shell,
  requiring users to opt-in for this setuid binary.  Note: For now,
  virt-login-shell will not have setuid permissions, pending
  resolution of bnc#837609
* Tue Oct 15 2013 jfehlig@suse.com
- qemu: Fix seamless SPICE migration
  484cc321-fix-spice-migration.patch
  bnc#842301
* Tue Oct 15 2013 jfehlig@suse.com
- CVE-2013-4399: Fix crash in libvirtd when events are registered
  and ACLs active
  8294aa0c-CVE-2013-4399.patch
  bnc#844052, bnc#842300
* Mon Oct 14 2013 jfehlig@suse.com
- Update the stale gettext BuildRequires and Requires dependencies
  in the spec file
  bnc#841325
* Mon Oct 14 2013 jfehlig@suse.com
- virt-aa-helper apparmor profile was denying read access to
  /proc/$PID/*.  Give read accesss to these files.
  Updated install-apparmor-profiles.patch
  bnc#841720
* Mon Oct 14 2013 jfehlig@suse.com
- libvirtd apparmor profile was denying access to
  /usr/lib/xen/bin/qemu-system-i386, which is now the default
  emulator used with Xen guests
  Updated install-apparmor-profiles.patch
  bnc#845648
* Thu Oct  3 2013 jfehlig@suse.com
- Fix condrestart|try-restart invocation of virtlockd init script
  Modifed virtlockd-init-script.patch
* Tue Sep 17 2013 jfehlig@suse.com
- CVE-2013-4311: Add support for using 3-arg pkcheck syntax for
  process
  db7a5688-CVE-2013-4311.patch, e65667c0-CVE-2013-4311.patch,
  922b7fda-CVE-2013-4311.patch, e4697b92-CVE-2013-4311.patch
  bnc#836931
* Thu Sep  5 2013 jfehlig@suse.com
- CVE-2013-4296: Fix crash in remoteDispatchDomainMemoryStats
  e7f400a1-CVE-2013-4296.patch
  bnc#838638
- CVE-2013-4297: Fix crash in virFileNBDDeviceAssociate
  2dba0323-CVE-2013-4297.patch
  bnc#838642
* Tue Sep  3 2013 jfehlig@suse.com
- Update to libvirt 1.1.2
  - various improvements to libxl driver
  - systemd integration improvements
  - Add flag to BaselineCPU API to return detailed CPU features
  - Introduce a virt-login-shell binary
  - conf: add startupPolicy attribute for harddisk
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: bcef0f01-libxl-console.patch,
    9d0557b9-legacy-xen-double-free.patch,
    d7a45bf2-legacy-xen-dumpxml.patch, 0e671a16-CVE-2013-4239.patch
  - Includes fixes for bnc#837530, bnc#837531, bnc#837999
* Tue Aug 13 2013 jfehlig@suse.com
- Fix memory corruption in legacy Xen driver
  0e671a16-CVE-2013-4239.patch
  bnc#834598
- Upstream patches to fix dumpxml in legacy Xen driver
  9d0557b9-legacy-xen-double-free.patch,
  d7a45bf2-legacy-xen-dumpxml.patch
* Wed Jul 31 2013 jfehlig@suse.com
- Backport upstream patch implementing domainOpenConsole in the
  libxl driver.  Allows 'virsh console dom-name' to work with
  Xen libxl toolstack.
  bcef0f01-libxl-console.patch
* Tue Jul 30 2013 jfehlig@suse.com
- Update to libvirt 1.1.1
  - Adding device removal or deletion events
  - Introduce new domain create APIs to pass pre-opened FDs to LXC
  - Add interface versions for Xen 4.3
  - Add new public API virDomainSetMemoryStatsPeriod
  - Various LXC improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f38c8185-CVE-2013-2230.patch,
    fd2e3c4c-xen-sysctl-domctl.patch, dfc69235-CVE-2013-4153.patch,
    96518d43-CVE-2013-4154.patch, fe89fd3b-storage-pool-deadlock.patch
  - Drop relax-qemu-usergroup-check.patch - no longer needed
    after hypervisor-specific daemon package split
* Mon Jul 22 2013 jfehlig@suse.com
- Unlock the storage volume object after looking it up
  fe89fd3b-storage-pool-deadlock.patch
  rhb#980676
* Mon Jul 22 2013 jfehlig@suse.com
- CVE-2013-4153: Fix double free of returned JSON array in
  qemuAgentGetVCPUs()
  dfc69235-CVE-2013-4153.patch
- CVE-2013-4154: Prevent crash of libvirtd without guest agent
  configuration
  96518d43-CVE-2013-4154.patch
  bnc#830498
* Wed Jul 17 2013 jfehlig@suse.com
- Fix legacy xen driver with Xen 4.3
  fd2e3c4c-xen-sysctl-domctl.patch
* Wed Jul 10 2013 jfehlig@suse.com
- CVE-2013-2230: Fix crash when multiple event callbacks were
  registered
  f38c8185-CVE-2013-2230.patch
  bnc#827801
* Wed Jul 10 2013 jfehlig@suse.com
- Update to libvirt 1.1.0
  - Extensible migration APIs
  - Add a policy kit access control driver
  - various improvements in the Xen and libxl drivers
  - improve networking support on BSD
  - agent based vCPU hotplug support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 244e0b8c-CVE-2013-2218.patch
* Mon Jul  8 2013 jfehlig@suse.com
- Only require lzop if suse_version > 1210
* Wed Jul  3 2013 jfehlig@suse.com
- Fix typo in spec file
* Wed Jul  3 2013 jfehlig@suse.com
- Enable support for netcontrol by default
- Only require libvirt-daemon-driver-interface when building the
  interface driver
* Mon Jul  1 2013 jfehlig@suse.com
- CVE-2013-2218: Fix crash listing network interfaces with filters
  244e0b8c-CVE-2013-2218.patch
* Tue Jun 11 2013 jfehlig@suse.com
- Add xencommons as 'Wanted' in the systemd libvirtd service file
  systemd-service-xen.patch
  bnc#820888
* Mon Jun 10 2013 jfehlig@suse.com
- Fix build for SLE11 SP2
* Fri Jun  7 2013 jfehlig@suse.com
- Add a README to the empty packages.  Provides some info about
  their purpose and satisfies suse-filelist-empty check.
  Drop rpmlintrc
* Fri Jun  7 2013 jfehlig@suse.com
- Fix typo in spec file: devel package requires doc package, not
  docs
* Thu Jun  6 2013 jfehlig@suse.com
- Add rpmlintrc to get around suse-filelist-empty error on
  older distros.
* Thu Jun  6 2013 jfehlig@suse.com
- Refactor libvirt spec file to create subpackages for the various
  libvirtd components.  This allows installing a libvirtd tailored
  for the underlying virtualizer.  E.g. on a KVM/QEMU virtualizer
  only the libvirt-daemon-qemu package needs installed.
  Similarly, only libvirt-daemon-xen on a Xen virtualizer and
  libvirt-daemon-lxc on LXC.
* Tue Jun  4 2013 jfehlig@suse.com
- Update to libvirt 1.0.6
  - Move VirtualBox driver into libvirtd
  - Support for static routes on a virtual bridge
  - Various improvement for hostdev SCSI support
  - Switch to VIR_STRDUP and VIR_STRNDUP
  - Various cleanups and improvement in Xen and LXC drivers
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f493d83f-cgroup-swap-control.patch,
    486a86eb-cgroups-docs.patch, 0ced83dc-cgroup-escape-dot.patch,
    bbe97ae9-no-cgroups.patch, c2cf5f1c-no-cgroups-fix.patch,
    95c6cc34-selinux.patch
* Tue May 21 2013 jfehlig@suse.com
- Update to libvirt 1.0.5.1 stable release
  - qemu: Fix cgroup handling when setting VCPU BW
  - daemon: fix leak after listing all volumes
  - Fix iohelper usage with streams opened for read
  - util: fix virFileOpenAs return value and resulting error logs
  - iscsi: don't leak portal string when starting a pool
  - don't mention disk controllers in generic controller errors
  - conf: don't crash on a tpm device with no backends
  - qemu: allocate network connections sooner during domain startup
  - Make detect_scsi_host_caps a function on all architectures
  - Fix release of resources with lockd plugin
  - Fix potential use of undefined variable in remote dispatch code
  - Fix F_DUPFD_CLOEXEC operation args
  - qemu: fix stupid typos in VFIO cgroup setup/teardown
  - network: fix network driver startup for qemu:///session
- Remove patches that are included in the 1.0.5.1 release
  0471637d-cgroups-vcpu-bw.patch, a2214c52-iohelper.patch,
  ca697e90-CVE-2013-1962.patch
* Mon May 20 2013 jfehlig@suse.com
- Don't mount selinux fs in LXC if selinux is disabled
  95c6cc34-selinux.patch
  bnc#814680
* Sat May 18 2013 jfehlig@suse.com
- fix leak after listing all volumes - CVE-2013-1962
  ca697e90-CVE-2013-1962.patch
  bnc#820397
- Fix iohelper usage with streams opened for read
  a2214c52-iohelper.patch
- Cope with missing swap cgroup controls
  f493d83f-cgroup-swap-control.patch
  bnc#819976
- Fix cgroup handling when setting VCPU BW
  0471637d-cgroups-vcpu-bw.patch
  rhb#963592
- Escape a leading '.' with '_' in the cgroup names
  0ced83dc-cgroup-escape-dot.patch
- Add missing documentation on new cgroup layout
  486a86eb-cgroups-docs.patch
- Another fix related to systems with no cgroups
  c2cf5f1c-no-cgroups-fix.patch
  bnc#819963
* Thu May 16 2013 jfehlig@suse.com
- Fix botched backport of commit bbe97ae9
* Mon May 13 2013 jfehlig@suse.com
- Fix starting domains when kernel has no cgroups support
  bbe97ae9-no-cgroups.patch
* Thu May  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.5
  - PPC64: Add NVRAM device
  - Add XML config for resource partitions
  - Add support for TPM
  - NPIV storage migration support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Tue Apr  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.4
  - qemu: support passthrough for iscsi disks
  - various S390 improvements
  - various LXC bugs fixes and improvements
  - add API for thread cancellation
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: ce4557c3-apparmor-tapfd-label.patch
    libvirt-iptables-1.4.18.diff
* Sun Mar 24 2013 seife+obs@b1-systems.com
- add libvirt-iptables-1.4.18.diff, fix masquerading with iptables
  v1.4.18 (--state match is deprectated, use conntrack instead)
* Fri Mar  8 2013 jfehlig@suse.com
- Fix PCI device attach for xen HVM domains
  fix-pci-attach-xen-driver.patch
  FATE#313570
* Fri Mar  8 2013 jfehlig@suse.com
- Apparmor security driver: Ensure tapfd's are labled when
  generating the guest profile.
  Modified install-apparmor-profiles.patch, added upstream patch
  ce4557c3-apparmor-tapfd-label.patch
  bnc#807940
* Thu Mar  7 2013 jfehlig@suse.com
- Grant permission to use datagram packets in libvirtd apparmor
  profile.
  Remove AF_PACKET.patch, modify install-apparmor-profiles.patch
  bnc#801145
* Wed Mar  6 2013 jfehlig@suse.com
- Add 'managed' PCI passthrough support to legacy xen driver
  support-managed-pci-xen-driver.patch
  FATE#313570
* Tue Mar  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.3
  - Introduce virDomainMigrate*CompressionCache APIs
  - Introduce virDomainGetJobStats API
  - Add basic support for VDI images
  - Introduce API virNodeDeviceLookupSCSIHostByWWN
  - Various locking improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: a6b8bae5-python-generator-fix1.patch,
    25ea8e47-python-generator-fix2.patch,
    567779e5-libxl-default-disk-backend.patch
* Fri Mar  1 2013 jfehlig@suse.com
- Fix path to qemu-bridge-helper in libvirt-qemu apparmor profile
  Modified install-apparmor-profiles.patch
* Mon Feb 25 2013 jfehlig@suse.com
- Fix detach of managed PCI devices from inactive domains.
  Detected while running test cases for FATE #313570.
  Modified xen-name-for-devid.patch
* Thu Feb 21 2013 jfehlig@suse.com
- spec: Fix installation of default network
* Wed Feb 20 2013 jfehlig@suse.com
- Fix default setting of backend field of libxl_device_disk
  567779e5-libxl-default-disk-backend.patch
  rhb#912488
* Tue Feb 12 2013 jfehlig@suse.com
- Fix build on IA64
  Modified clone.patch
* Thu Feb  7 2013 jfehlig@suse.com
- Fix error handling in python bindings
  a6b8bae5-python-generator-fix1.patch
  25ea8e47-python-generator-fix2.patch
  bnc#802619
* Sun Feb  3 2013 crrodriguez@opensuse.org
- Require modutils instead of module-init-tools.
* Wed Jan 30 2013 jfehlig@suse.com
- Update to libvirt 1.0.2
  - LXC improvements
  - S390 architecture improvements
  - Power architecture improvements
  - large Coverity report cleanups and associated bug fixes
  - virTypedParams* APIs to help with those data structures
  - libxenlight driver improvements
  - Fixes CVE-2013-0170, bnc#800976
  - Drop upstream patches: 68e7bc45-libxl-link-fix.patch,
    462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
    5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
    66ff2ddc-virtlockd-systemd-file-perms.patch
* Tue Jan 22 2013 jfehlig@suse.com
- Unconditionally build sanlock support
  bnc#799262
* Tue Jan 22 2013 jfehlig@suse.com
- Fix interface management functions that were broken when
  rebasing libvirt-suse-netcontrol.patch
  bnc#799444 (SLES bug that affect Factory too)
* Sat Jan  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.1
  - Introduce virtlockd daemon
  - parallels: add disk and network device support
  - Add virDomainSendProcessSignal API
  - Introduce virDomainFSTrim() public API
  - add fuse support for libvirt lxc
  - Add Gluster protocol as supported network disk backend
  - various snapshot improvements
- Add upstream patches to fix bugs in 1.0.1
  66ff2ddc-virtlockd-systemd-file-perms.patch,
  462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
  5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
  68e7bc45-libxl-link-fix.patch
- Rework SUSE patches for the various init scripts
  Dropped use-init-script-redhat.patch and added
  libvirtd-init-script.patch, libvirt-guests-init-script.patch,
  and virtlockd-init-script.patch
* Fri Nov  2 2012 jfehlig@suse.com
- Update to libvirt 1.0.0
  - virNodeGetCPUMap: Define public API
  - Add systemd journal support
  - Add a qemu capabilities cache manager
  - USB migration support
  - various improvement and fixes when using QMP QEmu interface
  - Support for Xen 4.2 in legacy xen driver
  - Lot of localization enhancements
  - Drop upstream patches: 371ddc98-xen-sysctl-9.patch,
    416eca18-xenstore-header-fix.patch,
    f644361b-virCommand-env.patch, 2b32735a-virCommand-env.patch,
    9785f2b6-fix-xen-sysctl9.patch
* Tue Oct 23 2012 jfehlig@suse.com
- Fix Xen sysctl version 9 support
  9785f2b6-fix-xen-sysctl9.patch
* Thu Oct 11 2012 jfehlig@suse.com
- Add upstream patches to support latest libguestfs
  f644361b-virCommand-env.patch
  2b32735a-virCommand-env.patch
* Thu Sep 27 2012 jfehlig@suse.com
- Fix build when using -werror
  416eca18-xenstore-header-fix.patch
* Wed Sep 26 2012 jfehlig@suse.com
- Support Xen sysctl version 9
  371ddc98-xen-sysctl-9.patch
  bnc#781425
* Tue Sep 25 2012 jfehlig@suse.com
- Temporarily disable building libxl driver.  The current
  implementation does not support libxl in Xen 4.2.
* Tue Sep 25 2012 jfehlig@suse.com
- Update to libvirt 0.10.2
  - network: define new API virNetworkUpdate
  - add support for QEmu sandbox support
  - blockjob: add virDomainBlockCommit
  - node_memory: Define the APIs to get/set memory parameters
  - list: Define new API virConnectListAllSecrets
  - list: Define new API virConnectListAllNWFilter
  - list: Define new API virConnectListAllNodeDevices
  - list: Define new API virConnectListAllInterfaces
  - list: Define new API virConnectListAllNetworks
  - list: Define new API virStoragePoolListAllVolumes
  - list: Define new API virStorageListAllStoragePools
  - parallels: add support of containers to the driver
  - Add PMSUSPENDED life cycle event
  - Add per-guest S3/S4 state configuration
  - qemu: Support for Block Device IO Limits
* Fri Sep  7 2012 jfehlig@suse.com
- Update to libvirt 0.10.1
  - Bug fix release for critical bugs in 0.10.0
  - Drop upstream patch f781e276-xen-driver-fix.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Update to libvirt 0.10.0
  - agent: add qemuAgentArbitraryCommand()
  - Introduce virDomainPinEmulator and virDomainGetEmulatorPinInfo
  - network: use firewalld instead of iptables, when available
  - network: make network driver vlan-aware
  - esx: Implement network driver
  - driver for parallels hypervisor
  - Various LXC improvements
  - Add virDomainGetHostname
  - Drop upstream patches
    4036aa91-systemd.patch
    6039a2cb-CVE-2012-3445.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Fix xen driver following changes to make it stateful
  f781e276-xen-driver-fix.patch
  bnc#778006
* Wed Aug  8 2012 jfehlig@suse.com
- Update to libvirt 0.9.13
  - S390: support for s390(x)
  - snapshot: implement new APIs for esx and vbox
  - snapshot: new query APIs and many improvements
  - virsh: Allow users to reedit rejected XML
  - nwfilter: add DHCP snooping
  - storage backend: Add RBD (RADOS Block Device) support
  - sVirt support for LXC domains inprovement
  - Drop upstream patches
    0dda594d-libvirtd-shutdown-deadlock.patch
    9c77bf04-fix-virnetserver-refcnt.patch
    57349ffc-lxc-ctrl.patch
    revert-d8978c90.patch
* Tue Aug  7 2012 jfehlig@suse.com
  _ Update to libvirt 0.9.12
  - qemu: allow snapshotting of sheepdog and rbd disks
  - blockjob: add new AP
  - many bug fixes and improvements
* Wed Aug  1 2012 jfehlig@suse.com
- daemon: Fix crash in virTypedParameterArrayClear
  CVE-2012-3445
  6039a2cb-CVE-2012-3445.patch
  bnc#773955
* Tue Jul 10 2012 jfehlig@suse.com
- libvirtd.service: ensure libvirtd starts after network
  4036aa91-systemd.patch
  bnc#767932
* Fri Jun 22 2012 jfehlig@suse.com
- Add upstream patch to fix ref count of virNetServer object
  9c77bf04-fix-virnetserver-refcnt.patch
* Thu Jun 21 2012 jfehlig@suse.com
- Fix libvirtd deadlock on shutdown
  0dda594d-libvirtd-shutdown-deadlock.patch
  bnc#767797
* Thu Jun 21 2012 jfehlig@suse.com
- Fix segfault in libvirt_lxc
  57349ffc-lxc-ctrl.patch
  bnc#767448
* Wed Jun 20 2012 jfehlig@suse.com
- Fix build on i586
  revert-d8978c90.patch
* Tue Jun 19 2012 jfehlig@suse.com
- Update to libvirt 0.9.11.4 stable release
* Tue Jun 12 2012 jfehlig@suse.com
- VUL-1: Fix hotplug support for usb devices with same vendorID,
  productID
  9914477e-usb-search-funcs.patch
  05abd150-usb-improve-hotplug.patch
  bnc#766559
* Wed May 30 2012 jfehlig@suse.com
- Add capability 'audit_write' to libvirtd apparmor profile
  update install-apparmor-profiles.patch
  bnc#764388
- Update to libvirt 0.9.11.3 stable release
* Wed Apr 25 2012 jfehlig@suse.com
- Copy user in virURIParse
  4eb1c256-viruri-user.patch
  bnc#757766
* Wed Apr 25 2012 jfehlig@suse.com
- yajl is availabile in all supported SUSE products, so always
  use it when building libvirtd
* Thu Apr 12 2012 jfehlig@suse.com
- Update to libvirt 0.9.11
  - Add support for the suspend event
  - Add support for event tray moved of removable disks
  - qemu: Support numad
  - cpustats: API, improvements and qemu support
  - qemu: support type='hostdev' network devices at domain start
  - Introduce virDomainPMWakeup API
  - network: support Open vSwitch
  - snapshot improvements
* Mon Mar 26 2012 jfehlig@suse.com
- Remove unconditional define of 'with_netcontrol'
* Thu Feb 16 2012 jfehlig@suse.com
- Add a note in /etc/libvirt/qemu.conf describing administrator
  vigilance required when enabling a lock manager such as sanlock
* Thu Feb 16 2012 jfehlig@suse.com
- Recommend dmidecode if suse_version > 1110.  dmidecode is used
  by virConnectGetSysinfo.
* Thu Feb 16 2012 jfehlig@suse.com
- Add upstream patches to fix issues with older PolicyKit
  c05ec920-polkit0-build.patch
  fcdfa31f-polkit0-auth.patch
* Wed Feb 15 2012 jfehlig@suse.com
- Update to libvirt 0.9.10
  - Add support for sVirt in the LXC driver
  - Add new API virDomainBlockRebase
  - Add api to set and get domain metadata
  - virDomainGetDiskErrors public API
  - Add rawio attribute to disk element of domain XML
  - Introduce virDomainPMSuspendForDuration API
  - Add virStorageVolResize() API
  - Add a virt-host-validate command to sanity check HV config
  - Add new virDomainShutdownFlags API
  - QEMU guest agent support
* Wed Feb  8 2012 jfehlig@suse.com
- Fix libvirtd apparmor profile to work with libxenlight toolstack
  Updated install-apparmor-profiles.patch
  bnc#745890
* Wed Jan 25 2012 jfehlig@suse.com
- Fix init script packaging after enabling systemd support
* Tue Jan 24 2012 jfehlig@suse.com
- Fix %%files after enabling sanlock support
* Wed Jan 18 2012 jfehlig@suse.com
- Enable libvirt integration with sanlock
* Wed Jan 11 2012 jfehlig@suse.com
- During configure, libvirt checks for availability of iptables
  binary and doesn't actually use anything from iptables-devel
  package, hence only need 'BuildRequires: iptables'.
* Mon Jan  9 2012 jfehlig@suse.com
- Update to libvirt 0.9.9
  - Add new API virDomain{S,G}etInterfaceParameters
  - Add new API virDomain{G,S}etNumaParameters
  - Add support for ppc64 qemu
  - Support Xen domctl v8
* Wed Jan  4 2012 jfehlig@suse.com
- Fixup systemd support as per openSUSE systemd packaging
  guidelines.
* Tue Jan  3 2012 jfehlig@suse.com
- Use %%fdupes for duplicate file checking instead of hand-rolled
  function
* Thu Dec 15 2011 jfehlig@suse.com
- CVE-2011-4600: unintended firewall port exposure after restarting
  libvirtd when defining a bridged forward-mode network
  ae1232b2-CVE-2011-4600.patch
  bnc#736082
- Post-0.9.8 upstream systemd patches
  10404671-systemd-build-fix.patch 478a4d07-systemd-build-fix.patch
- Update to libvirt 0.9.8
  - Add support for QEMU 1.0
  - Add first parts of PPC cpu driver
  - Add new API virDomain{Set, Get}BlockIoTune
  - block_resize: Define the new API
  - Add a public API to invoke suspend/resume on the host
  - Various improvements for LXC containers
  - Define keepalive protocol and add virConnectIsAlive API
  - Add support for STP and VLANfiltering
  - Numerous bug fixes and improvements
* Wed Dec 14 2011 jfehlig@suse.com
- Add support for QEMU 1.0
  dd8e8956-qemu-1.0.patch
  bnc#736569
* Wed Nov 30 2011 jfehlig@suse.com
- Allow qemu driver (and hence libvirtd) to load when qemu
  user:group does not exist.  The kvm or qemu package, which may
  not exist on a xen host, creates qemu user:group.
  relax-qemu-usergroup-check.patch
* Mon Nov 28 2011 jfehlig@suse.com
- Handle empty strings in s-expression returned by xend
  a495365d-sexpr-empty-str.patch
  bnc#731344
- Allow libvirtd to access libvirt_{io,part}helper when confined
  by apparmor
  Update install-apparmor-profiles.patch
  bnc#730435
* Mon Nov 21 2011 jfehlig@suse.com
- Accommodate Xen domctl version 8
  xen-domctl-ver8.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 jfehlig@suse.com
- Fix build when using older PolicyKit
  d47ab3fe-polkit0.patch
* Thu Nov 10 2011 jfehlig@suse.com
- Update to libvirt 0.9.7
  - esx: support vSphere 5.x
  - vbox: support for VirtualBox 4.1
  - Introduce the virDomainOpenGraphics API
  - Add AHCI support to qemu driver
  - snapshot: many improvements and 2 new APIs
  - api: Add public api for 'reset'
* Tue Oct 18 2011 jfehlig@suse.com
- Add AHCI controller support to qemu driver
  c1bc3d89-qemu-add-ahci.patch
- Set security driver to 'none' in /etc/libvirt/qemu.conf.  Users
  must opt-in for Apparmor confinement of qemu instances.
  suse-qemu-conf.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Revert upstream commit f84aedad, which is not needed since
  affected SUSE kvm packages have the necessary qemu fix
  f84aedad-revert.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Update to libvirt 0.9.6
  - Fix shutdown regression with buggy qemu
* Wed Sep 21 2011 andrea.turrini@gmail.com
- Fixed typos in libvirt.spec
* Tue Sep 20 2011 jfehlig@suse.com
- Update to libvirt 0.9.5
  - many snapshot improvements
  - latency: Define new public API and structure
  - USB2 and various USB improvements
  - storage: Add fs pool formatting
  - Add public API for getting migration speed
  - Add basic driver for Microsoft Hyper-V
  - Many bug fixes and improvements
* Fri Sep 16 2011 jfehlig@suse.com
- Enable building with libnetcontrol
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Wed Sep 14 2011 jfehlig@suse.com
- Set qemu migration speed unlimited when migrating to file
  7e5f6a51-rpc-generator.patch b12354be-mig-speed-1.patch
  1282bd80-mig-speed-2.patch 6f84e110-mig-speed-3.patch
  829bce17-mig-speed-4.patch 8fc40c51-mig-speed-5.patch
  ef1065cf-mig-speed-6.patch 0257ba8f-mig-speed-7.patch
  bnc#706436
* Wed Sep 14 2011 jfehlig@suse.com
- Increase max size of buffer used to receive xend response
  57c95175-xend-buff-size.patch
- Don't overwrite useful error messages in legacy xen driver
  32620dab-fix-xen-err-msg.patch
  bnc#711096
* Wed Sep 14 2011 jfehlig@suse.com
- Add upstream patches to stop excessive logging
  7f2498ef-no-log-invalid.patch 6ff9fc26-quiet-libxl-logging.patch
* Wed Sep 14 2011 jfehlig@suse.com
- Add 'Conflicts: kvm < 0.14.1' to ensure libvirt is using a
  kvm package that creates qemu user:group.  Remove user:group
  creation from libvirt
  bnc#694883
- Add libvirt group at package installation
  bnc#694885
* Thu Sep  8 2011 jfehlig@suse.com
- Explicitly add 'BuildRequires: libgcrypt-devel' since it is no
  longer required by libgnutls-devel
* Thu Sep  8 2011 jfehlig@suse.com
- netcf is buggy and not well maintained in SUSE.  Disable it in
  libvirt
* Thu Sep  8 2011 jfehlig@suse.com
- polkit support was mistakenly disabled, re-enable
* Thu Aug 25 2011 jfehlig@novell.com
- Add cgconfig to Should-{Start,Stop} in libvirtd init script
  bnc#712245
* Fri Aug 19 2011 jfehlig@suse.com
- Fix apparmor profile location and content
  update install-apparmor-profiles.patch
  bnc#705668
* Wed Aug 17 2011 jfehlig@suse.com
- Fix libvirtd SIGHUP handler
  9e093f0b-libvirtd-sighup.patch
* Wed Aug 17 2011 dmueller@suse.de
- add baselibs.conf to sources
* Mon Aug  8 2011 jfehlig@suse.com
- Enable apparmor security dirver, SLES bnc#705668
  install-apparmor-profiles.patch
* Thu Aug  4 2011 jfehlig@suse.com
- Update to libvirt 0.9.4
  - bandwidth QoS control
  - Add new API virDomainBlockPull*
  - save: new API to manipulate save file images
  - CPU bandwidth limits support
  - allow to send NMI and key event to guests
  - new API virDomainUndefineFlags
  - Implement code to attach to external QEMU instances
  - various missing python binding
  - bios: Add support for SGA
  - Numerous improvements and documentation / bug fixes
* Wed Jul 13 2011 jfehlig@suse.de
- Add some upstream patches to fix memory leaks and some bugs
  in new rpc code
  c2ddd536-cert-key-order.patch 3e5d48ef-rpc-1.patch
  927dfcf6-rpc-2.patch 2c85644b-rpc-3.patch afe8839f-rpc-4.patch
  3cfdc57b-rpc-5.patch 7518ad75-remote-mem-leak.patch
  a34e193f-statstest.patch 41828514-skip-xen-tests.patch
  eb314315-pv-kernel-cmdline.patch 00d3c5a6-remove-dead-code.patch
  b8adfcc6-fix-polkit0-build.patch b2534529-unused-param.patch
* Tue Jul  5 2011 jfehlig@suse.de
- Update to libvirt 0.9.3
  - vcpupin: introduce the new libvirt API (virDomainGetVcpupinInfo)
  - Add TXT record support for virtual DNS service
  - Support reboots with the QEMU driver
  - Introduce virDomainGetControlInfo API
  - virNodeGetMemoryStats: Expose new API
  - virNodeGetCPUTime: Implement public API
  - send-key: Defining the public API
  - vcpupin: introduce a new libvirt API (virDomainPinVcpuFlags)
  - support multifunction PCI device
  - lxc: various improvements
* Fri Jul  1 2011 jfehlig@suse.de
- Create qemu user:group if necessary at package installation.
  More fallout from bnc#694883
* Thu Jun 30 2011 jfehlig@suse.de
- VUL-0: libvirt: integer overflow in VirDomainGetVcpus
  774b21c1-CVE-2011-2511.patch
  bnc#703084
* Thu Jun 30 2011 jfehlig@suse.de
- Enable building libvirt with audit support
  bnc#694891
* Mon Jun 13 2011 lidongyang@novell.com
- fate#311371 Enhance yast to configure live migration for
  Xen and KVM
  add firewall service file for libvirt
* Thu Jun  9 2011 jfehlig@suse.de
- Invoke qemu instances as user:group qemu:qemu by default
  bnc#694883
* Mon Jun  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.2
  - Framework for lock manager plugins
  - API for network config change transactions (netcf required)
  - flags for setting memory parameters
  - virDomainGetState public API
  - qemu: allow blkstat/blkinfo calls during migration
  - Introduce migration v3 API
  - Defining the Screenshot public API
  - public API for NMI injection
- spec file: Adjust some directory attributes to support running
  non-privileged qemu instances
* Sun May 15 2011 jfehlig@suse.de
- Remove vi_VN locale if suse_version < 11.3
* Thu May 12 2011 fcrozat@suse.com
- Enable cap_ng when building lxc support.
* Fri May  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.1
  - support various persistent domain updates
  - improvements on memory APIs
  - Add virDomainEventRebootNew
  - various improvements to libxl drive
  - Spice: support audio, images and stream compression
* Tue Apr 12 2011 jfehlig@suse.de
- Move libvirt-iohelper from client to base package
* Tue Apr 12 2011 coolo@opensuse.org
- fix baselibs.conf not to requires source 32bit
* Mon Apr 11 2011 jfehlig@suse.de
- Install log dir for libxl
  f7e9b448-libxl-build.patch
* Mon Apr  4 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 final
  - Support cpu usage tuning
  - Add public APIs for storage volume upload/download
  - Add public API for setting migration speed on the fly
  - Add libxenlight driver
  - qemu: support migration to fd
  - add virDomain{Get,Set}BlkioParameters
  - introduce a new libvirt API (virDomainSetMemoryFlags)
  - Expose event loop implementation as a public API
  - Dump the debug buffer to libvirtd.log on fatal signal
  - Audit support
  - Numerous enhancements and bug fixes
* Thu Mar 31 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 RC3
* Thu Mar 24 2011 coolo@novell.com
- use %%first_lang before changing symlinks, find_lang removes
  unsupported languages
* Tue Mar 15 2011 jfehlig@novell.com
- VUL-0: libvirt: several API calls do not honour read-only
  connection
  71753cb7-CVE-2011-1146.patch
  bnc#678406
* Mon Mar  7 2011 jfehlig@novell.com
- Add baselibs.conf file to build xxbit packages
  for multilib support
  bnc#676921
* Fri Feb 25 2011 jfehlig@novell.com
- Minor fixes for libvirt-guests
  bnc#653398
* Fri Feb 18 2011 jfehlig@novell.com
- Do not add drive 'boot=on' param when a kernel is specified
  efc2594b-boot-param.patch
* Thu Feb 17 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 final
  - sysinfo: expose new API
  - cgroup blkio weight support
  - smartcard device support
  - qemu: Support per-device boot ordering
* Tue Feb 15 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC3
* Fri Feb 11 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC1
* Mon Jan 31 2011 jfehlig@novell.com
- Remove explicit dependency on libyajl
  libvirt.spec
  bnc#668225
* Fri Jan 21 2011 jfehlig@novell.com
- Retry JSON monitor 'cont' cmd on MigrationExpected error
  4301b95a-json-cont-cmd.patch
* Tue Jan 18 2011 jfehlig@novell.com
- Add support for specifying Hardware Assisted Paging (HAP) in
  libvirt domain XML.
  48a5dccd-hap1.patch
  04197350-hap2.patch
  af521a01-hap3.patch
  79f56c66-hap4.patch
  094c6f4a-hap-fix.patch
  bnc#659665
* Tue Jan 18 2011 jfehlig@novell.com
- Enabled yajl for suse_version >= 1140
* Fri Jan 14 2011 jfehlig@novell.com
- Fix generation of dnsmasq's --dhcp-hostsfile option
  a43c7338-dnsmasq-hostfile-fix.patch
- Disable yajl support as the library does not yet exist in
  SuSE distros.
* Tue Jan 11 2011 jfehlig@novell.com
- Support libvirt-guests on SuSE distros
  use-libvirt-guests-on-suse.patch
  bnc#653398
* Mon Jan  3 2011 jfehlig@novell.com
- Update to libvirt 0.8.7
  - Preliminary support for VirtualBox 4.0
  - IPv6 support
  - Add VMware Workstation and Player driver
  - Add network disk support
* Wed Dec 22 2010 jfehlig@novell.com
- Fix VNC port reservation race in qemu driver
  c58b1056-init-bitmap-size.patch
  bnc#659431
* Fri Dec 10 2010 jfehlig@novell.com
- Do not limit insserv_cleanup to SLES
* Thu Dec  9 2010 jfehlig@novell.com
- disable building openvz driver
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.6
  - new API virDomainIsUpdated
  - Add support for iSCSI target auto-discovery
  - QED: Basic support for QED images
  - Introduce a virDomainOpenConsole API
  - Support for SPICE graphics
  - Add a sysinfo and SMBIOS support
  - Implement virsh qemu-monitor-command
- Enabled yajl, macvtap, and virtualport for suse_version >= 1140
* Mon Nov  1 2010 jfehlig@novell.com
- Fix build when using "policy kit 0"
  polkit0.patch
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.5
  - Enable JSON and netdev features in QEMU > 0.13
  - framework for auditing integration
  - framework for DTrace/SystemTap integration
  - Setting the number of vcpu at boot
  - Enable support for nested SVM
  - Virtio plan9fs filesystem QEMU
  - Memory parameter controls
  - portability to OS-X
  - lot of bug fixes and other improvements
* Wed Oct 13 2010 jfehlig@novell.com
- cannot restart dead libvirtd without manually removing pidfile
  modified libvirtd.init
  bnc#645755
* Mon Oct 11 2010 cristian.rodriguez@opensuse.org
- Fix package dependencies so can be installed without
  pulling excess of optional components
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Support dropping capabilities with cap-ng library in
  openSUSE >= 11.3
* Tue Sep 28 2010 jfehlig@novell.com
- Fix build when virtualport support is available but macvtap is
  disabled.
  vport-configure.patch
* Thu Sep 23 2010 jfehlig@novell.com
- Fix CDROM media change for Xen PV domains
  modified xen-pv-cdrom.patch
  bnc#636231
* Fri Sep 10 2010 jfehlig@novell.com
- Update to libvirt 0.8.4
  - various improvements to UML driver
  - documentation improvements
  - lot of bug fixes and other improvements
  - enable ESX driver for openSUSE
* Sat Aug  7 2010 jfehlig@novell.com
- Update to libvirt 0.8.3
  - Support vSphere 4.1
  - Qemu arbitrary monitor commands
  - Qemu Monitor API entry point
  - lots of improvements and bug fixes
* Fri Jul  9 2010 jfehlig@novell.com
- VUL-0: multiple issues in libvirt
  CVE-2010-223x-000[1-0].patch, CVE-2010-223x-0010.patch,
  CVE-2010-2242-nat.patch
  bnc#618155
* Fri Jun 25 2010 jfehlig@novell.com
- Use netcat-openbsd, which contains a proper 'nc' program
  supporting the '-U' option.  Drop socat.patch.
  bnc#611023
* Mon Jun 21 2010 jfehlig@novell.com
- Re-enable numa support now that bnc#598488 is resolved.
* Fri Jun  4 2010 jfehlig@novell.com
- Allocate buffer to hold xend content
  bnc#609738
  xend-buff-size.patch
- Add upstream fixes to bitmap code that was introduced to fix
  bnc#594024
  bitmap-alloc.patch
  bitmap-fixes.patch
* Tue Jun  1 2010 jfehlig@novell.com
- Fix race in VNC port reservation with qemu/KVM domains
  bnc#594024
  vnc-race-{1,2,3}.patch
* Wed May 12 2010 jfehlig@novell.com
- Don't package directories/files under /var/run
- Add upstream commit 34a7f3f6 to fix unintentional breakage of
  RPC protocol.
- Disable numa support in openSUSE11.3/Factory pending resolution
  of bnc#598488
* Fri Apr 30 2010 jfehlig@novell.com
- Update to libvirt 0.8.1
  - Add virDomainGetBlockInfo API to query disk sizing
  - Start dnsmasq from libvirtd with --dhcp-hostsfile option
  - lots of improvements and bug fixes
* Tue Apr 13 2010 jfehlig@novell.com
- Update to libvirt 0.8.0
  - Snapshot API framework
  - Add managed save API entry points
  - Timer subselection for domain clock
  - Add hook utilities
  - Network filtering API
  - Introduce a new virDomainUpdateDeviceFlags public API
  - Introduce a new public API for domain events
  - Public virDomainMigrateSetMaxDowntime API
  - Add public API for volume wiping
  - xenapi: Initial commit of the new driver
  - lots of improvements and bug fixes
* Fri Mar 26 2010 jfehlig@novell.com
- Fix 'virsh dominfo' crash when no security driver is configured
  fix-no-secdriver.patch
* Mon Mar 22 2010 jfehlig@novell.com
- Updated to version 0.7.7
  - Introduce public API for domain async job handling
  - macvtap support
  - Add QEMU support for virtio channel
  - Add persistence of PCI addresses to QEMU
  - Functions for computing baseline CPU from a set of host CPUs
  - Public API for virDomain{Attach,Detach}DeviceFlags
  - lots of improvements and bug fixes
* Tue Mar  9 2010 jfehlig@novell.com
- Ensure yast-created bridges are not manipulated by libvirt
  bnc#584757
  Modified suse-network.patch
* Thu Mar  4 2010 jfehlig@novell.com
- Fix ordering of xen disks to preserve 'bootable' flag
  bnc#474738
  xend-disk-order.patch
- Add support for blktap2 disks
  xen-tap2-support.patch
* Mon Mar  1 2010 jfehlig@novell.com
- Fix listing of yast-created bridges
  bnc#583754
  Modified suse-network.patch
* Mon Feb 22 2010 jfehlig@novell.com
- Add support for new XEN_DOMCTL_INTERFACE_VERSION version 7.
  xen-domctl-ver7.patch
* Mon Feb 15 2010 jfehlig@novell.com
- Unconditionally add /var/log/libvirt/{qemu,lxc,uml} directories.
  bnc#579522
* Thu Feb  4 2010 jfehlig@novell.com
- Updated to version 0.7.6
  - Implement support for multi IQN
  - Implement CPU topology support for QEMU driver
  - Use QEmu new device adressing when possible
  - Implement SCSI controller hotplug/unplug for QEMU
  - lots of improvements and bug fixes
* Thu Jan 28 2010 jfehlig@novell.com
- Support new XEN_SYSCTL_INTERFACE_VERSION 7 in libvirt
  bnc#574124
  xen-sysctl-v7.patch
- Add upstream patches as prelude to fixing various device
  attach/detach issues
  devflag-0[1-9].patch
- Fix attaching/detaching disk device from inactive Xen guest
  bnc#500586 and bnc#573748
* Tue Jan 12 2010 jfehlig@novell.com
- Fix migration with Xen4.0
  bnc#569598
  Add xen-migration-params.patch
  Remove migrate-params.patch
* Thu Jan  7 2010 jfehlig@novell.com
- Fix freeing of uninitialized pointer when using HAL in
  node device driver
  node-dev-free.patch
* Mon Jan  4 2010 jfehlig@novell.com
- Require virt-utils package for common tools such as qemu-img
* Tue Dec 29 2009 jfehlig@novell.com
- Updated to version 0.7.5
  - Add new API virDomainMemoryStats to header and drivers
  - Public API and domain extension for CPU flags
  - expose SR IOV physical/virtual function relationships
  - Support for JSON mode monitor [deactivated]
  - Support for interface model='netfront'
  - vbox: Add support for version 3.1
  - Support QEMU's virtual FAT block device driver
  - lots of improvements and bug fixes
- Fix libvirt xen hypervisor driver to work with domctl interface
  version 6
  xen-shr-pages.patch
* Mon Dec  7 2009 jfehlig@novell.com
- Plumb domain description in xend backend
  xend-description-tag.patch
* Wed Nov 25 2009 jfehlig@novell.com
- Fix listing of defined but inactive Xen domains
  xen-list-defined.patch
* Tue Nov 24 2009 jfehlig@novell.com
- Updated to version 0.7.4
  - Implement a node device backend using libudev
  - New APIs for checking some object properties
  - Fully asynchronous monitor I/O processing
  - add MAC address based port filtering to qemu
  - support for IPv6 / multiple addresses per interfaces
  - lots of improvements and bug fixes
* Thu Nov 19 2009 jfehlig@novell.com
- Fix compilation against xen-unstable
  xen-max-vcpus.patch
- Modify detach-disk.patch as per upstream suggestions
* Thu Nov  5 2009 jfehlig@novell.com
- spec file: Fix polkit vs PolicyKit Requires
* Mon Oct 19 2009 jfehlig@novell.com
- Fix compilation when selinux is enabled
  selinux-ldflags.patch
- Fix compilation warnings
  updated snapshots.patch
  virsh-warning.patch
* Fri Oct 16 2009 jfehlig@novell.com
- Updated to version 0.7.2
  - sVirt AppArmor security driver
  - Add public API definition for data stream handling
  - ESX add esxDomainDefineXML()
  - LXC: suspend/resume support
  - Big code tree cleanup
  - Lots of bug fixes and improvements
* Tue Oct 13 2009 jfehlig@novell.com
- Add ocfs2 to list of supported fs pool types
  fate#307387
* Tue Oct 13 2009 jfehlig@novell.com
- Build phyp driver ifarch ppc64
  fate#307096
- Fix memory leaks in libvirtd's message processing
  msg-proc-memleak.patch
* Tue Sep 29 2009 jfehlig@novell.com
- Fix connection ref counting in xen drivers
  xen-refcnt.patch
* Fri Sep 25 2009 jfehlig@novell.com
- Fix abort in virsh when specifying a connection URI
  vshdeinit-recurse.patch
* Wed Sep 23 2009 jfehlig@novell.com
- Workaround for missing pkgconfig file in device-mapper-devel
  devmap-no-pkgconfig.patch
  bnc#540942
* Mon Sep 21 2009 jfehlig@novell.com
- Updated to version 0.7.1
  - Add support for encrypted (qcow) volume creation
  - Secret manipulation public API
  - Multipath storage support module
  - VBox add Storage Volume support
  - Support configuration of huge pages in guests
  - Support new PolicyKit 1.0 API
  - Compressed save image format for Qemu
  - Qemu add host PCI device hotplug support
* Wed Aug 26 2009 jfehlig@novell.com
- Updated to version 0.7.0
  - Interface implementation based on netcf (disabled on SuSE)
  - Add new net filesystem glusterfs
  - Initial VMWare ESX driver
  - Add support for VBox 3 and event callbacks on vbox
  - First version of the Power Hypervisor driver
  - Run QEMU guests as an unprivileged user (still root on SuSE)
  - Support cgroups in QEMU driver
  - QEmu hotplug NIC support
  - Storage cloning for LVM and Disk backends
* Tue Jul  7 2009 jfehlig@novell.com
- Updated to version 0.6.5
  - create storage volumes on disk backend
  - drop of capabilities based on libcap-ng when possible
  - forbid autostart on transcient networks
  - re-detection of transient VMs after libvirtd restart
  - create and destroy NPIV support
  - other bug fixes and cleanups
* Fri Apr 24 2009 jfehlig@novell.com
- Removed unnecessary call to fillup_and_insserv macro in
  %%post scriptlet
* Wed Apr 22 2009 jfehlig@novell.com
- Updated to version 0.6.2
  - support SASL auth for VNC server
  - memory ballooning in QEMU
  - SCSI HBA storage pool support
  - PCI passthrough in Xen driver
  - new APIs for Node device detach reattach and reset
  - sVirt mandatory access control support
  - thread safety of the API and event handling
  - allow QEmu domains to survive daemon restart
  - extended logging capabilities
  - support copy-on-write storage volumes
  - support of storage cache control options for QEMU/KVM
- Improvements from lnussel@suse.de
  - add %%jobs macro again
  - package default qemu network and augeas config files again
  - don't start libvirtd by default (bnc#496838)
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of just removing static libraries
* Fri Jan 30 2009 jfehlig@novell.com
- Fix build for architectures not supporting numa
- Forward port suse-network.patch and snapshots.patch
* Wed Jan 28 2009 jfehlig@novell.com
- Updated to version 0.5.1
  - CPU and scheduler support for LXC
  - SDL display configuration
  - domain lifecycle event support for QEmu and Xen with python
    bindings
  - KVM/QEmu migration support
  - User Mode Linux driver
  - API for node device enumeration using HAL and DeviceKit with
    python bindings
  - Many bug fixes and improvements
* Fri Jan  9 2009 jfehlig@novell.com
- Added missing html and png files to libvirt-doc package
  devhelp.patch
  bnc#463810
* Mon Dec 15 2008 jfehlig@novell.com
- Patch for CVE-2008-5086
  bnc#459009
* Fri Dec  5 2008 jfehlig@novell.com
- Fix migration of Xen domains
  bnc#456946
* Tue Dec  2 2008 jfehlig@novell.com
- Refresh xen-maxmem.patch to match upstream
  bnc#431766
* Tue Nov 25 2008 jfehlig@novell.com
- Add network to Required-Start in libvirtd init script
  bnc#448756
* Mon Nov 24 2008 jfehlig@novell.com
- Fix connecting/disconnecting ISO via virt-manager
  bnc#446773
* Fri Nov 21 2008 jfehlig@novell.com
- Fix detach of Xen tap devices
  bnc#410644 and bnc#411633
* Fri Nov  7 2008 jfehlig@novell.com
- Fix handling of iso/cdrom for xen pv domains.
  bnc#437388
* Wed Nov  5 2008 jfehlig@novell.com
- Expose networks managed outside of libvirt as read-only.
  bnc#441633
* Wed Nov  5 2008 jfehlig@novell.com
- Fix vnc port assignement in domain XML
  bnc#441625
* Thu Oct 23 2008 jfehlig@novell.com
- Add upstream patches to fix ordering problem with setting up
  cgroup containment on LXC domains.
  bnc#437816
* Mon Oct 20 2008 jfehlig@novell.com
- Remove IA64 from list of architectures supporting Xen.
* Fri Oct 10 2008 jfehlig@novell.com
- Added upstream patches providing additional LXC support
  bnc#433881
* Mon Oct  6 2008 jfehlig@novell.com
- Use xend vs hypercall interface to change max mem setting
  bnc#431766
* Wed Oct  1 2008 jfehlig@novell.com
- Enabled libvirtd listen mode in libvirtd init script.
* Wed Oct  1 2008 jfehlig@novell.com
- Updated to version 0.4.6
  - avoid a segfault if missing qemu emulator
  - reading vncdisplay from xend domain
  - segfault in OpenVZ
  - fix parsing of pool without a source
- Fixed bug in network interface parsing
  - vif-parsing.patch submitted upstream
* Tue Sep 16 2008 jfehlig@novell.com
- open-iscsi package required for iscsi storage backend
* Mon Sep 15 2008 jfehlig@novell.com
- Updated to version 0.4.5
  - NETNS support for Linux containers
  - unified XML domain and network parsing for all drivers
  - OpenVZ features improvements
  - OpenVZ and Linux containers support now default
  - USB device passthrough for QEmu/KVM
  - storage pool source discovery
  - other bug fixes and improvements
* Thu Sep  4 2008 kwolf@suse.de
- Added Python bindings for the snapshot functions
* Wed Sep  3 2008 kwolf@suse.de
- Implemented listing of snapshots for Xen and in virsh
* Tue Sep  2 2008 kwolf@suse.de
- Added snapshot support. Implemented snapshot_create/apply/delete
  for Xen.
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in nfs storage pool creation/deletion
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in LVM storage pool creation.
  logical-storage-driver.patch submitted upstream
* Wed Aug 27 2008 jfehlig@novell.com
- Changed mDNS advertisement of libvirtd service to disabled by
  default.  Enable in libvirtd.conf.
- Disable libvirtd from listening on TLS socket by default.  User
  must enable after setting up CA and issuing certificates.
* Mon Aug 25 2008 jfehlig@novell.com
- Enabled iscsi storage driver support
- Enabled ssh transport using socat.  SuSE's version of netcat
  does not support connecting to UDS.
- Fixed spec file breakage due to SELinux enablement
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Tue Aug 12 2008 jfehlig@novell.com
- Cleanup of libvirtd init script
- Removed dnsmasq from BuildRequires
* Sat Aug  9 2008 jfehlig@novell.com
- Adjustments to spec file
  + Added /var/lib/libvirt directory
  + Enabled LXC support if suse_version > 1100, fate #304001
  + Cleaned up some rpmlint warnings
* Sun Jul  6 2008 jfehlig@novell.com
- Updated to libvirt 0.4.4
  + Bug fixes: QEmu network serialization, internal memory allocation
    fixes, virsh large file config problem, xen list APIs when max is
    zero, string escape problems in the xm driver
  + Improvements: add autogen to tarballs, improve iSCSI support
  + Cleanups: const-ness fixed, string helpers for enumeations
- spec file adjustments
  + Remove ExclusiveArch
  + Common spec file for all products
  + Support for building/running without Xen
* Fri May  9 2008 jfehlig@novell.com
- Adjust libvirtd PolicyKit configuration file to match standard
  suse procedures.  bnc#388769
* Mon May  5 2008 jfehlig@novell.com
- Fix path to iptables.  bnc#386280
* Thu Apr 24 2008 jfehlig@novell.com
- Fix Xen 3.2 hypercalls.  bnc#378798
* Thu Apr 10 2008 jfehlig@novell.com
- Fix NULL pointer dereference in auth callback.  bnc#373180,
  bnc#354995
* Wed Jan  9 2008 jfehlig@novell.com
- Remove Requires of nc package.  netcat is the equivalent but it
  does not support unix domain sockets so no need to require it
  either.
* Tue Jan  8 2008 coolo@suse.de
- do not require a non existant package, but change it to a recommend
  to digestmd5
* Fri Jan  4 2008 jfehlig@novell.com
- Updated to libvirt-0.4.0
  - SASL based authentication for libvirt remote support
  - PolicyKit authentication
  - Documentation: example files for QEMU and libvirtd configuations,
    authentication documentation updates
  - Bug fixes, improvements and code cleanup
* Tue Oct  9 2007 jfehlig@novell.com
- Updated to libvirt 0.3.3
  - Avahi mDNS daemon export
  - NUMA support
  - Bug fixes
- Cleanup rpmlint warnings
* Mon Oct  8 2007 jfehlig@novell.com
- Removed 'jobs' option from make invocation in spec file.  Appears
  to be a subtle dependency issue in one of the makefiles which is
  causing problems with generation of python bindings when jobs > 1.
  Bug #329032.
* Mon Aug 20 2007 jfehlig@novell.com
- Added init script for libvirtd.  libvirtd is needed to support
  management of qemu/kvm guests.  Some Xen networking is handled
  through libvirt as well - bug #298021.
* Mon Jul 23 2007 jfehlig@novell.com
- Update to libvirt-0.3.0
  - Secure Remote support
  - Documentation: remote support, description of the URI connection
    strings, update of virsh man page, matrix of libvirt API/hypervisor
    support with version informations
  - Bug fixes: examples Makefile.am generation, SetMem fix, URI
    handling and ordering of drivers, fix virsh help without hypervisor,
    id marshalling fix, fix virConnectGetMaxVcpus on remote, avoid
    a realloc leak, scheduler parameters handling for Xen, various
    early remote bug fixes, remove virsh leaks of domains references,
    configCache refill bug, fix XML serialization bugs
  - Improvements: QEmu switch to XDR-based protocol, device attach/detach
    commands OCaml bindings, new entry points virDomainGetConnect and
    virNetworkGetConnect useful for bindings, reunitifaction of remote
    and qemu daemon under a single libvirtd with a config file
  - Cleanups: parsing of connection URIs, messages from virsh,
    Coverage files, Solaris fixes, avoid [r]index calls, release
    information in Xen backend, virsh cpupin command cleanups,
    xen:/// suppport as standard Xen URI, improve driver
    selection/decline mechanism, error reporting on XML dump,
    Remove unused virDomainKernel structure, daemon event loop event
    handling, various unifications cleanup in the daemon merging,
    internal file and timer monitoring API, remove libsysfs dependancy,
    call brctl program directly, virBuffer functions cleanups,
    make init script LSB compliant, error handling on lookup functions,
    remove internal virGetDomainByID, revamp of xen subdrivers interfaces
  - Localization updates
* Tue Jun 12 2007 ccoffing@novell.com
- Update to libvirt-0.2.3.
- Fix duplicate files found by rpmlint.
* Wed May 23 2007 ccoffing@novell.com
- Fix rpmlint errors.
* Fri Apr 27 2007 ccoffing@novell.com
- Update to libvirt-0.2.2.
* Wed Mar  7 2007 sbrabec@suse.cz
- Created -doc subpackage (#248813).
- Do not remove valid locales.
- Fixed docdir destination.
- Build with CFLAGS.
- Spec file cleanup.
* Tue Feb 20 2007 jfehlig@novell.com
- Removed usr/lib/libvirt_proxy setuid binary from package.  Fixes
  bug #246610.
* Sat Feb 17 2007 jfehlig@novell.com
- Updated to latest release.  Many of the issues seen in virt-manager
  have been caused by bugs / missing functionality in libvirt.  This
  upate provides a better basis for virt-manager.
* Thu Jan 11 2007 jfehlig@novell.com
- Updated to latest release, version 0.1.10.  Submitting to SLES10 SP1
  to provide base functionality for FATE feature 301181.
  - more localizations
  - bug fixes:
  - VCPU info breakages on xen 3.0.3
  - xenDaemonListDomains buffer overflow (Daniel Berrange)
  - reference count bug when creating Xen domains (Daniel Berrange)
  - improvements:
  - support graphic framebuffer for Xen paravirt (Daniel Berrange)
  - VNC listen IP range support (Daniel Berrange)
  - support for default Xen config files and inactive domains of 3.0.4 (Daniel Berrange)
* Fri Dec  8 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.9.
  - python bindings: release interpeter lock when calling C (Daniel Berrange)
  - don't raise HTTP error when looking informations for a domain
  - some refactoring to use the driver for all entry points
  - better error reporting (Daniel Berrange)
  - fix OS reporting when running as non-root
  - provide XML parsing errors
  - extension of the test framework (Daniel Berrange)
  - fix the reconnect regression test
  - python bindings: Domain instances now link to the Connect to avoid garbage collection and disconnect
  - separate the notion of maximum memory and current use at the XML level
  - Fix a memory leak (Daniel Berrange)
  - add support for shareable drives
  - add support for non-bridge style networking configs for guests(Daniel Berrange)
  - python bindings: fix unsigned long marshalling (Daniel Berrange)
  - new config APIs virConfNew() and virConfSetValue() to build configs from scratch
  - hot plug device support based on Michel Ponceau patch
  - added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)
  - special device model for HVM guests (Daniel Berrange)
  - add API to dump core of domains (but requires a patched xend)
  - pygrub bootloader informations take over <os> informations
  - updated the localization strings
* Fri Oct 20 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.8.
  - Bug for system with page size != 4k
  - vcpu number initialization (Philippe Berthault)
  - don't label crashed domains as shut off (Peter Vetere)
  - fix virsh man page (Noriko Mizumoto)
  - blktapdd support for alternate drivers like blktap (Daniel Berrange)
  - memory leak fixes (xend interface and XML parsing) (Daniel Berrange)
  - compile fix
  - mlock/munlock size fixes (Daniel Berrange)
  - improve error reporting
- Updated to latest release, version 0.1.7.
  - fix a memory bug on getting vcpu informations from xend (Daniel Berrange)
  - fix another problem in the hypercalls change in Xen changeset
    86d26e6ec89b when getting domain informations (Daniel Berrange)
* Tue Sep 26 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.6.  This release includes
  fix in hypercall driver so local patch has been removed.
* Wed Sep 13 2006 jfehlig@novell.com
- Fixed bug in hypercall driver introduced in version 0.1.5.
  Patch sumbmitted upstream and included locally until next release.
* Mon Sep 11 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.5
  - Support for new hypercalls change in Xen changeset 86d26e6ec89b
  - bug fixes: virParseUUID() was wrong, netwoking for paravirt guestsi
    (Daniel Berrange), virsh on non-existent domains (Daniel Berrange),
    string cast bug when handling error in python (Pete Vetere), HTTP
    500 xend error code handling (Pete Vetere and Daniel Berrange)
  - improvements: test suite for SEXPR <-> XML format conversions (Daniel
    Berrange), virsh output regression suite (Daniel Berrange), new environ
    variable VIRSH_DEFAULT_CONNECT_URI for the default URI when connecting
    (Daniel Berrange), graphical console support for paravirt guests
    (Jeremy Katz), parsing of simple Xen config files (with Daniel Berrange),
    early work on defined (not running) domains (Daniel Berrange),
    virsh output improvement (Daniel Berrange
* Mon Aug 28 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.4
  - bug fixes: spec file fix (Mark McLoughlin), error report problem (with
    Hugh Brock), long integer in Python bindings (with Daniel Berrange), XML
    generation bug for CDRom (Daniel Berrange), bug whem using number() XPath
    function (Mark McLoughlin), fix python detection code, remove duplicate
    initialization errors (Daniel Berrange)
  - improvements: UUID in XML description (Peter Vetere), proxy code
    cleanup, virtual CPU and affinity support + virsh support (Michel
    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
    for console in XML (Daniel Berrange), added XML dump to driver and proxy
    support (Daniel Berrange), extention of boot options with support for
    floppy and cdrom (Daniel Berrange), features block in XML to report/ask
    PAE, ACPI, APIC for HVM domains (Daniel Berrange), fail saide-effect
    operations when using read-only connection, large improvements to test
    driver (Daniel Berrange)
  - documentation: spelling (Daniel Berrange), test driver examples.
* Wed Aug 16 2006 jfehlig@novell.com
- Added ExclusiveArch tag so as to only build on x86 and x86_64
* Mon Jul 31 2006 jfehlig@novell.com
- initial submission of libvirt package, version 0.1.3
